@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2005-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--               Copyright (C) 2005, 2006, 2007, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,77 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: address.c,v $
--- Revision 1.15.2.1  2009/06/06 13:14:03  jsedwards
--- Moved get_input function to new dialog.c file, renamed it to nwos_ask_user,
--- and changed to call it.
---
--- Revision 1.15  2009/03/07 20:17:19  jsedwards
--- Removed #include of objectify_private.h, not needed.
---
--- Revision 1.14  2007/07/01 19:44:11  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.13  2007/01/06 20:10:41  jsedwards
--- Change to find_public_spelling instead of find_spelling.
---
--- Revision 1.12  2006/12/21 12:59:47  jsedwards
--- Hack to make it compile with new split public and private classes,
--- NON-FUNCTIONAL!
---
--- Revision 1.11  2006/12/07 14:08:46  jsedwards
--- Moved setup routine and associated functions to attic/big_bang.c.
---
--- Revision 1.10  2006/12/01 14:31:30  jsedwards
--- Changed to use new malloc_reference_list and free_reference_list functions
--- instead of inlining the code.
---
--- Revision 1.9  2006/11/11 12:01:01  jsedwards
--- Update e-mail address to something that works.
---
--- Revision 1.8  2006/10/26 01:51:22  jsedwards
--- Merged alpha_05_branch back into main trunk.
---
--- Revision 1.7.2.2  2006/10/25 12:22:26  jsedwards
--- Changed C_struct_class_definition to C_struct_Class_Definition so the case
--- is consistent with all the other C_struct objects.
---
--- Revision 1.7.2.1  2006/09/01 13:27:20  jsedwards
--- Changed "nwos_object_size" to "nwos_reference_list_size" and added the
--- object reference to "nwos_fill_in_common_header" so it can put the "id"
--- in the header now.
---
--- Revision 1.7  2006/01/06 14:10:34  jsedwards
--- Added "direction" class stuff, setup routine and (commented out) add
--- address routine.
---
--- Revision 1.6  2005/12/29 17:50:53  jsedwards
--- Commented out printf debugging statements, that aren't useful now.
---
--- Revision 1.5  2005/12/29 17:01:41  jsedwards
--- Changed to just read spelling obj header to get reference list instead of
--- the whole variable sized object.
---
--- Revision 1.4  2005/12/27 18:20:07  jsedwards
--- Changed to look up class definition instead of fixed file name.
---
--- Revision 1.3  2005/12/24 16:18:26  jsedwards
--- Removed "host" id from object references (ObjRef).  Host redirection will
--- be done using a "redirection" object in the future.
---
--- Revision 1.2  2005/12/21 03:44:33  jsedwards
--- Changed so "postal_code" is not a separate class, but just part of the
--- "state" object.  Removed the "create_postal_code" routine.
---
--- Revision 1.1  2005/12/17 15:21:37  jsedwards
--- Initial version with separate object for postal code.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
