@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2007-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                  Copyright (C) 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,91 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- This is a one time use program to add a bunch of features to the PERSON class
---
--- $Log: add_class.c,v $
--- Revision 1.24  2009/03/08 19:38:10  jsedwards
--- Fixed year in Copyright.
---
--- Revision 1.23  2009/03/08 16:59:09  jsedwards
--- Changed include objectify_private.h to objectify.h and added include
--- class_definition.h and disk_io.h.
---
--- Revision 1.22  2008/08/31 18:25:40  jsedwards
--- Change for new parameters to nwos_initialize_objectify without key stuff
--- and eliminate calle to nwos_set_root_object because initialize does that now.
---
--- Revision 1.21  2008/03/28 11:33:50  jsedwards
--- Add test to verify that class doesn't already exist!!
---
--- Revision 1.20  2008/03/14 12:50:58  jsedwards
--- Changed to add SHA512 class.
---
--- Revision 1.19  2007/08/17 16:44:30  jsedwards
--- Changed to add SHA256 class.
---
--- Revision 1.18  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.17  2007/06/09 12:05:59  jsedwards
--- Change to create 'Family Name' class.
---
--- Revision 1.16  2007/06/09 11:39:45  jsedwards
--- Changed to add "Given Name" class.
---
--- Revision 1.15  2007/05/28 15:15:44  jsedwards
--- Changed to create 'Unit' class again, but this time with more generic
--- 'Acquisition' and 'Disposal' features instead of 'Purchase' and 'Sale'
--- because somtimes stuff is given, thrown away, or stolen for example.
---
--- Revision 1.14  2007/05/28 10:36:54  jsedwards
--- Change to create 'Unit' class.
---
--- Revision 1.13  2007/05/20 17:49:20  jsedwards
--- Change to add SERIAL NUMBER class.
---
--- Revision 1.12  2007/05/20 17:36:15  jsedwards
--- Change to add "MODEL NUMBER" class.
---
--- Revision 1.11  2007/05/20 17:21:44  jsedwards
--- Change to add ACRONYM class.
---
--- Revision 1.10  2007/05/20 15:32:53  jsedwards
--- Changed to create Manufacturer class.
---
--- Revision 1.9  2007/05/06 02:56:55  jsedwards
--- Change to create "Checking" class.
---
--- Revision 1.8  2007/05/05 17:01:25  jsedwards
--- Change to add "account number" class.
---
--- Revision 1.7  2007/05/05 16:25:06  jsedwards
--- Changed to add "account" class.
---
--- Revision 1.6  2007/04/21 18:06:52  jsedwards
--- Change to create 'device' class.
---
--- Revision 1.5  2007/04/21 17:58:35  jsedwards
--- Changed to add 'URL' (Unified Resource Locator) class.
---
--- Revision 1.4  2007/04/19 12:48:51  jsedwards
--- Change abbreviation to acronym and add url list in credit union.
---
--- Revision 1.3  2007/04/14 02:09:46  jsedwards
--- Change to add the "credit union" class.
---
--- Revision 1.2  2007/04/13 12:20:53  jsedwards
--- Moved code to find class references to separate functions.
---
--- Revision 1.1  2007/04/11 14:26:53  jsedwards
--- Initial version, specifically adds "dollars and cents".
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
