@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                    Copyright (C) 2007 QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                  Copyright (C) 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,39 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: add_more_names.c,v $
--- Revision 1.6.6.2  2009/05/23 03:54:11  jsedwards
--- Changed to add 14 new names.
---
--- Revision 1.6.6.1  2009/05/22 12:09:50  jsedwards
--- Changed include of objectify_private.h to objectify.h, removed root object
--- stuff (now done by initialize function), and changed to new initialize
--- objectify calling conventions.
---
--- Revision 1.6  2007/07/29 17:41:37  jsedwards
--- Changed to add a few more girls names.
---
--- Revision 1.5  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.4  2007/06/05 12:38:43  jsedwards
--- Changed to add a bunch more names.
---
--- Revision 1.3  2007/05/20 14:35:36  jsedwards
--- Added some V through Z names.
---
--- Revision 1.2  2007/05/05 14:07:10  jsedwards
--- Changed to add some other names.
---
--- Revision 1.1  2007/05/05 12:42:01  jsedwards
--- Initial version.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
