@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2007-2008  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                  Copyright (C) 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,67 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- This is a one time use program to add a feature to the "Credit Union" class
---
--- $Log: add_to_class.c,v $
--- Revision 1.16  2008/09/01 00:22:56  jsedwards
--- Fix year in copyright.  NO code changes.
---
--- Revision 1.15  2008/08/31 16:33:38  jsedwards
--- Added assert around call to nwos_read_variable_sized_object_from_disk
--- because it now returns false if it fails, whereas before it asserted itself.
---
--- Revision 1.14  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.13  2007/06/03 12:19:19  jsedwards
--- Changed to add 'date discontinued' to device.
---
--- Revision 1.12  2007/05/28 19:57:50  jsedwards
--- Change yet again to add 'specifications url' feature to 'Device' class.
---
--- Revision 1.11  2007/05/28 15:53:21  jsedwards
--- Change to add generic name and introduction date to 'Device', and rearrange
--- order.
---
--- Revision 1.10  2007/05/28 10:29:05  jsedwards
--- Add even more features to Device.
---
--- Revision 1.9  2007/05/28 10:08:47  jsedwards
--- Added remove_feature() function and modified Device class by removing
--- features that are specific to a particular unit and added more features
--- that are not specific to a particular unit.
---
--- Revision 1.8  2007/05/25 02:48:32  jsedwards
--- Change to add 'location' to 'device' class.
---
--- Revision 1.7  2007/05/22 02:15:15  jsedwards
--- Change to add 'purchase' and 'sale' features to 'Device' class.
---
--- Revision 1.6  2007/05/06 00:02:45  jsedwards
--- Changed to add 'pin' to 'account' class.
---
--- Revision 1.5  2007/05/05 23:43:25  jsedwards
--- Added functions to find built in types from add_class.c.
---
--- Revision 1.4  2007/04/22 13:49:45  jsedwards
--- Added another 2 features to 'credit union' class.
---
--- Revision 1.3  2007/04/21 15:35:50  jsedwards
--- Made yet another addition to the 'credit union' class.
---
--- Revision 1.2  2007/04/19 14:40:29  jsedwards
--- Changed to add two more features to credit union.
---
--- Revision 1.1  2007/04/19 13:19:13  jsedwards
--- Created from add_to_check.c program, changed to add to credit union class.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
