@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2007-2008  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                  Copyright (C) 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,52 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- This is a one time use program to add a bunch of features to the PERSON class
---
--- $Log: add_to_person.c,v $
--- Revision 1.12  2008/09/01 00:22:57  jsedwards
--- Fix year in copyright.  NO code changes.
---
--- Revision 1.11  2008/08/31 16:33:38  jsedwards
--- Added assert around call to nwos_read_variable_sized_object_from_disk
--- because it now returns false if it fails, whereas before it asserted itself.
---
--- Revision 1.10  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.9  2007/03/31 11:33:14  jsedwards
--- Added more info.
---
--- Revision 1.8  2007/03/30 14:21:38  jsedwards
--- Removed private information that should be in a separate list.
---
--- Revision 1.7  2007/03/24 12:11:31  jsedwards
--- Add print statement to show what drive is being modified.
---
--- Revision 1.6  2007/03/24 02:21:45  jsedwards
--- Added print statement.
---
--- Revision 1.5  2007/03/24 02:16:34  jsedwards
--- Added code to recalculate the checksums and rewrite the class object.
---
--- Revision 1.4  2007/03/23 14:30:51  jsedwards
--- Fixed add_feature function, untested.
---
--- Revision 1.3  2007/03/23 11:42:06  jsedwards
--- Added a couple more features.
---
--- Revision 1.2  2007/03/22 14:28:11  jsedwards
--- Made changes and added to list of features to be added.
---
--- Revision 1.1  2007/03/22 13:18:26  jsedwards
--- Initial version... doesn't do anything yet.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
