@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2005-2007  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--            Copyright (C) 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,82 +17,34 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: big_bang.c,v $
--- Revision 1.20  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.  I have retained the CVS log from
+--   this file when it was in the root directory.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
--- Revision 1.19  2007/01/13 20:15:08  jsedwards
--- Added 'failed' to extra spelling list.
---
--- Revision 1.18  2007/01/09 13:04:18  jsedwards
--- Changed find_spelling to find_public_spelling and added 'missing' spelling.
---
--- Revision 1.17  2007/01/06 16:01:32  jsedwards
--- Added create_extra_spellings and create_extra_words routines.  The extra
--- words routine is not used yet because we would need to create things and
--- that is too complicated for now.
---
--- Revision 1.16  2006/12/29 01:51:10  jsedwards
--- Added more cities in Missouri.
---
--- Revision 1.15  2006/12/28 23:19:37  jsedwards
--- Added code to create all of the years from 1582 to 2020 (2020 was chosen
--- at random to just be out a few years it has no special meaning).  When we
--- generate the real public objects, probably need to generate a thousand
--- years into the future?
---
--- Revision 1.14  2006/12/27 14:57:40  jsedwards
--- Added writing messages about what is being created to log.
---
--- Revision 1.13  2006/12/27 12:19:30  jsedwards
--- Added code to import public names.
---
--- Revision 1.12  2006/12/25 19:08:40  jsedwards
--- Changed to call find_public_class_definition.
---
--- Revision 1.11  2006/12/11 03:34:48  jsedwards
--- Changed number in US_State class to ordinal number instead of uint8.  Fixed
--- bug in day of year calculation.  Changed to print out day of year values.
---
--- Revision 1.10  2006/12/10 19:31:29  jsedwards
--- Added code to create cardinal and ordinal numbers and changed to new date
--- format with month_and_day objects.
---
--- Revision 1.9  2006/12/08 17:20:38  jsedwards
--- Changed to call generate_new_public_id instead of generate_new_id.  Appears
--- like this program might be working.
---
--- Revision 1.8  2006/12/08 11:32:04  jsedwards
--- Added code to initialize the public root object (00000001).
---
--- Revision 1.7  2006/12/08 10:43:09  jsedwards
--- Changed name of 'create_city' function to 'nwos_private_create_city'.
---
--- Revision 1.6  2006/12/07 14:14:16  jsedwards
--- Moved various creation functions from class files to here.
---
--- Revision 1.5  2006/12/05 15:00:50  jsedwards
--- Moved code to create root object to prep_disk.c also.
---
--- Revision 1.4  2006/12/05 14:54:39  jsedwards
--- Removed the class creation stuff, for the basic classes.
---
--- Revision 1.3  2006/12/05 14:21:47  jsedwards
--- Moved the user warnings and security stuff to prep_disk.c.
---
--- Revision 1.2  2006/12/05 14:18:56  jsedwards
--- Changed includes to compile now that this is in the attic.
---
--- Revision 1.1  2006/12/05 14:00:25  jsedwards
--- Moved big_bang.c to attic, as it should only be run once to create the
--- public objects and then never again.
 --
 -- Revision 1.27  2006/11/11 12:01:01  jsedwards
 -- Update e-mail address to something that works.
