@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2006-2008  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--               Copyright (C) 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,36 +17,34 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- NOTE: This app should only be run one time by me to convert the Alpha_05
---       objects to the new format of objects.  The plan after this is that
---       those objects become the "official" objects and everyone just uses
---       them.  This eliminates the whole chicken and egg problem.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.  I have retained the CVS log from
+--   this file before it was moved to the attic.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
--- CHANGES TO OBJECT FORMAT:
---
--- Previously objects had a header checksum and a data checksum.  That has been
--- replaced with a GPG signature.
---
--- $Log: convert_to_new_format.c,v $
--- Revision 1.4  2008/09/01 00:22:58  jsedwards
--- Fix year in copyright.  NO code changes.
---
--- Revision 1.3  2008/08/31 16:42:01  jsedwards
--- Added assert around calls to nwos_read_object_from_disk because now it
--- returns false if it fails instead of asserting itself.
---
--- Revision 1.2  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.1  2007/07/01 14:16:04  jsedwards
--- Move to attic.
 --
 -- Revision 1.3  2006/12/01 14:31:30  jsedwards
 -- Changed to use new malloc_reference_list and free_reference_list functions
@@ -61,6 +57,17 @@
 -- One time program to convert Alpha_04/Alpha_05 objects to the new format.
 -- This program should not ever be needed again after that.
 --
+--
+-- NOTE: This app should only be run one time by me to convert the Alpha_05
+--       objects to the new format of objects.  The plan after this is that
+--       those objects become the "official" objects and everyone just uses
+--       them.  This eliminates the whole chicken and egg problem.
+--
+-- CHANGES TO OBJECT FORMAT:
+--
+-- Previously objects had a header checksum and a data checksum.  That has been
+-- replaced with a GPG signature.
+--
 */
 
 #include <assert.h>
