@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2007-2008  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--            Copyright (C) 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,82 +17,34 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
---   This program takes a compressed file as input, scans it for chunks
---   that only have one block in them and attempts to move that block
---   into an adjacent block to free up that chunk.
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: eliminate_one_block_chunks.c,v $
--- Revision 1.21  2008/09/01 00:22:59  jsedwards
--- Fix year in copyright.  NO code changes.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.  I have retained the CVS log from
+--   this file before it was moved to the attic.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
--- Revision 1.20  2008/08/31 16:42:02  jsedwards
--- Added assert around calls to nwos_read_object_from_disk because now it
--- returns false if it fails instead of asserting itself.
---
--- Revision 1.19  2007/12/09 16:38:42  jsedwards
--- Added code to modify the used_chunks in the header when copying file.
---
--- Revision 1.18  2007/12/09 16:00:03  jsedwards
--- Fix bug where first block wasn't being written to output file.
---
--- Revision 1.17  2007/12/09 13:35:44  jsedwards
--- Added code to recalculate crc32 block checksum.
---
--- Revision 1.16  2007/12/09 00:52:06  jsedwards
--- Added code to verify files.
---
--- Revision 1.15  2007/12/08 22:44:55  jsedwards
--- Remove unused variables and code.
---
--- Revision 1.14  2007/12/08 22:39:29  jsedwards
--- Moved objectify initialization to main so it can be done again for testing.
---
--- Revision 1.13  2007/12/08 21:59:18  jsedwards
--- Added function to copy compressed file to output file changing as we go.
---
--- Revision 1.12  2007/12/08 20:53:47  jsedwards
--- Added function to encrypt the reference list blocks that have changed.
---
--- Revision 1.11  2007/12/08 18:48:27  jsedwards
--- Added function to put the new references in the reference list blocks.
---
--- Revision 1.10  2007/12/08 17:59:44  jsedwards
--- Change to store the reference list block instead of the file reference.
---
--- Revision 1.9  2007/12/08 16:47:57  jsedwards
--- Fixed find_new_locations to deal with multiple blocks in a row.
---
--- Revision 1.8  2007/12/07 15:06:08  jsedwards
--- Changed locate function to print out stats of each found block.
---
--- Revision 1.7  2007/12/06 15:19:08  jsedwards
--- First code to handle more than one block in a row.
---
--- Revision 1.6  2007/12/06 14:08:46  jsedwards
--- Added function to find location to move block - incomplete.
---
--- Revision 1.5  2007/12/02 15:50:06  jsedwards
--- Added counting the number of files checked and verify the block count is
--- correct for each file.
---
--- Revision 1.4  2007/11/30 14:15:22  jsedwards
--- Added code to log and print out the number of single blocks that are used
--- int the reference list first block and extra blocks.
---
--- Revision 1.3  2007/11/29 16:06:40  jsedwards
--- Added code to scan the remainder of each reference list.
---
--- Revision 1.2  2007/11/29 13:51:50  jsedwards
--- Added code to search the first block in a reference list for single blocks.
---
--- Revision 1.1  2007/11/29 12:19:40  jsedwards
--- Move to attic.
 --
 -- Revision 1.4  2007/11/29 05:36:36  jsedwards
 -- Added subroutine to scan the files for the blocks found in block table.
