@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2005-2007  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--            Copyright (C) 2004, 2005, 2006, 2007, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,43 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: export_0014_to_csv.c,v $
--- Revision 1.7  2007/07/01 19:44:13  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.6  2006/12/23 16:35:16  jsedwards
--- Added some functions taked from other files that were removed.
---
--- Revision 1.5  2006/12/23 16:11:49  jsedwards
--- Added code to process all the newer file related classes.
---
--- Revision 1.4  2006/12/23 14:11:04  jsedwards
--- Exporting all of the older classes working.
---
--- Revision 1.3  2006/12/23 12:58:28  jsedwards
--- Copied in functions from old export_0005_to_csv.c.
---
--- Revision 1.2  2006/12/22 14:24:00  jsedwards
--- Remove _0014 from names and change 'import' to 'export'.
---
--- Revision 1.1  2006/12/22 14:06:13  jsedwards
--- Moved from directory above into its own directory.
---
--- Revision 1.1  2006/12/22 13:17:40  jsedwards
--- Renamed import_compressed_0014.c to export_0014_to_csv.c.
---
--- Revision 1.2  2006/12/22 13:12:22  jsedwards
--- Change so loop is inside function.
---
--- Revision 1.1  2006/12/18 18:36:03  jsedwards
--- Initial version, very incomplete.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
