@@ -1,93 +1,48 @@
-/*             This file is part of the New World OS project
---                   Copyright (C) 2006  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+/*
+--          This file is part of the New World OS and Objectify projects
+--                  Copyright (C) 2006, 2007, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
--- NWOS is free software;  you can redistribute it and/or modify it under the
--- terms of the GNU General Public License  as published by the Free Software
--- Foundation; either version 2, or (at your option) any later version.  This
--- software is distributed with the hope that it will be useful,  but WITHOUT
--- ANY WARRANTY;  without  even the  implied warranty  of MERCHANTABILITY  or
--- FITNESS FOR A PARTICULAR PURPOSE.   See the GNU General Public License for
--- more  details.  You should have received a copy  of the GNU General Public
--- License along with this package;  see the file LICENSE.  If not, write to:
+--   This program is free software: you can redistribute it and/or modify
+--   it under the terms of the GNU General Public License as published by
+--   the Free Software Foundation, either version 3 of the License, or
+--   (at your option) any later version.
 --
---      Free Software Foundation, Inc.
---      59 Temple Place - Suite 330
---      Boston, MA 02111-1307, USA.
+--   This program is distributed in the hope that it will be useful,
+--   but WITHOUT ANY WARRANTY; without even the implied warranty of
+--   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+--   GNU General Public License for more details.
 --
--- $Log: import_from_0014_csv.c,v $
--- Revision 1.22  2007/04/07 14:03:12  jsedwards
--- Fix copy and paste errors in phone number print statements.
+--   You should have received a copy of the GNU General Public License
+--   along with this program, in the file LICENSE.  If not, see 
+--   <http://www.gnu.org/licenses/>.
 --
--- Revision 1.21  2007/04/07 13:30:27  jsedwards
--- Added code to save phone_number and mobile_phone objects.
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
 --
--- Revision 1.20  2007/04/07 13:09:31  jsedwards
--- Added code to create private 801 area code object.
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
 --
--- Revision 1.19  2007/04/07 02:15:05  jsedwards
--- Added code to generate person objects.
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
 --
--- Revision 1.18  2007/04/07 00:41:36  jsedwards
--- Added code to search for and link in public name if it exists.
+--   You can also contact me via paper mail at:
 --
--- Revision 1.17  2007/04/06 14:09:34  jsedwards
--- Added code to fix class definition on spelling and name objects.
+--      QRW Software
+--      P.O. Box 27511
+--      Salt Lake City, UT 84127-0511, USA.
 --
--- Revision 1.16  2007/04/06 14:01:18  jsedwards
--- Added code to link to public spelling if it exists.
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- Revision 1.15  2007/04/06 13:52:46  jsedwards
--- Added code to write name and spelling objects.
---
--- Revision 1.14  2007/04/06 13:31:09  jsedwards
--- Added process_spelling, incomplete.
---
--- Revision 1.13  2007/04/06 13:07:25  jsedwards
--- Started adding name processing, incomplete.
---
--- Revision 1.12  2007/04/06 12:27:06  jsedwards
--- Enabled the area code, phone number, and mobile phone objects.
---
--- Revision 1.11  2007/04/05 13:18:59  jsedwards
--- Added code to create date from the old csv date.
---
--- Revision 1.10  2007/04/05 12:58:35  jsedwards
--- Added creation of private month and day objects for dates.
---
--- Revision 1.9  2007/04/05 12:37:16  jsedwards
--- Combined process_month function into import_month function so that all
--- months are processed once.
---
--- Revision 1.8  2007/04/05 12:13:34  jsedwards
--- Added code to create new year and month private objects from old objects.
---
--- Revision 1.7  2007/04/05 11:46:58  jsedwards
--- Enabled doing gender objects and deleted all the save_object stuff.
---
--- Revision 1.6  2007/04/05 11:32:50  jsedwards
--- Changed to initialize objectify and print warning when a block is already
--- used.
---
--- Revision 1.5  2007/04/05 11:20:55  jsedwards
--- Fix cut and paste error in date print statement.
---
--- Revision 1.4  2007/04/04 23:25:58  jsedwards
--- Changed to just do person objects and objects that they require (date,
--- year, month, name, spelling).
---
--- Revision 1.3  2007/01/01 16:11:18  jsedwards
--- Now reads in all objects except the root object and reference lists and
--- saves them in RAM.
---
--- Revision 1.2  2006/12/29 13:54:54  jsedwards
--- Removed creation of file/device because that should be done with prep_disk
--- now.  Other changes to make it compile and link, still NON-functional.
---
--- Revision 1.1  2006/12/23 16:17:34  jsedwards
--- Copied import_from_0005_csv.c to start.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
