@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2006-2007  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                  Copyright (C) 2006, 2007, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,33 +17,34 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: import_public_csv.c,v $
--- Revision 1.6  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.  I have retained the CVS log from
+--   this file before it was moved to the attic.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
--- Revision 1.5  2006/12/27 14:59:27  jsedwards
--- Added messages about what is being written to log and fixed bug where
--- reference list ids were always zeros.
---
--- Revision 1.4  2006/12/27 12:21:32  jsedwards
--- Add call to log arguments when program is started.
---
--- Revision 1.3  2006/12/25 12:22:59  jsedwards
--- Deleted all the code to fake a key because now objectify can handle a call
--- to initialize with null values.  Also set the encryption level.
---
--- Revision 1.2  2006/12/14 22:31:54  jsedwards
--- Change include paths because now this is located in the attic directory.
---
--- Revision 1.1  2006/12/14 15:00:13  jsedwards
--- Moved from root directory because this should only be used once.
 --
 -- Revision 1.7  2006/12/05 04:22:56  jsedwards
 -- Changed to create a root object (00000001).
