@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                   Copyright (C) 2007  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                  Copyright (C) 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,34 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- This is a simple program to list all public names in the system, this
--- includes names for people, cities, states, classes, manufacturers, etc.
---
--- $Log: list_public_names.c,v $
--- Revision 1.4  2009/06/13 11:47:36  jsedwards
--- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
---
--- Revision 1.3.6.1  2009/05/18 12:41:20  jsedwards
--- Fixed to compile with new refactored files in objectify: changed include of
--- objectify_private.h file to objectify.h, changed parameters to initialize
--- objectify function, and removed root object stuff (now handled by initialize).
---
--- Revision 1.3  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.2  2007/06/23 11:55:37  jsedwards
--- Removed private file patch which is no longer needed because public objects
--- are separate now.
---
--- Revision 1.1  2007/06/03 17:17:22  jsedwards
--- Initial version, created from list_public_spellings.c.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
