@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                    Copyright (C) 2008 QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                  Copyright (C) 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,33 +17,39 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: log_file.c,v $
--- Revision 1.4  2008/08/31 18:25:43  jsedwards
--- Change for new parameters to nwos_initialize_objectify without key stuff
--- and eliminate calle to nwos_set_root_object because initialize does that now.
---
--- Revision 1.3  2008/02/23 01:41:59  jsedwards
--- Changed to call new nwos_add_info_to_existing_file function to add SHA1 and
--- SHA256 sums to existing file.
---
--- Revision 1.2  2008/02/16 13:05:19  jsedwards
--- Changed AccessType to PUBLIC.
---
--- Revision 1.1  2007/11/24 17:06:12  jsedwards
--- Initial version.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
+
 #include <stdio.h>
 
-#include "../objectify_private.h"
+#include "../objectify.h"
 
 
 int main(int argc, char* argv[])
@@ -74,8 +78,6 @@ int main(int argc, char* argv[])
 	{
 	    printf("result: %d\n", result);
 	}
-
-	nwos_flush_bit_maps();
     }
 
 
