@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2004-2007  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--            Copyright (C) 2004, 2005, 2006, 2007, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,25 +17,35 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: objectify_0014.h,v $
--- Revision 1.4  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.  Since this file was originally
+--   copied from the file in the root directory I have left the CVS log from
+--   that file below.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
--- Revision 1.3  2006/12/21 13:17:16  jsedwards
--- Include c_structs_0014.h file.
---
--- Revision 1.2  2006/12/18 18:34:54  jsedwards
--- Changes to be used to read old compressed version 0014 files.
---
--- Revision 1.1  2006/12/17 11:53:44  jsedwards
--- Version copied from root directory of Version 0014.
 --
 -- Revision 1.55  2006/12/01 14:27:47  jsedwards
 -- Added a union in the CommonHeader to allow the number of references in a
