@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2008-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                     Copyright (C) 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,39 +17,36 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: read_md5_file.c,v $
--- Revision 1.7  2009/03/08 19:38:10  jsedwards
--- Fixed year in Copyright.
---
--- Revision 1.6  2009/03/08 17:05:56  jsedwards
--- Changed include objectify_private.h to objectify.h.
---
--- Revision 1.5  2008/08/31 18:25:44  jsedwards
--- Change for new parameters to nwos_initialize_objectify without key stuff
--- and eliminate calle to nwos_set_root_object because initialize does that now.
---
--- Revision 1.4  2008/05/08 11:58:12  jsedwards
--- Fixed so that it will accept an asterisk before the file name.
---
--- Revision 1.3  2008/02/23 01:40:24  jsedwards
--- Removed print statement accidentally left in previous check in.
---
--- Revision 1.2  2008/02/16 13:11:38  jsedwards
--- Changed to call new nwos_create_file_with_only_md5 function with entries
--- read from file.
---
--- Revision 1.1  2008/02/14 13:05:29  jsedwards
--- Initial version just reads file in and prints it back out.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
+
 #include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
