@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2007-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                  Copyright (C) 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,104 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: backup.c,v $
--- Revision 1.24  2009/03/14 22:41:59  jsedwards
--- Added include of new backup.h file.
---
--- Revision 1.23  2009/03/13 12:09:28  jsedwards
--- Added include log.h file.
---
--- Revision 1.22  2009/03/08 00:06:18  jsedwards
--- Changed include objectify_private.h to disk_io.h.
---
--- Revision 1.21  2008/06/26 14:51:33  jsedwards
--- Changed nwos_initialize_backup to return false if opening backup files
--- failed.
---
--- Revision 1.20  2008/06/21 15:06:19  jsedwards
--- Added code to log backup file name when opening.
---
--- Revision 1.19  2008/06/14 16:13:02  jsedwards
--- Added a new line character to warning message for existing file.
---
--- Revision 1.18  2008/06/14 13:02:12  jsedwards
--- Fix Bug #1992924 - Changed so that if backup (.dif) file already exists it
--- will wait one second, generate a new file name and try to open it again.
---
--- Revision 1.17  2008/02/04 03:01:17  jsedwards
--- Added 'const' to backup_location parameter and added a '/' between the
--- backup_location (directory) and the file name.
---
--- Revision 1.16  2008/01/18 03:18:29  jsedwards
--- Add code to clear errno at beginning of sort_file in case it was non-zero
--- from some previous call.
---
--- Revision 1.15  2008/01/04 15:06:43  jsedwards
--- Bug #1862306 - Removed extra 'offset' increment in sort which caused the
--- 'offset' to be incremented twice when a duplicate block was encountered
--- and the buffer was full.
---
--- Revision 1.14  2008/01/04 14:55:49  jsedwards
--- Added code at the end of the sort function to go back through the file and
--- check the blocks are all in order, emit an error message if not.
---
--- Revision 1.13  2008/01/04 14:45:46  jsedwards
--- Added more debugging print statements to sort and changed some of the
--- existing debug print statements.  NO changes to the normal code, all of
--- the debugging statements are commented out.
---
--- Revision 1.12  2007/12/04 13:48:39  jsedwards
--- Corrected bug of using BACKUP_LOCATION instead of backup_location.
---
-
--- Revision 1.11  2007/12/04 13:25:26  jsedwards
--- Commented out the print statements for duplicate blocks.  Added a log
--- message when there were duplicates found.
---
--- Revision 1.10  2007/11/24 17:32:46  jsedwards
--- Changed file extension from .bak to .dif, need to use .bak for something
--- else.
---
--- Revision 1.9  2007/11/20 06:06:29  jsedwards
--- Fix to not write to backup file unless it is open and to close backup file
--- if an error occurs.
---
--- Revision 1.8  2007/11/14 13:53:10  jsedwards
--- Change to use "objectify" for the file name instead of the username.
---
--- Revision 1.7  2007/11/13 15:07:25  jsedwards
--- Fixed compiler warning about 'read_offset' being uninitialized and add test
--- to make sure modifications were made before complaining that no backup was
--- made.
---
--- Revision 1.6  2007/11/12 14:35:54  jsedwards
--- Fixed code to deal with duplicate blocks.
---
--- Revision 1.5  2007/11/11 18:53:52  jsedwards
--- Added code to sort_file to deal with the case where the file is larger than
--- the sort buffer.
---
--- Revision 1.4  2007/11/10 15:04:48  jsedwards
--- Moved test for error after read in sort loop outside the loop so it doesn't
--- try to write the file after an error.
---
--- Revision 1.3  2007/11/10 14:48:16  jsedwards
--- Add malloc for buffer in sort_file that was lost during move from another
--- file.  Move setting of backup_file_desc to -1 from sort_file() to
--- nwos_terminate_backup().  And free memory allocated for nwos_backup_path.
---
--- Revision 1.2  2007/11/09 21:54:26  jsedwards
--- Added function to sort the blocks into order in the backup file.
---
--- Revision 1.1  2007/11/09 15:47:08  jsedwards
--- Initial version created with code take from disk_io.c.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revisions of this file and the disk_io.c file which this file was
+--   taken from.  (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
@@ -155,6 +81,7 @@ bool nwos_initialize_backup(const char* backup_location, Disk_Header* disk_heade
     TimeStamp time_stamp;
     int path_length;
     char* backup_file_suffix = ".dif";
+    Disk_Header copy_header;
     uint8 buffer[FILE_BLOCK_SIZE];
     size_t bytes_written();
     int retry_count = 0;
@@ -217,10 +144,15 @@ bool nwos_initialize_backup(const char* backup_location, Disk_Header* disk_heade
 	}
 	else
 	{
-	    assert(sizeof(*disk_header) <= sizeof(buffer));
+	    /* copy the header and then change the type_code to "diff" */
+
+	    memcpy(&copy_header, disk_header, sizeof(copy_header));
+	    memcpy(&copy_header.type_code, TYPE_CODE_DIFF, sizeof(copy_header.type_code));
+
+	    assert(sizeof(copy_header) <= sizeof(buffer));
 
 	    memset(buffer, 0, sizeof(buffer));
-	    memcpy(buffer, disk_header, sizeof(*disk_header));
+	    memcpy(buffer, &copy_header, sizeof(copy_header));
 
 	    if (write(backup_file_desc, buffer, sizeof(buffer)) != sizeof(buffer))
 	    {
@@ -689,6 +621,7 @@ void sort_file()
 void nwos_terminate_backup(bool modified, Disk_Header* disk_header)
 {
     time_t start_time;
+    Disk_Header copy_header;
 
     if (backup_file_desc < 0)
     {
@@ -701,11 +634,16 @@ void nwos_terminate_backup(bool modified, Disk_Header* disk_header)
     {
 	if (modified)
 	{
+	    /* copy the header and then change the type_code to "diff" */
+
+	    memcpy(&copy_header, disk_header, sizeof(copy_header));
+	    memcpy(&copy_header.type_code, TYPE_CODE_DIFF, sizeof(copy_header.type_code));
+
 	    if (lseek(backup_file_desc, (off_t)FILE_BLOCK_SIZE, SEEK_SET) < 0)
 	    {
 		perror(nwos_backup_path);
 	    }
-	    else if (write(backup_file_desc, disk_header, sizeof(*disk_header)) != sizeof(*disk_header))
+	    else if (write(backup_file_desc, &copy_header, sizeof(copy_header)) != sizeof(copy_header))
 	    {
 		perror(nwos_backup_path);
 	    }
