@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2004-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--         Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,103 +17,34 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: chunk_info.c,v $
--- Revision 1.22  2009/07/16 13:34:31  jsedwards
--- Changed so chunk_info ref member has the proper upper 4 bytes for the 32-bit
--- private space.
---
--- Revision 1.21  2009/07/11 22:13:51  jsedwards
--- Changed 'used_blocks' variable to 64 bits and print statements to use 'll'.
---
--- Revision 1.20  2009/06/30 10:23:37  jsedwards
--- Added include of new header.h file and removed call to write the used
--- private chunks back to the header if the chunk_info was modified, this is
--- done in the header.c file now.
---
--- Revision 1.19  2009/06/23 13:12:45  jsedwards
--- Remove debugging code accidentally left in previous check in.
---
--- Revision 1.18  2009/06/23 13:06:23  jsedwards
--- Added functions to deal with the MD5 verified flag.
---
--- Revision 1.17  2009/06/13 16:37:32  jsedwards
--- Add code to clear the chunk MD5 checksum when chunk has been inserted into
--- the chunk_info table.
---
--- Revision 1.16  2009/05/09 16:05:11  jsedwards
--- Added new nwos_blocks_used_in_chunk and nwos_chunk_is_full functions.
---
--- Revision 1.15  2009/05/09 10:58:47  jsedwards
--- Merged changes from alpha_29_10_branch.
---
--- Revision 1.7.2.3  2009/05/05 13:45:38  jsedwards
--- Moved calculation of used blocks before swapping for little endian in
--- nwos_terminate_chunk_info.
---
--- Revision 1.7.2.2  2009/05/05 12:59:05  jsedwards
--- Changed to verify used block count matches in nwos_terminate_chunk_info.
---
--- Revision 1.7.2.1  2009/05/05 12:48:22  jsedwards
--- Fix Bug #2786129 - builds incorrectly on big endian machines, added include
--- of config.h to define WORDS_BIGENDIAN.
---
--- Revision 1.14  2009/04/21 12:00:34  jsedwards
--- Changed to byte swap references as 64 bits and indexes as 32 bits for new
--- chunk_info table.  Also fixed print statement for unsigned long long.
---
--- Revision 1.13  2009/04/19 15:33:33  jsedwards
--- Changed to call new nwos_calculate_chunk_md5sum function if a chunk's MD5
--- checksum hasn't been updated, instead of asserting.
---
--- Revision 1.12  2009/04/19 14:56:03  jsedwards
--- Added new nwos_clear_chunk_digest function to clear the MD5 checksum to
--- zeros when a chunk has been modified.  Added loop to terminate so that if a
--- chunk has been modified but the MD5 checksum hasn't been updated it asserts.
---
--- Revision 1.11  2009/04/19 09:07:20  jsedwards
--- Moved nwos_hash_uint32_ref, nwos_hash_ref, and nwos_ref_to_offset functions
--- from gen_id.c file.
---
--- Revision 1.10  2009/04/14 10:58:47  jsedwards
--- Added asserts to verify that chunk_info is non-null.
---
--- Revision 1.9  2009/04/13 13:23:54  jsedwards
--- Changed initialize and terminate functions to call new read and write chunk
--- info functions in disk_io.c file, instead of doing the I/O directly.
---
--- Revision 1.8  2009/04/07 13:40:41  jsedwards
--- Merged in changes from disk_io.c file in CVS
--- branch_0030_new_chunk_info branch, see revision 1.89.2.1 in disk_io.c file.
---
--- Revision 1.7  2009/03/14 23:14:04  jsedwards
--- Added include of the new chunk_info.h file.
---
--- Revision 1.6  2009/03/14 11:46:46  jsedwards
--- Added include of gen_id.h file.
---
--- Revision 1.5  2009/03/13 12:14:18  jsedwards
--- Added includes for log.h and mem_alloc.h files.
---
--- Revision 1.4  2009/03/08 00:06:18  jsedwards
--- Changed include objectify_private.h to disk_io.h.
---
--- Revision 1.3  2009/03/04 14:56:25  jsedwards
--- Moved uint32_ref_to_info_index function from disk_io.c and renamed to
--- nwos_uint32_ref_to_info_index.
---
--- Revision 1.2  2009/03/02 15:32:11  jsedwards
--- Changed so allocate_new_chunk only calls write_empty_chunk if the archive
--- is stored in a block device.
---
--- Revision 1.1  2009/03/01 18:02:48  jsedwards
--- New file created from code taken from the disk_io.c file.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file, the disk_io.c file, and the
+--   objectify.c file, since this file was created with code taken from the
+--   disk_io.c and the objectify.c files.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
