@@ -1,10 +1,7 @@
 /*
---         This file is part of the New World OS and Objectify projects
---                    Copyright (C) 2004-2009  QRW Software
---              J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                         http://www.qrwsoftware.com
---                         http://nwos.sourceforge.com
---                      http://objectify.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--         Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -20,54 +17,34 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: chunk_info.h,v $
--- Revision 1.12  2009/06/23 13:05:46  jsedwards
--- Added MD5_VERIFIED_MASK and external declarations for verified functions.
---
--- Revision 1.11  2009/06/13 16:29:12  jsedwards
--- Moved external declaration for nwos_allocate_new_chunk from gen_id.h to
--- chunk_info.h because it is defined in the chunk_info.c file.
---
--- Revision 1.10  2009/06/01 10:44:02  jsedwards
--- Added Chunk_Info structure from Alpha_29.10_branch and called it
--- Chunk_Info_0029.
---
--- Revision 1.9  2009/05/09 16:04:01  jsedwards
--- Added external declarations for new nwos_blocks_used_in_chunk and
--- nwos_chunk_is_full functions.
---
--- Revision 1.8  2009/04/21 11:47:22  jsedwards
--- Changed chunk_info.ref to 64 bits and chunk_info.index to 32 bits.
---
--- Revision 1.7  2009/04/19 14:49:47  jsedwards
--- Added external declaration for new nwos_clear_chunk_digest function.
---
--- Revision 1.6  2009/04/19 09:01:27  jsedwards
--- Moved external references for nwos_hash_uint32_ref, nwos_hash_ref, and
--- nwos_ref_to_offset from gen_id.h file.
---
--- Revision 1.5  2009/04/13 13:21:16  jsedwards
--- Removed file descriptor parameter from initialize and terminate functions.
---
--- Revision 1.4  2009/04/11 21:41:29  jsedwards
--- Changed so that bit map size is derived from USABLE_BLOCKS_PER_CHUNK.
---
--- Revision 1.3  2009/04/11 21:11:30  jsedwards
--- Moved bit map and chunk defines from the disk_io.h file.
---
--- Revision 1.2  2009/04/07 12:44:39  jsedwards
--- Merged changes from objectify_private.h file in CVS
--- branch_0030_new_chunk_info branch, see revision 1.69.2.1 in disk_io.h file.
---
--- Revision 1.1  2009/03/14 22:43:37  jsedwards
--- Created from declarations moved from the disk_io.h file.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revisions of this file and the disk_io.h which this file was
+--   created from.  Also see the log in the disk_io.h file itself from when it
+--   was named objectify_private.h.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
