@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2005-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--            Copyright (C) 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,147 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: class_definition.c,v $
--- Revision 1.33  2009/03/10 10:16:17  jsedwards
--- Moved MAX_CLASS_DEFINITION_SIZE and MAX_FEATURE_NAME_SIZE defines to
--- class_definition.h file and renamed with _OBJ_SIZE suffix instead of _SIZE.
---
--- Revision 1.32  2009/03/09 14:00:41  jsedwards
--- Eliminated use of FILE_BLOCK_SIZE for kludge buffers.
---
--- Revision 1.31  2009/03/08 06:47:22  jsedwards
--- Removed include objectify_private.h and changed include objectify.h to
--- class_definition.h.  Moved class reference global variables
--- from objectify.c.  Changed calls to nwos_generate_new_completely_random_id
--- nwos_generate_new_id, call nwos_is_ready instead of reading nwos_ready flag
--- directly, and call nwos_is_writable instead of nwos_disk_io_is_read_write.
---
--- Revision 1.30  2009/01/31 12:29:12  jsedwards
--- Moved functions to deal with various file class definitions from objectify.c.
---
--- Revision 1.29  2008/08/31 21:53:51  jsedwards
--- Added an assert around calls to nwos_read_variable_sized_object_from_disk
--- and nwos_read_object_from_disk because now they return false when they fail
--- instead of asserting themselves.
---
--- Revision 1.28  2008/07/19 13:07:03  jsedwards
--- Added asserts to verify that after an updated class is cloned that it can
--- be accessed succesfully.  NO changes to the code operation.
---
--- Revision 1.27  2008/07/17 12:07:18  jsedwards
--- Changed nwos_find_or_create_private_class_definition to return
--- ObjCreateResult instead of void.
---
--- Revision 1.26  2008/03/15 16:41:00  jsedwards
--- Changed 'nwos_find_private_class_definition' to call new
--- 'nwos_get_object_class_without_update function' instead of
--- 'nwos_get_object_class' to keep from getting in a recursive mess.
---
--- Revision 1.25  2007/07/28 01:20:09  jsedwards
--- Changes to deal with classes that have been updated.
---
--- Revision 1.24  2007/07/01 19:44:11  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.23  2007/06/21 22:34:15  jsedwards
--- Added function to determine the size of an object automatically from it's
--- class.
---
--- Revision 1.22  2007/04/12 02:43:27  jsedwards
--- Add #ifdef public_mode around find or create public feature definition.
---
--- Revision 1.21  2007/03/23 14:04:29  jsedwards
--- Finished routine to create feature definition, not tested yet!
---
--- Revision 1.20  2007/03/23 13:22:06  jsedwards
--- Added find_public_feature_definition and started adding create public
--- feature.
---
--- Revision 1.19  2007/01/04 17:30:28  jsedwards
--- Changed to always get a completely random id for the private class clone
--- and print clone message to log instead of stdout.
---
--- Revision 1.18  2007/01/03 14:26:08  jsedwards
--- Changed the name of create_private_class_definition to
--- find_or_create_private_class_definition.
---
--- Revision 1.17  2007/01/03 14:20:39  jsedwards
--- Changed create_class_definition to create_private_class_definition which
--- clones the public class.
---
--- Revision 1.16  2007/01/02 11:23:32  jsedwards
--- Removed assert so we can clone the class_definition_class itself.
---
--- Revision 1.15  2006/12/21 13:15:41  jsedwards
--- Ifdef out find_class_definition function, at least for now.
---
--- Revision 1.14  2006/12/20 12:37:26  jsedwards
--- Split class_definition_class_ref into public and private variants.  Added
--- find public and find private class definiton functions.
---
--- Revision 1.13  2006/12/15 11:28:05  jsedwards
--- Change find routine to change the global variable when it steps down one
--- level.  Can only handle two areas (NOT three).
---
--- Revision 1.12  2006/12/14 13:49:59  jsedwards
--- Modified find_class_definition function to search through levels of class
--- definitions (encrypted, private, public).
---
--- Revision 1.11  2006/12/14 13:20:35  jsedwards
--- Added clone_class function.
---
--- Revision 1.10  2006/12/14 12:26:12  jsedwards
--- Change to clear kludge instead of class_ref.
---
--- Revision 1.9  2006/12/08 17:12:57  jsedwards
--- Moved 'read_class_definition' function from objectify.c and fixed it to
--- read the new variable length class_definition.  HOWEVER it is kludged now
--- to only NOT read the feature definitions into the class object because
--- none of the places it is called is set up to deal with variable sized
--- class objects.  Needs to be fixed!!
---
--- Revision 1.8  2006/12/05 04:17:08  jsedwards
--- Changed find_class to deal with the new variable sized class objects.
---
--- Revision 1.7  2006/12/01 14:37:23  jsedwards
--- Fix the year in the copyright.
---
--- Revision 1.6  2006/12/01 14:31:30  jsedwards
--- Changed to use new malloc_reference_list and free_reference_list functions
--- instead of inlining the code.
---
--- Revision 1.5  2006/11/29 18:29:03  jsedwards
--- Fixed bug where memory following class_ref was overwritten if pointers were
--- not the same size as an ObjRef.
---
--- Revision 1.4  2006/11/11 14:19:07  jsedwards
--- Moved find_class_defintion function from objectify.c.
---
--- Revision 1.3  2006/11/11 12:01:01  jsedwards
--- Update e-mail address to something that works.
---
--- Revision 1.2  2006/10/26 01:51:23  jsedwards
--- Merged alpha_05_branch back into main trunk.
---
--- Revision 1.1.2.2  2006/10/25 12:22:27  jsedwards
--- Changed C_struct_class_definition to C_struct_Class_Definition so the case
--- is consistent with all the other C_struct objects.
---
--- Revision 1.1.2.1  2006/09/01 13:27:20  jsedwards
--- Changed "nwos_object_size" to "nwos_reference_list_size" and added the
--- object reference to "nwos_fill_in_common_header" so it can put the "id"
--- in the header now.
---
--- Revision 1.1  2005/12/31 17:54:54  jsedwards
--- Extracted "create_class_definition" routine from "big_bang.c" and created
--- this file.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
