@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2005-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--            Copyright (C) 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,164 +17,35 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: computer.c,v $
--- Revision 1.38  2009/06/13 11:37:25  jsedwards
--- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revisions of this file.  Since this file was originally created
+--   from a file called "create_person.c".  To make it easier to find I have
+--   left the part of the log from when it was called create_person.c below.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
--- Revision 1.37.2.1  2009/06/06 13:18:43  jsedwards
--- Moved get_input function to new dialog.c file, renamed it to nwos_ask_user,
--- and changed to call it.
---
--- Revision 1.37  2009/03/19 11:38:20  jsedwards
--- Wrapped call to nwos_set_security_level with ifdef CHANGE_SECURITY_TO_DENSITY
--- because what was called security level stuff is temporarily disabled.
---
--- Revision 1.36  2009/03/13 12:18:46  jsedwards
--- Added include of strlcxx.h file.
---
--- Revision 1.35  2009/03/07 20:17:19  jsedwards
--- Removed #include of objectify_private.h, not needed.
---
--- Revision 1.34  2008/09/01 03:13:41  jsedwards
--- Change for new nwos_initialize_objectify calling convention (doesn't pass
--- back root_object_reference anymore) and removed call to nwos_set_root_object
--- because initialize calls it now.
---
--- Revision 1.33  2008/08/30 12:46:07  jsedwards
--- Removed code and variables to read pass phrase and pass it to initialize,
--- and change parameters passed to initialize.
---
--- Revision 1.32  2008/02/03 01:00:16  jsedwards
--- Changed DEFAULT_TYPE_RW to READ_WRITE.
---
--- Revision 1.31  2007/10/07 03:51:35  jsedwards
--- Added new function 'space_available' and don't execute command if it
--- returns false.
---
--- Revision 1.30  2007/09/02 19:45:31  jsedwards
--- Added calls to set the block estimate.
---
--- Revision 1.29  2007/08/12 20:45:00  jsedwards
--- Change all of the "Encryption Level" stuff to "Security Level" because it
--- doesn't really change the encryption at all, all it does is change the
--- randomization of where objects are stored.
---
--- Revision 1.28  2007/07/12 03:12:42  jsedwards
--- Add a command to add a birthday to a person.
---
--- Revision 1.27  2007/07/01 19:44:11  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.26  2007/05/24 13:27:13  jsedwards
--- Added list all manufacturers command.
---
--- Revision 1.25  2007/05/06 17:24:34  jsedwards
--- Add 'add account' and 'list accounts' commands.
---
--- Revision 1.24  2007/04/22 15:17:44  jsedwards
--- Added "list all credit unions" command.
---
--- Revision 1.23  2007/03/17 11:43:30  jsedwards
--- Added code to set the encryption level to extreme.
---
--- Revision 1.22  2007/02/11 16:58:26  jsedwards
--- Changed so DEFAULT_TYPE has to specify RO (Read-Only) or RW (Read-Write).
---
--- Revision 1.21  2007/02/11 16:20:27  jsedwards
--- Changed calls to "strncat" to "strlcat" because it makes more sense.
---
--- Revision 1.20  2007/01/06 20:20:36  jsedwards
--- Changed to call both find_private_name and find_public_name instead of
--- find_name (which no longer exists).
---
--- Revision 1.19  2006/12/15 11:42:11  jsedwards
--- Removed kludge added in previous version, this version should be the same
--- as r1.17.
---
--- Revision 1.18  2006/12/15 11:29:40  jsedwards
--- Kludged to read root object from private area.
---
--- Revision 1.17  2006/11/30 00:51:12  jsedwards
--- Changed to use strlcpy instead of strcpy to stop warnings from linker.
---
--- Revision 1.16  2006/11/11 12:01:01  jsedwards
--- Update e-mail address to something that works.
---
--- Revision 1.15  2006/10/26 01:51:26  jsedwards
--- Merged alpha_05_branch back into main trunk.
---
--- Revision 1.14.2.3  2006/10/03 12:53:07  jsedwards
--- Changed so that instead of calling a separate routine after initialize to
--- change the already opened storage, you call it now with a type of storage
--- parameter and a path to the storage.  The problem with the other way was
--- if you tried reading a compressed file on another machine it tried to open
--- the default file which didn't exist.
---
--- Revision 1.14.2.2  2006/09/29 12:09:24  jsedwards
--- Added "list_persons" command.
---
--- Revision 1.14.2.1  2006/09/02 15:09:41  jsedwards
--- Add call to terminate objectify so reference list cache gets flushed back
--- to disk, etc.
---
--- Revision 1.14  2006/01/12 03:42:37  jsedwards
--- Changed the "what is number" routine to accept "phone number", "mobile
--- number", and "cell number" as well.
---
--- Revision 1.13  2006/01/12 03:35:22  jsedwards
--- Added help for "what is so and so's number".
---
--- Revision 1.12  2006/01/10 13:57:20  jsedwards
--- Added a phone number query command.
---
--- Revision 1.11  2006/01/09 03:27:13  jsedwards
--- Changed "describe" command to deal with persons or states.
---
--- Revision 1.10  2006/01/08 15:25:26  jsedwards
--- Added some more information to the help print out.
---
--- Revision 1.9  2006/01/08 15:12:46  jsedwards
--- Added "help" information.
---
--- Revision 1.8  2006/01/04 19:00:08  jsedwards
--- Made a separate subroutine to execute commands, instead of doing it in main
--- routine.  Changed main routine to check for parameters passed on command
--- line and reassemble them into a command string, which is passed to the
--- execute command subroutine.  This way a command can be passed to it via
--- the command line.
---
--- Revision 1.7  2006/01/04 15:15:41  jsedwards
--- Added "add city" and "list cities in state" commands.
---
--- Revision 1.6  2006/01/02 01:57:52  jsedwards
--- Fixed bug in get_input routine that was using a fixed size for the buffer
--- instead of the size parameter.
---
--- Revision 1.5  2006/01/01 21:19:30  jsedwards
--- Removed debugging print statement.
---
--- Revision 1.4  2006/01/01 19:50:50  jsedwards
--- Moved all of the tests for quitting (stop, exit, etc.) into a function
--- (is quit command) in objectify.c.
--- Added code to add mobile phone number to database.
---
--- Revision 1.3  2006/01/01 00:45:42  jsedwards
--- Added a command loop where it asks what to do and then tries to interpret
--- your request.
---
--- Revision 1.2  2005/12/31 19:03:33  jsedwards
--- Moved code to create a person object to the "person.c" file.
---
--- Revision 1.1  2005/12/31 14:49:08  jsedwards
--- Copied "create_person.c" into "computer.c" and "person.c" and then removed
--- "create_person.c".
 --
 -- Revision 1.15  2005/12/30 14:13:39  jsedwards
 -- Removed Social Security Number stuff, not ready yet.
