@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2005-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--            Copyright (C) 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,170 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: date.c,v $
--- Revision 1.41  2009/03/08 01:04:26  jsedwards
--- Removed include of objectify_private.h and changed all calls to
--- nwos_generate_new_completely_random_id to nwos_generate_new_id.
---
--- Revision 1.40  2008/09/01 00:10:49  jsedwards
--- Fix copyright year.  NO code changes.
---
--- Revision 1.39  2008/08/31 20:33:17  jsedwards
--- Add assert around calls to nwos_read_object_from_disk because it now
--- returns false when it fails, whereas before it would assert itself.
---
--- Revision 1.38  2007/07/01 19:44:11  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.37  2007/04/01 17:39:41  jsedwards
--- Added code for private mode to create_date.
---
--- Revision 1.36  2007/04/01 17:25:24  jsedwards
--- Added find_or_create_private_month_and_day function.
---
--- Revision 1.35  2007/04/01 16:07:50  jsedwards
--- Added find_or_create_private_year and find_or_create_public_year functions.
---
--- Revision 1.34  2007/04/01 14:58:15  jsedwards
--- Added find_public_date function.
---
--- Revision 1.33  2007/04/01 14:45:04  jsedwards
--- Changed incorrect calls to find_or_create_private_class to find_private_class
--- in find routines.
---
--- Revision 1.32  2007/04/01 14:32:56  jsedwards
--- Added find_private_month_and_day function.
---
--- Revision 1.31  2007/04/01 14:21:59  jsedwards
--- Added find_private_month function.
---
--- Revision 1.30  2007/04/01 14:11:49  jsedwards
--- Added find_private_year function.
---
--- Revision 1.29  2007/04/01 14:00:19  jsedwards
--- Added 'public' to the names of the find functions because they currently
--- only work on public dates.
---
--- Revision 1.28  2007/04/01 12:04:48  jsedwards
--- Added check for valid day in find_month_and_day and fixed bug in find_date
--- assertion on day.
---
--- Revision 1.27  2007/04/01 11:53:57  jsedwards
--- Removed unused result variables.
---
--- Revision 1.26  2006/12/28 23:13:15  jsedwards
--- Added ifdef to create_year function so that it is only compiled when in
--- public mode because all years should already be in the public data.  Also
--- changed create date to just call find_year instead of creating the year.
---
--- Revision 1.25  2006/12/25 12:13:00  jsedwards
--- Ifdef out code to find date in private area and switch find class to public
--- or private.
---
--- Revision 1.24  2006/12/21 13:10:51  jsedwards
--- Attempt to fix for new split public and private objects, but turned into a
--- hack to make it compile, NON-FUNCTIONAL!
---
--- Revision 1.23  2006/12/10 19:27:09  jsedwards
--- Converted to new date format with month_and_day objects.
---
--- Revision 1.22  2006/12/10 18:26:35  jsedwards
--- Split find_date out of create_date routine (untested).
---
--- Revision 1.21  2006/12/10 14:21:55  jsedwards
--- Split find year code out of create_year routine (untested).
---
--- Revision 1.20  2006/12/07 14:08:46  jsedwards
--- Moved setup routine and associated functions to attic/big_bang.c.
---
--- Revision 1.19  2006/12/01 14:31:30  jsedwards
--- Changed to use new malloc_reference_list and free_reference_list functions
--- instead of inlining the code.
---
--- Revision 1.18  2006/11/11 12:01:03  jsedwards
--- Update e-mail address to something that works.
---
--- Revision 1.17  2006/10/26 01:51:26  jsedwards
--- Merged alpha_05_branch back into main trunk.
---
--- Revision 1.16.2.3  2006/10/25 12:22:27  jsedwards
--- Changed C_struct_class_definition to C_struct_Class_Definition so the case
--- is consistent with all the other C_struct objects.
---
--- Revision 1.16.2.2  2006/09/10 20:43:30  jsedwards
--- Changed to use sizeof instead of hard coded 4 (not sure 4 was correct).
---
--- Revision 1.16.2.1  2006/09/02 01:11:19  jsedwards
--- Changed "nwos_object_size" to "nwos_reference_list_size" and added the
--- object reference to "nwos_fill_in_common_header" so it can put the "id"
--- in the header now.
---
--- Revision 1.16  2006/01/09 03:19:12  jsedwards
--- Changed the upgrade routine to search through the month class reference
--- list itself, to find all of the months instead of using the "get month ref"
--- routine.  The "get month ref" routine reads the month objects to find the
--- right one and since they are of the wrong size the checksum fails.
---
--- Revision 1.15  2006/01/06 14:08:52  jsedwards
--- Added code to upgrade a 0004 month object to a 0005 month object.
---
--- Revision 1.14  2006/01/01 21:49:01  jsedwards
--- Moved date, phone, us_state, and word class creations out of "big bang"
--- and into the respective files.
---
--- Revision 1.13  2006/01/01 00:41:23  jsedwards
--- Removed count from month object.  Since it was always 2, why have it?
--- Added date, month, and year to string routines.
---
--- Revision 1.12  2005/12/30 14:07:03  jsedwards
--- Added is_leap_year function.
---
--- Revision 1.11  2005/12/29 17:50:53  jsedwards
--- Commented out printf debugging statements, that aren't useful now.
---
--- Revision 1.10  2005/12/29 17:47:58  jsedwards
--- Changed to make Year object variable sized (although in reality at this
--- time it is fixed at 4 digits in the year).  This allows the write object
--- to disk routine to fill in the remainder of the 512 bytes with random data.
---
--- Revision 1.9  2005/12/27 18:32:36  jsedwards
--- Changed to look up class definition instead of using a fixed file name.
--- Also changed so that object id is random instead of based upon contents.
---
--- Revision 1.8  2005/12/24 16:18:26  jsedwards
--- Removed "host" id from object references (ObjRef).  Host redirection will
--- be done using a "redirection" object in the future.
---
--- Revision 1.7  2005/12/21 03:52:27  jsedwards
--- Moved US state objects creation from 'create_class_def.c' into 'date.c'.
---
--- Revision 1.6  2005/12/10 15:03:36  jsedwards
--- Fixed header to say the GPL is in the LICENSE file instead of COPYING.
---
--- Revision 1.5  2005/12/05 05:22:46  jsedwards
--- Change to call read_reference_list_from_disk for reference lists instead
--- of read_object_from_disk.  Also moved calculating checksums down to just
--- before writing object, so that no changes occur after computing them.
---
--- Revision 1.4  2005/12/04 14:09:10  jsedwards
--- Added checks when creating a date that it is a valid date.
---
--- Revision 1.3  2005/12/04 04:13:02  jsedwards
--- Added 'nwos' prefix to create_xxxx function names and eliminated the
--- 'referring' object parameter from all of them.
---
--- Revision 1.2  2005/12/04 00:37:46  jsedwards
--- Added get_month function and made create_date function work.
---
--- Revision 1.1  2005/12/03 23:22:09  jsedwards
--- Initial version extracted from create_person.c.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
