@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2007-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                  Copyright (C) 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,111 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: diff_compressed.c,v $
--- Revision 1.25  2009/07/18 15:40:43  jsedwards
--- Added code to set the upper 4 bytes of the reference in blocks from a 0029
--- or older file to 0xfffffffe and back to zero if the block has to go around
--- again.
---
--- Revision 1.24  2009/07/17 14:01:51  jsedwards
--- Fixed to deal with having 0xfffffffe in the upper word of the reference in
--- each block if the version > 29.
---
--- Revision 1.23  2009/07/17 13:23:19  jsedwards
--- Fixed added blocks error upper bytes print statement to print to stderr too.
---
--- Revision 1.22  2009/07/17 13:10:01  jsedwards
--- Fixed to report error and exit if upper four bytes of reference are not zero.
---
--- Revision 1.21  2009/07/11 13:30:30  jsedwards
--- Changed to pass TYPE_CODE_COMPRESSED in the calls to check headers.
---
--- Revision 1.20  2009/07/10 15:05:59  jsedwards
--- Changed to write "diff" into the headers of the output file if they are
--- version 0030 or above.
---
--- Revision 1.19  2009/07/02 13:47:01  jsedwards
--- Changed to call the new nwos_check_disk_header function instead of testing
--- the header inline.
---
--- Revision 1.18  2009/04/06 14:21:14  jsedwards
--- Merged in changes from CVS branch_0030_new_chunk_info branch, see revisions
--- 1.15.2.1, 1.15.2.2, and 1.15.2.3 below.
---
--- Revision 1.17  2009/03/08 00:06:18  jsedwards
--- Changed include objectify_private.h to disk_io.h.
---
--- Revision 1.16  2008/09/01 00:10:50  jsedwards
--- Fix copyright year.  NO code changes.
---
--- Revision 1.15.2.3  2008/08/16 02:26:14  jsedwards
--- Changed to work with new Disk_Header with total_chunks instead of
--- total_blocks and still allow diff'ing with 0022 to 0029 headers.
---
--- Revision 1.15.2.2  2008/08/15 13:48:54  jsedwards
--- Changed for new Disk_Header with total_chunks instead of total_blocks.
---
--- Revision 1.15.2.1  2008/08/15 13:39:16  jsedwards
--- Removed old code to upgrade from version 0021 to 0022.
---
--- Revision 1.15  2008/01/04 04:25:08  jsedwards
--- Added call to close the output file (fp3).
---
--- Revision 1.14  2007/11/17 21:26:57  jsedwards
--- Fix increment in version_string_to_int function so it isn't an infinite loop.
---
--- Revision 1.13  2007/11/17 20:00:09  jsedwards
--- Changed to detect if the files are older than version 0023 (where the
--- reference id's wrapped around the storage) and insert the next block in
--- bytes 0 to 3 of the block.  If they are not old leave zeros in bytes 0 to 3.
---
--- Revision 1.12  2007/07/01 19:44:11  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.11  2007/06/22 22:07:17  jsedwards
--- Add code to correctly deal with 0021 to 0022 conversion.
---
--- Revision 1.10  2007/06/19 19:06:30  jsedwards
--- Changed feature names in Disk Header because it was change (0022).
---
--- Revision 1.9  2007/03/24 14:08:17  jsedwards
--- Change to not write the next block info into bytes 0-3 when file 1 has
--- reached the end of file, because it tricks the patch program.
---
--- Revision 1.8  2007/03/24 12:32:39  jsedwards
--- Moved the increment of blocks added count outside the if writing output
--- file, so it gets incremented even when not writing an output file.
---
--- Revision 1.7  2007/03/24 12:29:13  jsedwards
--- Fixed to finish adding blocks from file 2 after file file 1 has reached
--- the end of the file.
---
--- Revision 1.6  2007/03/15 13:44:04  jsedwards
--- Changed to zero out the bytes before writing and added counts.
---
--- Revision 1.5  2007/03/15 12:50:25  jsedwards
--- Changed to write both the old header and the new header into the patch file.
---
--- Revision 1.4  2007/03/14 23:53:38  jsedwards
--- Added code to write the differences to a file.
---
--- Revision 1.3  2007/03/14 23:42:01  jsedwards
--- Changed to just look for changed blocks and blocks added in file 2 (assume
--- that no blocks were deleted).
---
--- Revision 1.2  2007/03/14 14:38:12  jsedwards
--- Changed to verify the headers are the same.
---
--- Revision 1.1  2007/02/25 16:00:53  jsedwards
--- This is a quick hack to compare the compressed archives of version 0017
--- and the updated (moved root objects) 0018 archive.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
