@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2006-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                  Copyright (C) 2006, 2007, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,35 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: diff_sparse.c,v $
--- Revision 1.6  2009/03/08 00:06:18  jsedwards
--- Changed include objectify_private.h to disk_io.h.
---
--- Revision 1.5  2007/08/10 00:03:35  jsedwards
--- Removed defintion of _LARGEFILE64_SOURCE, now using _FILE_OFFSET_BITS=64.
--- Also removed using O_LARGEFILE from open call.
---
--- Revision 1.4  2007/07/01 19:44:11  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.3  2007/02/11 15:15:20  jsedwards
--- Change 'sprintf' calls to 'snprintf' calls so the OpenBSD linker will stop
--- whining.
---
--- Revision 1.2  2007/02/11 14:41:26  jsedwards
--- Change all 'off64_t' and 'lseek64' references to 'off_t' and 'lseek',
--- because BSD doesn't dig the whole brain damaged 64 bit thing.
---
--- Revision 1.1  2006/12/02 17:30:54  jsedwards
--- Compare a compressed file with the disk (can only do same / different at
--- this time).
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
