@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2006-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--               Copyright (C) 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,33 +17,34 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: disc.c,v $
--- Revision 1.5  2009/07/19 13:48:32  jsedwards
--- Moved one of the endifs added in previous check in so that it enclosed the
--- free that went along with the malloc.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file and the file.c file which these
+--   functions were taken from.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
--- Revision 1.4  2009/07/19 12:43:54  jsedwards
--- Added ifdef VERIFY_WRITE around code that reads back objects to verify they
--- were written correctly, they don't work correctly when nwos_write_block
--- modifies the upper 4 bytes of the reference in the block.
---
--- Revision 1.3  2009/03/13 12:21:34  jsedwards
--- Added include of strlcxx.h file.
---
--- Revision 1.2  2009/03/08 00:13:54  jsedwards
--- Changed include objectify_private.h to objectify.h.
---
--- Revision 1.1  2009/01/31 11:53:34  jsedwards
--- Moved functions related to disc_lists and logging from file.c.
---
--- For revisions to this code prior to 2009/01/31 see the file.c file.
 */
 
 #include <assert.h>
