@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2006-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--               Copyright (C) 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,168 +17,33 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: disc_list.c,v $
--- Revision 1.37  2009/07/19 12:51:18  jsedwards
--- Added ifdef VERIFY_WRITE around code that reads back objects to verify they
--- were written correctly, they don't work correctly when nwos_write_block
--- modifies the upper 4 bytes of the reference in the block.
---
--- Revision 1.36  2009/06/13 11:37:25  jsedwards
--- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
---
--- Revision 1.35.2.1  2009/06/06 13:41:22  jsedwards
--- Fix Bug #2740516 - Added new get_disc_id function that calls fgets and
--- checks return value.
---
--- Revision 1.35  2009/03/19 11:38:21  jsedwards
--- Wrapped call to nwos_set_security_level with ifdef CHANGE_SECURITY_TO_DENSITY
--- because what was called security level stuff is temporarily disabled.
---
--- Revision 1.34  2009/03/14 03:31:24  jsedwards
--- Added include of bit_map.h file.
---
--- Revision 1.33  2009/03/10 04:04:08  jsedwards
--- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
---
--- Revision 1.32  2009/03/08 00:13:54  jsedwards
--- Changed include objectify_private.h to objectify.h.
---
--- Revision 1.31  2008/09/01 03:13:41  jsedwards
--- Change for new nwos_initialize_objectify calling convention (doesn't pass
--- back root_object_reference anymore) and removed call to nwos_set_root_object
--- because initialize calls it now.
---
--- Revision 1.30  2008/08/31 21:53:51  jsedwards
--- Added an assert around calls to nwos_read_variable_sized_object_from_disk
--- and nwos_read_object_from_disk because now they return false when they fail
--- instead of asserting themselves.
---
--- Revision 1.29  2008/08/30 12:46:08  jsedwards
--- Removed code and variables to read pass phrase and pass it to initialize,
--- and change parameters passed to initialize.
---
--- Revision 1.28  2008/08/03 17:31:34  jsedwards
--- Add --ignore-empty-directories and --ignore-empty-files options.
---
--- Revision 1.27  2008/08/03 15:44:36  jsedwards
--- Changed to handle new error values returned by nwos_read_files_disc_list.
---
--- Revision 1.26  2008/07/26 15:09:02  jsedwards
--- Changed to use returned value from nwos_read_files_disc_list for exit code
--- if it fails.
---
--- Revision 1.25  2008/07/24 16:40:00  jsedwards
--- Moved read_file_names function to file.c and rename to
--- nwos_read_files_disc_list.
---
--- Revision 1.24  2008/07/24 14:20:59  jsedwards
--- Change to read subdirectories recursively.
---
--- Revision 1.23  2008/07/24 11:25:18  jsedwards
--- Move code that scans for all file names out of "main" and into new function
--- "read_file_names".  Also moved "num_files", "file_names" and "files"
--- variables out of "main" and made global to this file.
---
--- Revision 1.22  2008/05/22 10:04:55  jsedwards
--- Fix Bug #1954154 - Changed so that revised file links are in the PATH AND
--- FILE ASSOCIATION objects instead of the FILE objects.
---
--- Revision 1.21  2008/03/30 13:38:45  jsedwards
--- Moved code to get disc ID before checking public files as well.
---
--- Revision 1.20  2008/03/30 13:07:41  jsedwards
--- Move code to check public files out of the initial directory scan loop and
--- into it's own loop.  This way we can get the pass phrase first instead of
--- having a delay while it reads public files and then asking for the pass
--- phrase.
---
--- Revision 1.19  2008/03/21 14:48:22  jsedwards
--- Added code to check for public files.
---
--- Revision 1.18  2008/02/03 01:06:30  jsedwards
--- Changed DEFAULT_TYPE_RW to READ_WRITE.
---
--- Revision 1.17  2007/12/24 02:20:53  jsedwards
--- Added --add-revision option to connect any new files with any existing files.
---
--- Revision 1.16  2007/12/23 18:23:25  jsedwards
--- Added terminate_objectify call before exiting in disc already exists case.
---
--- Revision 1.15  2007/10/07 03:43:50  jsedwards
--- Renamed 'nwos_set_block_estimate' to 'nwos_check_blocks_available' and
--- changed to exit gracefully if not enough space available.
---
--- Revision 1.14  2007/09/02 19:47:25  jsedwards
--- Added call to set the block estimate.
---
--- Revision 1.13  2007/08/12 20:45:00  jsedwards
--- Change all of the "Encryption Level" stuff to "Security Level" because it
--- doesn't really change the encryption at all, all it does is change the
--- randomization of where objects are stored.
---
--- Revision 1.12  2007/07/01 19:44:11  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.11  2007/06/13 21:15:03  jsedwards
--- Comment out debugging print statement accidentally left in.
---
--- Revision 1.10  2007/06/13 20:51:39  jsedwards
--- Added code to free memory used for file names.
---
--- Revision 1.9  2007/06/13 20:13:54  jsedwards
--- Change to take a directory as a parameter instead of a list of files.
---
--- Revision 1.8  2007/02/11 16:58:26  jsedwards
--- Changed so DEFAULT_TYPE has to specify RO (Read-Only) or RW (Read-Write).
---
--- Revision 1.7  2007/01/20 13:07:26  jsedwards
--- Print blank line after entering pass phrase and move log_arguments call.
---
--- Revision 1.6  2007/01/07 20:31:55  jsedwards
--- Added call to log arguments.
---
--- Revision 1.5  2007/01/07 03:26:19  jsedwards
--- Changed default encryption level to 'Very_Low' instead of 'Low'.
---
--- Revision 1.4  2007/01/04 17:39:14  jsedwards
--- Add code to set encryption level (always "Low" for now).
---
--- Revision 1.3  2006/12/07 14:10:25  jsedwards
--- Removed call to file_setup, no longer needed.
---
--- Revision 1.2  2006/12/02 17:26:09  jsedwards
--- Changed to deal with file paths that can point to different files.
---
--- Revision 1.1  2006/11/19 13:53:12  jsedwards
--- Created "disc_list.c" from "log_disc.c".  This program just creates a disc
--- list and does not create a disc copy object.
---
--- Revision 1.6  2006/11/18 14:34:58  jsedwards
--- Changed so that discs can be stored in one of three different binders.
---
--- Revision 1.5  2006/11/11 12:01:04  jsedwards
--- Update e-mail address to something that works.
---
--- Revision 1.4  2006/11/07 14:03:35  jsedwards
--- Add assert to verify file_path didn't come back void.
---
--- Revision 1.3  2006/11/06 13:54:07  jsedwards
--- Changed wording in print statement because disc_list now stores the
--- references to the file_path object instead of the file object.
---
--- Revision 1.2  2006/11/05 21:32:18  jsedwards
--- Add code to create storage_location and disc_copy objects.
---
--- Revision 1.1  2006/11/04 18:56:22  jsedwards
--- Program to scan all the files on a CD or DVD and make a disk_list object
--- of it.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revisions of this file and the log_disc.c file which this file
+--   was created from.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
