@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2004-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--            Copyright (C) 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,56 +17,34 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-31 05:54:03 -0600 (Fri, 31 Jul 2009) $
+--   $Revision: 4214 $
 --
--- $Log: disk_io.h,v $
--- Revision 1.11  2009/03/14 22:33:49  jsedwards
--- Moved backup and chunk_info related declarations to new backup.h and
--- chunk_info.h files.  Removed old declarations that don't exist anymore.
---
--- Revision 1.10  2009/03/14 15:33:48  jsedwards
--- Moved some declarations to the security.h, security.c and objectify.c files
--- and deleted some that are now static.
---
--- Revision 1.9  2009/03/14 11:11:10  jsedwards
--- Moved all of the id generation related declarations to gen_id.h file.
---
--- Revision 1.8  2009/03/14 03:11:15  jsedwards
--- Moved nwos_set_bit_in_map, nwos_clear_bit_in_map, nwos_test_bit_in_map,
--- nwos_find_random_block_in_chunk, nwos_find_low_density_in_chunk,
--- nwos_find_next_empty_block, nwos_terminate_bit_map, and nwos_block_used
--- to new bit_map.h file.
---
--- Revision 1.7  2009/03/13 03:49:48  jsedwards
--- Deleted include of objectify.h, moved reference_list related declarations
--- to reference_list.h, added external declaration for nwos_erase_block, and
--- moved MAGIC_NUMBER define from objectify.h.
---
--- Revision 1.6  2009/03/10 11:54:51  jsedwards
--- Moved nwos_private_create_city, nwos_create_url, and
--- nwos_create_public_manufacturer to the objectify.h file.
---
--- Revision 1.5  2009/03/10 09:42:37  jsedwards
--- Moved FILE_BLOCK_SIZE from the objectify.h file.
---
--- Revision 1.4  2009/03/09 00:56:00  jsedwards
--- Added external declarations for nwos_initialize_gen_id and
--- nwos_terminate_gen_id.
---
--- Revision 1.3  2009/03/08 01:56:45  jsedwards
--- Moved class definition related declarations to class_definition.h file and
--- object related definitions to objectify.h file.
---
--- Revision 1.2  2009/03/07 13:46:15  jsedwards
--- Fixed #ifndef and #define tag.
---
--- Revision 1.1  2009/03/07 13:41:25  jsedwards
--- Renamed objectify_private.h to disk_io.h.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revisions of this file.  Since this file was originally named
+--   objectify_private.h, I left the part of the log from when it was called
+--   objectify_private.h below to make it easier to access.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 -- Revision 1.87  2009/03/06 04:38:17  jsedwards
 -- Added external declarations for nwos_write_bit_map, nwos_read_bit_map,
@@ -139,6 +115,21 @@
 -- Remove duplicate declaration of nwos_read_object_from_disk which is
 -- declared in objectify.h.
 --
+-- Revision 1.69.2.3  2008/08/13 03:46:38  jsedwards
+-- Changed USABLE_BLOCKS_PER_CHUNK to the full 65536 and BLOCKS_IN_CHUNK to
+-- USABLE_BLOCKS_PER_CHUNK plus BIT_MAP_BLOCKS (65568).  Also changed disk
+-- header to have total_chunks instead of total_blocks, it is easier to deal
+-- with.
+--
+-- Revision 1.69.2.2  2008/08/12 11:17:42  jsedwards
+-- Removed BIT_MAP_BLOCK_MASK because it was not used anywhere and it is not
+-- compatible with the new 16 megabyte chunks.
+--
+-- Revision 1.69.2.1  2008/08/11 13:17:44  jsedwards
+-- Changed "uint16 used" member of Chunk_Info to "uint32 flags_used" and added
+-- "sha1_digest" member to store chunk checksum.  Also added CHUNK_INFO_USED_MASK
+-- and CHUNK_INFO_FULL_MASK defines to mask off used count in "flags_used".
+--
 -- Revision 1.69  2008/07/31 14:01:56  jsedwards
 -- Added external declaration for nwos_read_object_from_disk_and_old_decrypt.
 --
@@ -424,123 +415,18 @@
 #ifndef DISK_IO_H
 #define DISK_IO_H
 
-#include "reference.h"
 #include "time_stamp.h"
-
-#define MAGIC_NUMBER "NWOS"
+#include "types.h"
 
 
-#define RESERVED_PUBLIC_BLOCKS    0x10000000    /* IDs 0x00000000 to 0x0fffffff reserved */
-#define RESERVED_PRIVATE_BLOCKS   0xeff00000    /* IDs 0x10000000 to 0xfff00000 reserved */
-#define RESERVED_TEMPORARY_BLOCKS 0x00100000    /* IDs 0xfff00000 to 0xffffffff reserved */
-
-#define FILE_BLOCK_SIZE 256
-
-#define BIT_MAP_BLOCKS 32
-#define BIT_MAP_BYTES (BIT_MAP_BLOCKS * FILE_BLOCK_SIZE)
-
-#define BLOCKS_IN_CHUNK (BIT_MAP_BYTES * 8)
-#define BIT_MAP_BLOCK_MASK (~(BLOCKS_IN_CHUNK-1))
-#define USABLE_BLOCKS_PER_CHUNK (BLOCKS_IN_CHUNK - BIT_MAP_BLOCKS)   /* 65536 - 32 = 65504 */
+typedef enum { Public_Archive = 0x50756241, Private_Archive = 0x50726941 } Archive_Type;
 
 
-/* some blocks don't come out even when dividing usable chunks per block, so don't allocate them */
-
-#define RESERVED_PRIVATE_CHUNKS (RESERVED_PRIVATE_BLOCKS / USABLE_BLOCKS_PER_CHUNK)
-/*                              (0xeff00000              / 65504)    = 61454 */
-
-#define MAXIMUM_PUBLIC_REFERENCE   (RESERVED_PUBLIC_BLOCKS - 1)
-
-#define MINIMUM_PRIVATE_REFERENCE  RESERVED_PUBLIC_BLOCKS
-
-// USE THIS in Alpha_30:
-// #define MAXIMUM_PRIVATE_REFERENCE (RESERVED_PUBLIC_BLOCKS + RESERVED_PRIVATE_BLOCKS - 1)
-/*                                                0x10000000 + 0xeff00000 - 1   = 0xffefffff */
-
-// THIS IS ONLY FOR Alpha_29
-#define MAXIMUM_PRIVATE_REFERENCE (RESERVED_PUBLIC_BLOCKS + (RESERVED_PRIVATE_CHUNKS * USABLE_BLOCKS_PER_CHUNK) - 1) /* 0xffeffe40 */
-
-#define MINIMUM_TEMPORARY_REFERENCE (RESERVED_PUBLIC_BLOCKS + RESERVED_PRIVATE_BLOCKS)
-#define MAXIMUM_TEMPORARY_REFERENCE (RESERVED_PUBLIC_BLOCKS + RESERVED_PRIVATE_BLOCKS + (RESERVED_TEMPORARY_BLOCKS - 1))
-
-#define CHUNK_SIZE (BLOCKS_IN_CHUNK * FILE_BLOCK_SIZE)
+extern int  nwos_verbosity_level;
 
 
-typedef struct {
-    char magic_number[4];
-    char version_string[4];
-    TimeStamp last_prep_disk;
-
-    uint8 total_blocks[4];
-    uint8 used_blocks[4];
-    TimeStamp last_change;
-
-    uint8 block_offset_to_chunks[4];
-    uint8 used_chunks[4];
-    uint8 unused7[4];
-    uint8 unused8[4];
-} Disk_Header;
-
-typedef struct {
-    char magic_number[4];
-    char version_string[4];
-    TimeStamp last_prep_disk;
-
-    uint8 total_public_blocks[4];
-    uint8 used_public_blocks[4];
-    TimeStamp public_last_change;
-
-    uint8 total_private_blocks[4];
-    uint8 used_private_blocks[4];
-    TimeStamp private_last_change;
-
-    uint8 unused5[4];
-    uint8 next_private_chunk[4];
-    uint8 unused6[4];
-    uint8 unused7[4];
-} Disk_Header_0021;
-
-typedef struct {
-    char magic_number[4];
-    char version_string[4];
-    TimeStamp time_last_change;
-
-    uint8 total_public_blocks[4];
-    uint8 total_private_blocks[4];
-    uint8 unused1[4];
-    uint8 unused2[4];
-
-    uint8 used_public_blocks[4];
-    uint8 used_private_blocks[4];
-    uint8 unused3[4];
-    uint8 unused4[4];
-
-    uint8 unused5[4];
-    uint8 next_private_chunk[4];
-    uint8 unused6[4];
-    uint8 unused7[4];
-} Disk_Header_0016_to_0020;
-
-extern Disk_Header nwos_disk_header;
-
-extern uint32 nwos_total_public_blocks;
-extern uint32 nwos_total_private_blocks;
-extern uint32 nwos_used_public_blocks;
-extern uint32 nwos_used_private_blocks;
-
-extern uint32 nwos_total_private_chunks;
-extern uint32 nwos_used_private_chunks;
-extern uint32 nwos_block_offset_to_chunks;
-
-
-extern bool verbose;
-
-extern bool nwos_ready;
-
-
-extern bool nwos_read_block(ObjRef* ref, uint8 block[FILE_BLOCK_SIZE]);
-extern void nwos_write_block(ObjRef* ref, uint8 block[FILE_BLOCK_SIZE]);
-extern void nwos_erase_block(ObjRef* ref);
+extern bool nwos_read_block_from_offset(Archive_Type archive, int64 offset, uint8 block[FILE_BLOCK_SIZE]);
+extern bool nwos_write_block_to_offset(Archive_Type archive, int64 offset, uint8 block[FILE_BLOCK_SIZE]);
 
 extern const char* nwos_public_path;
 extern const char* nwos_private_path;
@@ -548,12 +434,25 @@ extern const char* nwos_private_path;
 extern void  nwos_initialize_disk_io(AccessType type, const char* path);
 extern bool  nwos_disk_io_is_read_only();
 extern bool  nwos_disk_io_is_read_write();
+extern bool  nwos_disk_io_is_public_only();
+extern bool  nwos_disk_io_is_compressed_file(void);
+extern bool  nwos_disk_has_been_modified(void);
 extern bool  nwos_archive_is_block_device(void);
 extern bool  nwos_archive_is_file(void);
 extern void  nwos_write_bit_map(int chunk_index, void* map);
 extern void  nwos_read_bit_map(int chunk_index, void* map);
+extern void  nwos_read_chunk_info(void* chunk_info, size_t chunk_info_size_in_bytes);
+extern void  nwos_write_chunk_info(void* chunk_info, size_t chunk_info_size_in_bytes);
 extern void  nwos_write_empty_chunk();
 extern void  nwos_terminate_disk_io();
 
+
+/* These are only here temorarily until the index junk can be eliminated */
+
+#include "reference.h"
+
+extern ObjRef* nwos_storage_index;
+extern int     nwos_storage_count;
+
 #endif
 
