@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2005-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--            Copyright (C) 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,99 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: dump_obj.c,v $
--- Revision 1.23  2009/03/14 19:14:21  jsedwards
--- Added include of security.h file, renamed read_object_and_decrypt functions
--- to read_block_and_decrypt, and changed parameters to just pass sequence
--- number.
---
--- Revision 1.22  2009/03/13 12:31:18  jsedwards
--- Added include of objectify.h file and added comment about needing disk_io.h
--- just for IVEC_SIZE.
---
--- Revision 1.21  2009/03/08 00:06:18  jsedwards
--- Changed include objectify_private.h to disk_io.h.
---
--- Revision 1.20  2008/09/01 03:13:41  jsedwards
--- Change for new nwos_initialize_objectify calling convention (doesn't pass
--- back root_object_reference anymore) and removed call to nwos_set_root_object
--- because initialize calls it now.
---
--- Revision 1.19  2008/08/31 17:58:26  jsedwards
--- Add assert around call to nwos_read_object_from_disk because it now returns
--- false when it fails, whereas before it would assert itself.
---
--- Revision 1.18  2008/08/30 12:46:09  jsedwards
--- Removed code and variables to read pass phrase and pass it to initialize,
--- and change parameters passed to initialize.
---
--- Revision 1.17  2008/08/02 11:02:24  jsedwards
--- Added call to log arguments to disable logging and fixed typo in print
--- statement text.
---
--- Revision 1.16  2008/08/01 14:36:54  jsedwards
--- Added code to print class name and to dump object data in hex.
---
--- Revision 1.15  2008/08/01 00:35:04  jsedwards
--- Changed to try old decryption algorithm if checksum fails after reading
--- with new decryption algorithm.
---
--- Revision 1.14  2008/07/19 14:19:29  jsedwards
--- Removed some unused variables.
---
--- Revision 1.13  2008/07/19 10:58:05  jsedwards
--- Added printing of header and object checksums.
---
--- Revision 1.12  2008/07/15 13:21:34  jsedwards
--- Added code to allow dumping object from compressed file, changed to use
--- strtoul instead of strtol for converting reference id, and added new line
--- character to usage.
---
--- Revision 1.11  2008/07/15 12:45:19  jsedwards
--- Updated to work with current version, was at version 0004 - 29-Dec-2005.
---
--- Revision 1.10  2007/07/13 21:04:32  jsedwards
--- Change HEADER_VERSION (which wasn't used anywhere else) to VERSION_STRING
--- which is defined in objectify.h.
---
--- Revision 1.9  2007/07/01 19:44:11  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.8  2006/12/01 14:37:23  jsedwards
--- Fix the year in the copyright.
---
--- Revision 1.7  2006/11/11 12:01:03  jsedwards
--- Update e-mail address to something that works.
---
--- Revision 1.6  2006/10/26 01:51:26  jsedwards
--- Merged alpha_05_branch back into main trunk.
---
--- Revision 1.5.2.1  2006/10/25 12:22:28  jsedwards
--- Changed C_struct_class_definition to C_struct_Class_Definition so the case
--- is consistent with all the other C_struct objects.
---
--- Revision 1.5  2005/12/29 14:33:14  jsedwards
--- Updated to work with version Alpha_04 (0004) WITHOUT encryption turned on!
---
--- Revision 1.4  2005/12/24 16:18:26  jsedwards
--- Removed "host" id from object references (ObjRef).  Host redirection will
--- be done using a "redirection" object in the future.
---
--- Revision 1.3  2005/12/10 15:03:36  jsedwards
--- Fixed header to say the GPL is in the LICENSE file instead of COPYING.
---
--- Revision 1.2  2005/12/02 14:12:09  jsedwards
--- Modified for new header layouts.
---
--- Revision 1.1.1.1  2005/11/25 12:44:27  jsedwards
--- Copied from 'lab'.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
