@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2006-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--               Copyright (C) 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,132 +17,33 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: export_file.c,v $
--- Revision 1.25  2009/01/26 16:25:53  jsedwards
--- Changed boolean result to count the number of failures and report it at the
--- end.  Also use the number of failures as the exit code instead of just 1.
---
--- Revision 1.24  2008/12/27 15:00:29  jsedwards
--- Merged from alpha_29_5_branch back into main trunk.
---
--- Revision 1.23.2.2  2008/12/21 14:12:52  jsedwards
--- Changed to exit with code 1 when export_file subroutine fails.
---
--- Revision 1.23.2.1  2008/12/17 03:29:41  jsedwards
--- Changed to exit with failure status when file doesn't exist.
---
--- Revision 1.23  2008/09/01 03:13:42  jsedwards
--- Change for new nwos_initialize_objectify calling convention (doesn't pass
--- back root_object_reference anymore) and removed call to nwos_set_root_object
--- because initialize calls it now.
---
--- Revision 1.22  2008/08/31 21:53:52  jsedwards
--- Added an assert around calls to nwos_read_variable_sized_object_from_disk
--- and nwos_read_object_from_disk because now they return false when they fail
--- instead of asserting themselves.
---
--- Revision 1.21  2008/08/30 12:46:10  jsedwards
--- Removed code and variables to read pass phrase and pass it to initialize,
--- and change parameters passed to initialize.
---
--- Revision 1.20  2008/06/05 11:04:14  jsedwards
--- Fixed to find the latest version of the path and file association object.
---
--- Revision 1.19  2008/03/09 15:41:12  jsedwards
--- Added code to create subdirectories if they don't exist.  (File changed on
--- laptop on 2008/02/29 in Columbia, South Carolina but could not check in
--- because didn't have Internet access).
---
--- Revision 1.18  2008/02/03 01:04:28  jsedwards
--- Changed DEFAULT_TYPE_RO to READ_ONLY and changed path variable to const char
--- instead of char.
---
--- Revision 1.17  2007/09/18 01:22:29  jsedwards
--- Rearrange the order of testing for an old (depreciated) file name, so that
--- it is only done if the file name matches.  That way the association object
--- only has to be read if we have found a match instead of for every single
--- file.
---
--- Revision 1.16  2007/08/26 18:41:26  jsedwards
--- Added code so that if an old (renamed) file name is specifically given it
--- will be exported, but old (renamed) file names will not match a wild card
--- search.
---
--- Revision 1.15  2007/08/23 13:50:22  jsedwards
--- Added file name globbing.
---
--- Revision 1.14  2007/07/24 17:27:09  jsedwards
--- Modified to deal with files that have more than one revision.
---
--- Revision 1.13  2007/07/01 19:44:11  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.12  2007/02/11 16:58:26  jsedwards
--- Changed so DEFAULT_TYPE has to specify RO (Read-Only) or RW (Read-Write).
---
--- Revision 1.11  2007/01/14 17:17:48  jsedwards
--- Changed to use path_and_file_association objects instead of file objects.
---
--- Revision 1.10  2007/01/07 20:31:55  jsedwards
--- Added call to log arguments.
---
--- Revision 1.9  2007/01/07 14:18:10  jsedwards
--- Changed so that file_path_to_file has to succeed before reading the file
--- (before it ignored the return value of file_path_to_file because it always
--- returned true).
---
--- Revision 1.8  2006/12/21 12:59:47  jsedwards
--- Hack to make it compile with new split public and private classes,
--- NON-FUNCTIONAL!
---
--- Revision 1.7  2006/12/01 14:31:30  jsedwards
--- Changed to use new malloc_reference_list and free_reference_list functions
--- instead of inlining the code.
---
--- Revision 1.6  2006/11/29 19:03:45  jsedwards
--- Added code to handle the case where the requested file is not stored in
--- the system.
---
--- Revision 1.5  2006/11/29 18:52:04  jsedwards
--- Change so that this function finds the file reference and passes it along
--- with the path to the restore_file function.
---
--- Revision 1.4  2006/11/18 15:09:09  jsedwards
--- Added "max_size" parameter to read_variable_sized_object_from_disk because
--- objects are no longer limited to one file block.
---
--- Revision 1.3  2006/11/11 12:01:03  jsedwards
--- Update e-mail address to something that works.
---
--- Revision 1.2  2006/10/26 01:51:26  jsedwards
--- Merged alpha_05_branch back into main trunk.
---
--- Revision 1.1.2.5  2006/10/25 12:22:28  jsedwards
--- Changed C_struct_class_definition to C_struct_Class_Definition so the case
--- is consistent with all the other C_struct objects.
---
--- Revision 1.1.2.4  2006/10/07 12:35:41  jsedwards
--- Changed to allow an '*' to specify exporting all files.
---
--- Revision 1.1.2.3  2006/10/03 12:53:07  jsedwards
--- Changed so that instead of calling a separate routine after initialize to
--- change the already opened storage, you call it now with a type of storage
--- parameter and a path to the storage.  The problem with the other way was
--- if you tried reading a compressed file on another machine it tried to open
--- the default file which didn't exist.
---
--- Revision 1.1.2.2  2006/10/02 02:27:03  jsedwards
--- Added option to read the file from a compressed archive file.
---
--- Revision 1.1.2.1  2006/09/18 01:45:12  jsedwards
--- Program to export a file stored in objectify.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.  Also this file was created in the
+--   alpha_05_branch so check the logs for this file in it too.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
@@ -262,7 +161,7 @@ int main(int argc, char* argv[])
     C_struct_Class_Definition class_def_obj;
     C_struct_Path_And_File_Association assoc_obj;
     C_struct_Path_And_File_Association next_assoc_obj;
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_PATH_OBJ_SIZE];
     C_struct_File_Path* ptr_path_obj = (C_struct_File_Path*)kludge;
     int argn;
     int i;
@@ -395,7 +294,7 @@ int main(int argc, char* argv[])
 	}
     }
 
-    printf("Number of files expored: %d\n", num_files);
+    printf("Number of files exported: %d\n", num_files);
     printf("Number of files failed: %d\n", num_failures);
 
     nwos_free_reference_list(ref_list);
