@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2007-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                  Copyright (C) 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,64 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: financial.c,v $
--- Revision 1.13  2009/07/19 13:41:22  jsedwards
--- Added ifdef VERIFY_WRITE around more code that reads back objects to verify
--- they were written correctly, they don't work correctly when nwos_write_block
--- modifies the upper 4 bytes of the reference in the block.
---
--- Revision 1.12  2009/07/19 13:21:44  jsedwards
--- Added ifdef VERIFY_WRITE around code that reads back objects to verify they
--- were written correctly, they don't work correctly when nwos_write_block
--- modifies the upper 4 bytes of the reference in the block.
---
--- Revision 1.11  2009/06/13 11:37:25  jsedwards
--- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
---
--- Revision 1.10.2.1  2009/06/06 14:03:54  jsedwards
--- Moved get_input function to new dialog.c file, renamed it to nwos_ask_user,
--- and changed to call it.
---
--- Revision 1.10  2009/03/10 11:19:00  jsedwards
--- Moved MAX_NUMBER_SIZE, MAX_ID_SIZE, MAX_ACCOUNT_NUMBER_SIZE, and
--- MAX_CHECKING_SIZE to the objectify.h file and renamed.
---
--- Revision 1.9  2009/03/09 14:12:35  jsedwards
--- Eliminated use of FILE_BLOCK_SIZE for kludge buffers.
---
--- Revision 1.8  2009/03/08 00:50:30  jsedwards
--- Changed include objectify_private.h to objectify.h and changed to call
--- nwos_generate_new_id instead of nwos_generate_new_completely_random_id.
---
--- Revision 1.7  2008/09/01 00:10:51  jsedwards
--- Fix copyright year.  NO code changes.
---
--- Revision 1.6  2008/08/31 21:53:52  jsedwards
--- Added an assert around calls to nwos_read_variable_sized_object_from_disk
--- and nwos_read_object_from_disk because now they return false when they fail
--- instead of asserting themselves.
---
--- Revision 1.5  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.4  2007/05/24 11:48:45  jsedwards
--- Add acronym to credit union.
---
--- Revision 1.3  2007/05/06 17:20:36  jsedwards
--- Add 'list_accounts' function.
---
--- Revision 1.2  2007/05/06 16:37:28  jsedwards
--- Added all the code to create checking accounts.
---
--- Revision 1.1  2007/04/22 15:16:23  jsedwards
--- Initial version created from person.c.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
