@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2005-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--               Copyright (C) 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,150 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: gen_id.c,v $
--- Revision 1.28  2009/07/18 02:16:38  jsedwards
--- Changed functions that reference the chunk_info.ref to 64 bit values.
---
--- Revision 1.27  2009/07/12 01:24:00  jsedwards
--- Changed total blocks from uint32 to uint64, deleted assert that checked
--- total chunks and total blocks correlated, and fixed print statements.
---
--- Revision 1.26  2009/06/13 15:35:22  jsedwards
--- Changed to call new chunk_is_full and blocks_used_in_chunk functions instead
--- of accessing chunk_info directly.
---
--- Revision 1.25  2009/06/13 13:00:20  jsedwards
--- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
---
--- Revision 1.18.2.6  2009/06/09 12:39:19  jsedwards
--- Changed to only create a new chunk island at random.
---
--- Revision 1.18.2.5  2009/06/09 10:59:20  jsedwards
--- Renamed find_new_chunk_location function to find_new_random_chunk_location
--- and made static.
---
--- Revision 1.18.2.4  2009/06/09 02:38:01  jsedwards
--- Fix Bug #2803265 - changed to always allow two chunks, even for small files.
---
--- Revision 1.18.2.3  2009/06/07 22:30:33  jsedwards
--- Fix Bug #2734284 - changed to only print warning about non-contiguous chunks
--- if archive is disk and no more chunks are available, otherwise it allocates
--- all new chunks.
---
--- Revision 1.18.2.2  2009/06/06 19:45:31  jsedwards
--- Add a hack so that it doesn't create the private class definition object and
--- it's associated reference list object at the first two locations in the chunk.
---
--- Revision 1.18.2.1  2009/05/18 12:28:15  jsedwards
--- Fixed to compile correctly in PUBLIC MODE.
---
--- Revision 1.24  2009/05/09 16:50:09  jsedwards
--- Changed to call new nwos_blocks_used_in_chunk and nwos_chunk_is_full
--- functions instead of accessing chunk_info table directly.
---
--- Revision 1.23  2009/04/19 09:04:23  jsedwards
--- Moved nwos_hash_uint32_ref, nwos_hash_ref, and nwos_ref_to_offset functions
--- to chunk_info.c file.
---
--- Revision 1.22  2009/04/13 12:51:13  jsedwards
--- Moved nwos_read_block, nwos_write_block, and nwos_erase_block functions to
--- new storage.c file.
---
--- Revision 1.21  2009/04/12 00:40:06  jsedwards
--- Moved the nwos_read_block, nwos_write_block, and nwos_erase_block functions
--- from the disk_io.c file.
---
--- Revision 1.20  2009/04/11 21:20:10  jsedwards
--- Moved the RESERVED_PRIVATE_CHUNKS define (which currently isn't used) from
--- the disk_io.h file.
---
--- Revision 1.19  2009/04/07 14:51:38  jsedwards
--- Merged in changes from disk_io.c file in CVS
--- branch_0030_new_chunk_info branch, see revision 1.89.2.1 in disk_io.c file.
---
--- Revision 1.18  2009/04/04 13:18:11  jsedwards
--- Moved code from nwos_check_blocks_available and created new
--- find_starting_chunk_for_blocks function and then called it in several
--- places to always try to start the ID generation in a good place.
---
--- Revision 1.17  2009/04/03 14:43:32  jsedwards
--- Changed to search for available space before allocating chunks.
---
--- Revision 1.16  2009/04/02 13:00:33  jsedwards
--- Changed to always keep 1/2 chunk extra allocated.
---
--- Revision 1.15  2009/04/01 15:28:36  jsedwards
--- Moved initial setting of last_ref to check_blocks_available instead of
--- doing it the first time generate_new_private_id is called.
---
--- Revision 1.14  2009/04/01 14:12:35  jsedwards
--- Fixed check blocks to only set block_estimate global variable if it is
--- returning true, so it won't log results the next time if it fails.  Also
--- deleted unused code in generate new private id function.
---
--- Revision 1.13  2009/03/31 02:27:06  jsedwards
--- Change to allocate first available block from the first chunk with blocks
--- available and allocate each available block from there.
---
--- Revision 1.12  2009/03/19 11:19:26  jsedwards
--- Wrapped all of the stuff related to generating ids based upon the security
--- level with ifdef CHANGE_SECURITY_TO_DENSITY to disable it and changed to
--- just allocate based upon the next available id in sequence.
---
--- Revision 1.11  2009/03/18 13:33:23  jsedwards
--- Moved nwos_restart_id_generation earlier in file so it preceeds the calls
--- to it.  Made nwos_generate_new_completely_random_id,
--- nwos_generate_new_closely_spaced_id, and nwos_generate_new_1_in_N_id static.
---
--- Revision 1.10  2009/03/18 13:12:00  jsedwards
--- Moved nwos_set_allocation parameters earlier in file so it preceeds calls
--- to it and made it static.
---
--- Revision 1.9  2009/03/14 22:59:40  jsedwards
--- Added include of new chunk_info.h file and moved nwos_next_public_ref from
--- the disk_io.c file.
---
--- Revision 1.8  2009/03/14 19:10:25  jsedwards
--- Moved randomxxx variable from objectify.c file.
---
--- Revision 1.7  2009/03/14 03:31:24  jsedwards
--- Added include of bit_map.h file.
---
--- Revision 1.6  2009/03/13 12:43:22  jsedwards
--- Added includes for new gen_id.h and log.h files.
---
--- Revision 1.5  2009/03/09 01:13:28  jsedwards
--- Moved block_estimate, last_used_blocks, last_ref, chunk_density_target,
--- chunk_skip_forward, log_estimate_results variables and
--- initialize_random_number_generator, generate_new_completely_random_id
--- nwos_generate_new_completely_random_id, nwos_restart_id_generation
--- nwos_set_allocation_parameters, nwos_check_blocks_available
--- nwos_generate_new_closely_spaced_id, nwos_generate_new_1_in_N_id
--- nwos_generate_new_public_id functions from disk_io.c file.  Renamed
--- initialize_random_number_generator to nwos_initialize_gen_id and created
--- new nwos_terminate_gen_id function.
---
--- Revision 1.4  2009/03/08 00:06:18  jsedwards
--- Changed include objectify_private.h to disk_io.h.
---
--- Revision 1.3  2009/03/04 15:27:40  jsedwards
--- Moved nwos_hash_uint32_ref, nwos_hash_ref, and nwos_ref_to_offset functions
--- from the disk_io.c file.
---
--- Revision 1.2  2009/02/25 14:51:15  jsedwards
--- Removed skip_backward parameter from calls to nwos_set_allocation_parameters
--- because it wasn't used.
---
--- Revision 1.1  2009/02/23 14:59:04  jsedwards
--- Initial version created with nwos_set_security_level and nwos_generate_new_id
--- functions taken from objectify.c.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revisions of this file and the objectify.c file which this file
+--   was taken from.  (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
