@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2006-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--               Copyright (C) 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,54 +17,33 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: identify_disc.c,v $
--- Revision 1.11  2009/03/13 12:21:34  jsedwards
--- Added include of strlcxx.h file.
---
--- Revision 1.10  2008/12/27 15:00:29  jsedwards
--- Merged from alpha_29_5_branch back into main trunk.
---
--- Revision 1.9.2.1  2008/12/23 11:03:15  jsedwards
--- Changed to use strlcpy instead of strcpy.
---
--- Revision 1.9  2008/09/01 03:13:42  jsedwards
--- Change for new nwos_initialize_objectify calling convention (doesn't pass
--- back root_object_reference anymore) and removed call to nwos_set_root_object
--- because initialize calls it now.
---
--- Revision 1.8  2008/08/31 21:17:33  jsedwards
--- Added assert around call to nwos_read_variable_sized_object_from_disk
--- because it now returns false when it fails instead of asserting itself.
---
--- Revision 1.7  2008/08/30 12:46:11  jsedwards
--- Removed code and variables to read pass phrase and pass it to initialize,
--- and change parameters passed to initialize.
---
--- Revision 1.6  2008/02/03 17:31:30  jsedwards
--- Changed #include "objectify_private.h" back to "objectify.h" because the
--- change to "objectify_private.h" was accidentally left in last check in.
---
--- Revision 1.5  2008/02/03 01:05:23  jsedwards
--- Changed DEFAULT_TYPE_RO to READ_ONLY.
---
--- Revision 1.4  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.3  2007/06/13 21:08:41  jsedwards
--- Changed to take a directory as an argument instead of a list of files.
---
--- Revision 1.2  2007/06/04 13:44:05  jsedwards
--- Add 'match' paramter to find_matchine_path_and_file_association.
---
--- Revision 1.1  2007/04/26 13:35:37  jsedwards
--- Initial version extracted from log_disc.c.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file and the log_disc.c file which this
+--   file was derived from.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
