@@ -1,10 +1,7 @@
 /*
---         This file is part of the New World OS and Objectify projects
---                    Copyright (C) 2006-2009  QRW Software
---              J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                         http://www.qrwsoftware.com
---                         http://nwos.sourceforge.com
---                      http://objectify.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--               Copyright (C) 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -20,202 +17,33 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: import_file.c,v $
--- Revision 1.47  2009/05/09 10:48:44  jsedwards
--- Merged in changes from alpha_29_10_branch (note: the same fix was already
--- made in the main trunk in revision 1.45, so the merge only added the log
--- message from the alpha_29_10_branch).
---
--- Revision 1.44.2.1  2009/05/05 13:13:16  jsedwards
--- Added 'z' to a couple of print statements to eliminate compiler warning.
---
--- Revision 1.46  2009/04/10 14:25:14  jsedwards
--- Changed to call new flush_to_disk function instead of the old flush_bit_maps
--- function because the reference lists need to be flushed as well.
---
--- Revision 1.45  2009/04/05 12:42:35  jsedwards
--- Fixed two compiler warnings in printf statements on amd64 machines.
---
--- Revision 1.44  2009/04/04 15:41:51  jsedwards
--- Fix copyright years.  NO code changes.
---
--- Revision 1.43  2009/03/19 11:27:35  jsedwards
--- Wrapped everything that was related to security levels with ifdef
--- CHANGE_SECURITY_TO_DENSITY to disable it for the time being.
---
--- Revision 1.42  2009/03/14 03:31:24  jsedwards
--- Added include of bit_map.h file.
---
--- Revision 1.41  2008/12/27 15:00:29  jsedwards
--- Merged from alpha_29_5_branch back into main trunk.
---
--- Revision 1.40.2.2  2008/12/19 14:47:20  jsedwards
--- Changed so that any PATH_NOT_FOUND, DUPLICATE_PATH, DUPLICATE_FILE, and
--- MULTIPLE_FILES errors also exit with a 1 code.
---
--- Revision 1.40.2.1  2008/12/16 14:44:18  jsedwards
--- Changed so that exit code is non-zero if any errors occurred during import
--- or the archive was too full to import any files.
---
--- Revision 1.40  2008/09/01 18:53:48  jsedwards
--- Fixed Bug #2043130 - asserts if given an absolute path.
---
--- Revision 1.39  2008/09/01 03:13:42  jsedwards
--- Change for new nwos_initialize_objectify calling convention (doesn't pass
--- back root_object_reference anymore) and removed call to nwos_set_root_object
--- because initialize calls it now.
---
--- Revision 1.38  2008/08/30 12:46:12  jsedwards
--- Removed code and variables to read pass phrase and pass it to initialize,
--- and change parameters passed to initialize.
---
--- Revision 1.37  2008/07/13 14:18:58  jsedwards
--- Feature Request #1856369 - Added handling of new IMPORTED_DATA result from
--- nwos_create_file.
---
--- Revision 1.36  2008/07/11 13:01:05  jsedwards
--- Added include of limits.h to define PATH_MAX.
---
--- Revision 1.35  2008/06/23 13:40:18  jsedwards
--- Fixed to remove the leading "./" from the path if doing "-r .".
---
--- Revision 1.34  2008/06/23 04:31:40  jsedwards
--- The nwos_normalize_path function changed to return void instead of book,
--- accept "." and ".." paths so calls were changed to deal with it.
---
--- Revision 1.33  2008/06/22 19:01:18  jsedwards
--- Reversed order of expressions in if statement so that it tests the size
--- before testing the array (should not have caused a problem anyway).
---
--- Revision 1.32  2008/06/21 16:17:42  jsedwards
--- Moved cleanup_path function to file.c, renamed to nwos_normalize_path, and
--- added size parameter.
---
--- Revision 1.31  2008/06/21 03:49:20  jsedwards
--- Fixed cleanup_path to do multiple slashes, so it will eliminate '///' or
--- '////' as well as '//'.
---
--- Revision 1.30  2008/06/21 03:44:18  jsedwards
--- Added cleanup_path function and fixed to eliminate duplicate slashes in
--- path.
---
--- Revision 1.29  2008/06/21 02:52:32  jsedwards
--- Fixed spacing on line 261.  NO code changes.
---
--- Revision 1.28  2008/06/21 02:12:14  jsedwards
--- Added print statement left out in previous check in.
---
--- Revision 1.27  2008/06/19 13:20:24  jsedwards
--- Changed to allow multiple paths to files when importing recursively.
---
--- Revision 1.26  2008/06/19 11:50:51  jsedwards
--- Added asserts to make sure we don't create any paths with a double slash.
--- NOTE: have NOT fixed the code yet to eliminate the double paths so if you
--- do import_file -r xyzzy/ it will assert.
---
--- Revision 1.25  2008/06/12 03:42:25  jsedwards
--- Moved 'check_invalid_type' and 'check_directory_is_all_ok' functions to
--- file.c and added 'nwos_' prefix.
---
--- Revision 1.24  2008/04/28 12:50:32  jsedwards
--- Added initializer for 'result' in process_file function so that the compiler
--- won't complain about it being uninitialized.
---
--- Revision 1.23  2008/04/26 13:00:45  jsedwards
--- Removed --add-revision code from main() and put it in process_file() so now
--- it can add-revision when recursively processing directories.
---
--- Revision 1.22  2008/04/26 12:01:00  jsedwards
--- Took code from main() and created new process_file function that can
--- recursively do directories.
---
--- Revision 1.21  2008/04/26 00:26:57  jsedwards
--- Added code to deal with recursively doing directories (Incomplete!).
---
--- Revision 1.20  2008/02/03 01:00:35  jsedwards
--- Changed DEFAULT_TYPE_RW to READ_WRITE.
---
--- Revision 1.19  2007/11/04 13:06:02  jsedwards
--- Added an extra note to look at Security_Levels.txt file in display_usage.
---
--- Revision 1.18  2007/11/04 13:00:43  jsedwards
--- Added display usage.
---
--- Revision 1.17  2007/10/08 12:40:52  jsedwards
--- Added call to restart ID generation for each file.
---
--- Revision 1.16  2007/10/07 03:56:09  jsedwards
--- Renamed 'nwos_set_block_estimate' to 'nwos_check_blocks_available' and
--- changed to skip the file if not enough space available.
---
--- Revision 1.15  2007/09/02 19:45:31  jsedwards
--- Added calls to set the block estimate.
---
--- Revision 1.14  2007/09/01 21:52:57  jsedwards
--- Changed 'encryption_options' table to 'security_options' to match up with
--- changes made earlier (Aug 12th).
---
--- Revision 1.13  2007/08/12 20:45:00  jsedwards
--- Change all of the "Encryption Level" stuff to "Security Level" because it
--- doesn't really change the encryption at all, all it does is change the
--- randomization of where objects are stored.
---
--- Revision 1.12  2007/08/06 02:22:45  jsedwards
--- Added "high" security option.
---
--- Revision 1.11  2007/07/24 04:47:03  jsedwards
--- Added "--add-revision" option and code to add new revision to a file that
--- is already in the system.
---
--- Revision 1.10  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.9  2007/02/11 16:58:26  jsedwards
--- Changed so DEFAULT_TYPE has to specify RO (Read-Only) or RW (Read-Write).
---
--- Revision 1.8  2007/01/27 14:59:03  jsedwards
--- Changed to handle new possible return values (duplicate path or file).
---
--- Revision 1.7  2007/01/17 13:17:43  jsedwards
--- Added security level options.
---
--- Revision 1.6  2007/01/07 20:31:55  jsedwards
--- Added call to log arguments.
---
--- Revision 1.5  2007/01/07 03:27:06  jsedwards
--- Added call to set encryption level (Low by default).
---
--- Revision 1.4  2006/12/07 14:10:25  jsedwards
--- Removed call to file_setup, no longer needed.
---
--- Revision 1.3  2006/11/11 12:01:03  jsedwards
--- Update e-mail address to something that works.
---
--- Revision 1.2  2006/10/26 01:51:27  jsedwards
--- Merged alpha_05_branch back into main trunk.
---
--- Revision 1.1.2.4  2006/10/13 12:58:52  jsedwards
--- Added printing of time to import each file.
---
--- Revision 1.1.2.3  2006/10/13 11:48:27  jsedwards
--- Add call to flush block maps after each file is read.
---
--- Revision 1.1.2.2  2006/10/03 12:53:07  jsedwards
--- Changed so that instead of calling a separate routine after initialize to
--- change the already opened storage, you call it now with a type of storage
--- parameter and a path to the storage.  The problem with the other way was
--- if you tried reading a compressed file on another machine it tried to open
--- the default file which didn't exist.
---
--- Revision 1.1.2.1  2006/09/18 01:45:37  jsedwards
--- Program to store a file into objectify.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.  Also this file was created in the
+--   alpha_05_branch so check the logs for this file in it too.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
