@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2006-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--               Copyright (C) 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,111 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: list_discs.c,v $
--- Revision 1.25.2.2  2009/06/06 12:51:32  jsedwards
--- Changed to print white space around warning messages and print "Warning" in
--- upper case.
---
--- Revision 1.25.2.1  2009/06/06 12:37:57  jsedwards
--- Bug #2455976 - changed so that if there are disc lists but no disc copies
--- it prints a warning message and still lists the discs.
---
--- Revision 1.25  2009/03/10 04:12:10  jsedwards
--- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
---
--- Revision 1.24  2008/09/01 03:13:42  jsedwards
--- Change for new nwos_initialize_objectify calling convention (doesn't pass
--- back root_object_reference anymore) and removed call to nwos_set_root_object
--- because initialize calls it now.
---
--- Revision 1.23  2008/08/31 21:53:52  jsedwards
--- Added an assert around calls to nwos_read_variable_sized_object_from_disk
--- and nwos_read_object_from_disk because now they return false when they fail
--- instead of asserting themselves.
---
--- Revision 1.22  2008/08/30 12:46:13  jsedwards
--- Removed code and variables to read pass phrase and pass it to initialize,
--- and change parameters passed to initialize.
---
--- Revision 1.21  2008/05/18 17:10:09  jsedwards
--- Feature Request #1966442 - added ability to pass disc IDs with wildcards on
--- command line.
---
--- Revision 1.20  2008/04/09 12:35:05  jsedwards
--- Added call to nwos_log_arguments to disable logging.
---
--- Revision 1.19  2008/02/03 01:05:23  jsedwards
--- Changed DEFAULT_TYPE_RO to READ_ONLY.
---
--- Revision 1.18  2007/07/05 18:24:02  jsedwards
--- Changed to not print copy if there is a newer version of the object.
---
--- Revision 1.17  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.16  2007/06/06 00:19:33  jsedwards
--- Fixed name of storage location class.
---
--- Revision 1.15  2007/06/03 22:02:39  jsedwards
--- Changed so that location printed can be either a Location or a Person.
---
--- Revision 1.14  2007/03/03 15:25:16  jsedwards
--- Changed to list each disc list and then each copy of it.
---
--- Revision 1.13  2007/02/24 01:09:49  jsedwards
--- Add "--contents" option to list all files on disc as well.  Default is
--- now to just list discs.
---
--- Revision 1.12  2007/02/11 16:58:26  jsedwards
--- Changed so DEFAULT_TYPE has to specify RO (Read-Only) or RW (Read-Write).
---
--- Revision 1.11  2007/01/20 13:39:44  jsedwards
--- Change so that it prints a nice error message instead of asserting when
--- private File_Path or Disc_Copy classes don't exist.
---
--- Revision 1.10  2007/01/07 03:24:53  jsedwards
--- Changed to work with new path_and_file_association object.
---
--- Revision 1.9  2006/12/21 13:08:36  jsedwards
--- Hack to make it compile with new split public and private classes,
--- NON-FUNCTIONAL!
---
--- Revision 1.8  2006/12/19 14:52:18  jsedwards
--- Kludged version to compile with new 'file path' structure without 'file'
--- feature.  DOES NOT function correctly!
---
--- Revision 1.7  2006/12/01 14:31:30  jsedwards
--- Changed to use new malloc_reference_list and free_reference_list functions
--- instead of inlining the code.
---
--- Revision 1.6  2006/11/27 13:50:44  jsedwards
--- Changed to use variable sized counts for disc lists (so number of files can
--- be larger than 127).
---
--- Revision 1.5  2006/11/19 15:28:20  jsedwards
--- Made get_disc_list_object_size a global function.
---
--- Revision 1.4  2006/11/18 15:09:10  jsedwards
--- Added "max_size" parameter to read_variable_sized_object_from_disk because
--- objects are no longer limited to one file block.
---
--- Revision 1.3  2006/11/18 14:37:02  jsedwards
--- Change size of kludge buffer for reading disc list to max size of disc
--- list instead of file block size, because now disc list objects can be
--- larger than one file block.
---
--- Revision 1.2  2006/11/11 12:01:04  jsedwards
--- Update e-mail address to something that works.
---
--- Revision 1.1  2006/11/07 14:04:46  jsedwards
--- Program to list all of the discs logged in the system.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
