@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2006-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--               Copyright (C) 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,170 +17,33 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: list_files.c,v $
--- Revision 1.39  2009/03/10 04:15:05  jsedwards
--- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
---
--- Revision 1.38  2009/03/08 01:01:51  jsedwards
--- Changed include objectify_private.h to objectify.h and changed test to verify
--- that public files were found to an assert because the public objects have had
--- files in them for over a year now and so it should never fail if we have the
--- current public objects.  This way we don't have to include disk_io.h.  Also
--- changed to call new nwos_archive_version function instead of accessing the
--- header directly.
---
--- Revision 1.37  2009/01/26 16:32:52  jsedwards
--- Changed to use PATH_MAX for size of name buffer instead of 256.
---
--- Revision 1.36  2008/12/27 15:00:29  jsedwards
--- Merged from alpha_29_5_branch back into main trunk.
---
--- Revision 1.35.2.1  2008/12/20 16:07:59  jsedwards
--- Fixed to report arguments that didn't match any files and return exit code
--- of 1 if any didn't.
---
--- Revision 1.35  2008/09/01 03:13:43  jsedwards
--- Change for new nwos_initialize_objectify calling convention (doesn't pass
--- back root_object_reference anymore) and removed call to nwos_set_root_object
--- because initialize calls it now.
---
--- Revision 1.34  2008/08/31 21:53:52  jsedwards
--- Added an assert around calls to nwos_read_variable_sized_object_from_disk
--- and nwos_read_object_from_disk because now they return false when they fail
--- instead of asserting themselves.
---
--- Revision 1.33  2008/08/30 12:46:13  jsedwards
--- Removed code and variables to read pass phrase and pass it to initialize,
--- and change parameters passed to initialize.
---
--- Revision 1.32  2008/06/01 04:10:49  jsedwards
--- Fix assert to verify the correct reference for the previous version.
---
--- Revision 1.31  2008/05/31 14:37:54  jsedwards
--- Fix so that revision is always initialized.
---
--- Revision 1.30  2008/05/31 14:32:07  jsedwards
--- Fixed so that old name gets the ;0 revision NOT the new name.
---
--- Revision 1.29  2008/05/31 13:47:56  jsedwards
--- Changed code to flag old revision files that were a name change, with a ;0
--- revision.
---
--- Revision 1.28  2008/05/22 11:35:58  jsedwards
--- Changed so that it deals with pre Alpha_28 revised files, but warns of
--- problem at the end.
---
--- Revision 1.27  2008/05/21 13:26:40  jsedwards
--- Added code to deal with revisied file links being in PATH AND FILE
--- ASSOCIATION objects instead of FILE objects.  Still need to figure out
--- how to deal with reading compressed files that are the old way.
---
--- Revision 1.26  2008/04/09 12:35:21  jsedwards
--- Added call to nwos_log_arguments to disable logging.
---
--- Revision 1.25  2008/03/14 19:11:19  jsedwards
--- Added --sha512 option.
---
--- Revision 1.24  2008/02/16 17:34:34  jsedwards
--- Added if statements in print_sha1 to print "not available" if it is void in
--- the file object and print_time to print "unknown" if modification time is
--- zero.
---
--- Revision 1.23  2008/02/11 04:15:12  jsedwards
--- Added the --public option.
---
--- Revision 1.22  2008/02/03 01:05:23  jsedwards
--- Changed DEFAULT_TYPE_RO to READ_ONLY.
---
--- Revision 1.21  2008/01/22 13:40:03  jsedwards
--- Updated year in copyright.
---
--- Revision 1.20  2008/01/22 13:30:33  jsedwards
--- Added missing options to usage print and expanded to explain options.
---
--- Revision 1.19  2007/12/24 02:25:51  jsedwards
--- Added --time and --revision options.
---
--- Revision 1.18  2007/08/25 22:48:27  jsedwards
--- Fixed option name in usage print statement.
---
--- Revision 1.17  2007/08/25 21:55:09  jsedwards
--- Added --list-old-files option and code to only print the old names of files
--- that have been renamed if that option is set.
---
--- Revision 1.16  2007/08/23 13:43:58  jsedwards
--- Removed unused code to read File Path class reference and emit error message
--- when there isn't a private File and Path Association class (meaning no files
--- exist in the system), instead of asserting.
---
--- Revision 1.15  2007/08/17 17:59:52  jsedwards
--- Added code to deal with the case where a file object doesn't have a SHA256
--- checksum, but the --sha256 option is enabled.
---
--- Revision 1.14  2007/08/17 16:48:54  jsedwards
--- Added code to optionally print SHA256 checksums.
---
--- Revision 1.13  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.12  2007/02/11 16:58:26  jsedwards
--- Changed so DEFAULT_TYPE has to specify RO (Read-Only) or RW (Read-Write).
---
--- Revision 1.11  2007/01/14 22:22:03  jsedwards
--- Add --sha1 option to do print SHA1 checksum instead of MD5.
---
--- Revision 1.10  2007/01/10 13:58:54  jsedwards
--- Changed to scan the path_and_file_association objects instead of the
--- file_path objects.
---
--- Revision 1.9  2007/01/09 13:06:18  jsedwards
--- Change to use new path_and_file_association object.
---
--- Revision 1.8  2006/12/21 13:08:36  jsedwards
--- Hack to make it compile with new split public and private classes,
--- NON-FUNCTIONAL!
---
--- Revision 1.7  2006/12/19 14:52:18  jsedwards
--- Kludged version to compile with new 'file path' structure without 'file'
--- feature.  DOES NOT function correctly!
---
--- Revision 1.6  2006/12/02 03:44:03  jsedwards
--- Change to print md5 sums when there are multiple files with the same name.
---
--- Revision 1.5  2006/12/01 14:31:30  jsedwards
--- Changed to use new malloc_reference_list and free_reference_list functions
--- instead of inlining the code.
---
--- Revision 1.4  2006/12/01 05:20:26  jsedwards
--- Changed to handle the case where a file path points to more than one file.
--- The case where printing MD5 sums is not handled yet.
---
--- Revision 1.3  2006/11/18 15:09:10  jsedwards
--- Added "max_size" parameter to read_variable_sized_object_from_disk because
--- objects are no longer limited to one file block.
---
--- Revision 1.2  2006/10/26 01:51:27  jsedwards
--- Merged alpha_05_branch back into main trunk.
---
--- Revision 1.1.2.4  2006/10/25 12:22:28  jsedwards
--- Changed C_struct_class_definition to C_struct_Class_Definition so the case
--- is consistent with all the other C_struct objects.
---
--- Revision 1.1.2.3  2006/10/07 12:56:27  jsedwards
--- Added file name globing so you specify which files to list.
---
--- Revision 1.1.2.2  2006/10/07 12:27:59  jsedwards
--- Added the ability to print md5sums in the listing with the --md5 option.
---
--- Revision 1.1.2.1  2006/10/06 12:06:57  jsedwards
--- Program to list all files (actually file_paths) in system.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.  Also this file was created in the
+--   alpha_05_branch so check the logs for this file in it too.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
