@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2004-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--            Copyright (C) 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,100 +17,33 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: log.c,v $
--- Revision 1.22  2009/03/14 04:11:53  jsedwards
--- Removed include of disk_io.h file and added include of user_config.h file.
---
--- Revision 1.21  2009/03/13 12:45:40  jsedwards
--- Removed include of objectify.h file and added includes for log.h and
--- strlcxx.h files.
---
--- Revision 1.20  2009/03/08 19:11:31  jsedwards
--- Moved strlcat function to new strlcat.c file and strlcpy function to new
--- strlcpy.c file.
---
--- Revision 1.19  2009/03/08 00:41:36  jsedwards
--- Changed include objectify_private.h to disk_io.h.
---
--- Revision 1.18  2008/12/27 15:00:29  jsedwards
--- Merged from alpha_29_5_branch back into main trunk.
---
--- Revision 1.17.2.2  2008/12/23 11:48:16  jsedwards
--- Fix Bug #2026708 - change to use strlcpy instead of strncpy.
---
--- Revision 1.17.2.1  2008/12/23 10:40:31  jsedwards
--- Changed the name of the 'len' parameter to the strlcpy and strlcat functions
--- to 'size' to be consistent with the documentation (OpenBSD man pages).  Also
--- added an assert to verify the size isn't zero.  No changes to the
--- functionality of the code.
---
--- Revision 1.17  2008/08/24 14:39:36  jsedwards
--- Added code to disable logging if log file path is NULL or empty.
---
--- Revision 1.16  2008/04/26 11:36:13  jsedwards
--- Added 'const' to char* file_name parameter in the four log_*sum functions.
---
--- Revision 1.15  2008/03/14 13:11:55  jsedwards
--- Added nwos_log_sha512sum function.
---
--- Revision 1.14  2008/03/12 14:43:59  jsedwards
--- Added code to create subdirectories in the path if they don't already
--- exist.
---
--- Revision 1.13  2008/03/12 11:40:48  jsedwards
--- Added code to disable logging if nwos_log_arguments is called with argc=0
--- and argv=NULL.
---
--- Revision 1.12  2008/02/05 04:23:44  jsedwards
--- Added include of objectify_private.h.  Removed forward references for
--- strlcat and strlcpy because they are declared in objectify.h.  Changed to
--- get the log file path from the new nwos_get_log_file_path function.
--- Added 'const' specifier to strlcat and strlcpy.
---
--- Revision 1.11  2008/01/13 20:09:06  jsedwards
--- Added nwos_log_md5sum, nwos_log_sha1sum, and nwos_log_sha256sum functions.
---
--- Revision 1.10  2007/10/27 14:55:21  jsedwards
--- Changed to use #ifndef STRLCAT and #ifndef STRLCPY instead of #ifdef linux.
---
--- Revision 1.9  2007/10/03 13:37:13  jsedwards
--- Bug #1806945 - Fixed so least significant digit of month isn't goofed up
--- in October, November, and December.
---
--- Revision 1.8  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.7  2007/03/07 13:10:45  jsedwards
--- Fixed bug so appending date is null terminated.
--- Changed to use file name defined in config.h so debug versions can have a
--- different file name.
---
--- Revision 1.6  2007/02/23 13:27:02  jsedwards
--- Move the strlcpy and strlcat functions from objectify.c to log.c so that
--- log.o can be used without having to drag in the whole objecitfy library.
---
--- Revision 1.5  2007/02/11 18:04:22  jsedwards
--- Added code to dynamically create the log file path using the users home
--- directory and the date.
---
--- Revision 1.4  2007/02/11 14:43:45  jsedwards
--- Cast the time value for ctime so the compiler won't complain.
---
--- Revision 1.3  2007/01/07 20:30:56  jsedwards
--- Increased size of msg buffer for logging arguments.
---
--- Revision 1.2  2006/12/28 23:24:39  jsedwards
--- Added include of sys/time.h to declare gettimeofday.
---
--- Revision 1.1  2006/12/27 14:15:24  jsedwards
--- Move log functions out of objectify.c and into a new file log.c.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file and the objectify.c file which
+--   this file was derived from.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
