@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2006-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--               Copyright (C) 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,162 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: log_disc.c,v $
--- Revision 1.42.2.1  2009/06/06 14:27:40  jsedwards
--- Fix Bug #2740516 - Moved get_input function to new dialog.c file, renamed it
--- to nwos_ask_user, and changed to call it.  Created new get_number function
--- that checks the return value from fgets string and changed to call it.
---
--- Revision 1.42  2009/04/04 15:41:51  jsedwards
--- Fix copyright years.  NO code changes.
---
--- Revision 1.41  2009/03/19 11:38:21  jsedwards
--- Wrapped call to nwos_set_security_level with ifdef CHANGE_SECURITY_TO_DENSITY
--- because what was called security level stuff is temporarily disabled.
---
--- Revision 1.40  2008/09/01 03:13:43  jsedwards
--- Change for new nwos_initialize_objectify calling convention (doesn't pass
--- back root_object_reference anymore) and removed call to nwos_set_root_object
--- because initialize calls it now.
---
--- Revision 1.39  2008/08/31 21:53:53  jsedwards
--- Added an assert around calls to nwos_read_variable_sized_object_from_disk
--- and nwos_read_object_from_disk because now they return false when they fail
--- instead of asserting themselves.
---
--- Revision 1.38  2008/08/30 12:46:14  jsedwards
--- Removed code and variables to read pass phrase and pass it to initialize,
--- and change parameters passed to initialize.
---
--- Revision 1.37  2008/08/03 17:31:34  jsedwards
--- Add --ignore-empty-directories and --ignore-empty-files options.
---
--- Revision 1.36  2008/08/03 15:44:36  jsedwards
--- Changed to handle new error values returned by nwos_read_files_disc_list.
---
--- Revision 1.35  2008/07/25 12:11:03  jsedwards
--- Changed to allow it to scan subdirectories recursively.
---
--- Revision 1.34  2008/03/25 14:18:40  jsedwards
--- Added an error message if the disk is empty so the user doesn't get some
--- bogus assert.
---
--- Revision 1.33  2008/03/25 14:11:39  jsedwards
--- Fix so that it can deal with more than 9 storage locations (2 digits).
---
--- Revision 1.32  2008/03/25 12:59:08  jsedwards
--- Fixed a typo in a couple of comments and add a couple of new comments.
--- NO code changes!
---
--- Revision 1.31  2008/02/03 01:00:53  jsedwards
--- Changed DEFAULT_TYPE_RW to READ_WRITE.
---
--- Revision 1.30  2007/10/07 03:43:50  jsedwards
--- Renamed 'nwos_set_block_estimate' to 'nwos_check_blocks_available' and
--- changed to exit gracefully if not enough space available.
---
--- Revision 1.29  2007/09/02 19:47:25  jsedwards
--- Added call to set the block estimate.
---
--- Revision 1.28  2007/08/12 20:45:00  jsedwards
--- Change all of the "Encryption Level" stuff to "Security Level" because it
--- doesn't really change the encryption at all, all it does is change the
--- randomization of where objects are stored.
---
--- Revision 1.27  2007/07/12 16:00:04  jsedwards
--- Give 'binder' an illegal initial value so compiler on FreeBSD won't complain.
---
--- Revision 1.26  2007/07/07 20:33:01  jsedwards
--- Changed to also print disc_list info to log.
---
--- Revision 1.25  2007/07/06 12:26:36  jsedwards
--- Change so that storage locations are not hard coded in the program but can
--- be added on the fly by the user.
---
--- Revision 1.24  2007/07/05 18:21:55  jsedwards
--- Changed assert(result == CREATED_NEW) to if statement that says if a new
--- disc_copy was created or it was updated.
---
--- Revision 1.23  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.22  2007/06/13 21:15:01  jsedwards
--- Comment out debugging print statement accidentally left in.
---
--- Revision 1.21  2007/06/13 20:53:50  jsedwards
--- Changed to take a directory as a parameter instead of a list of files.
---
--- Revision 1.20  2007/06/04 13:44:05  jsedwards
--- Add 'match' paramter to find_matchine_path_and_file_association.
---
--- Revision 1.19  2007/06/03 22:03:55  jsedwards
--- Changed so that 'location' can be a Location object or a Person object.
---
--- Revision 1.18  2007/04/28 12:40:56  jsedwards
--- Added printing of each file name so the printing from finding the name and
--- file isn't so weird.
---
--- Revision 1.17  2007/02/11 16:58:26  jsedwards
--- Changed so DEFAULT_TYPE has to specify RO (Read-Only) or RW (Read-Write).
---
--- Revision 1.16  2007/01/27 01:43:51  jsedwards
--- Change storage options to be numbered from 1 to 6 instead of 0 to 5.
---
--- Revision 1.15  2007/01/20 13:36:58  jsedwards
--- Change encryption level to "very low".
---
--- Revision 1.14  2007/01/13 14:36:48  jsedwards
--- Added "failed" storage location for disk copies that didn't write, verify,
--- or some other problem occured.
---
--- Revision 1.13  2007/01/10 13:15:59  jsedwards
--- Added "missing" as a storage location for discs that are misplaced.
---
--- Revision 1.12  2007/01/07 19:13:41  jsedwards
--- Add call to log the arguments.
---
--- Revision 1.11  2007/01/06 20:12:06  jsedwards
--- Changed binder names and error if no files specified on command line.
---
--- Revision 1.10  2007/01/05 13:51:16  jsedwards
--- Change to work with new file association.
---
--- Revision 1.9  2006/12/07 14:10:25  jsedwards
--- Removed call to file_setup, no longer needed.
---
--- Revision 1.8  2006/12/02 17:23:32  jsedwards
--- Removed start_time that wasn't used and added SafeDepositBox location.
---
--- Revision 1.7  2006/11/19 16:40:22  jsedwards
--- Moved creation of disc list to separate program (disc_list) and made this
--- program just verify the disc list create the disc_copy object.
---
--- Revision 1.6  2006/11/18 14:34:58  jsedwards
--- Changed so that discs can be stored in one of three different binders.
---
--- Revision 1.5  2006/11/11 12:01:04  jsedwards
--- Update e-mail address to something that works.
---
--- Revision 1.4  2006/11/07 14:03:35  jsedwards
--- Add assert to verify file_path didn't come back void.
---
--- Revision 1.3  2006/11/06 13:54:07  jsedwards
--- Changed wording in print statement because disc_list now stores the
--- references to the file_path object instead of the file object.
---
--- Revision 1.2  2006/11/05 21:32:18  jsedwards
--- Add code to create storage_location and disc_copy objects.
---
--- Revision 1.1  2006/11/04 18:56:22  jsedwards
--- Program to scan all the files on a CD or DVD and make a disk_list object
--- of it.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
