@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2005-2008  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--            Copyright (C) 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,159 +17,34 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: name.c,v $
--- Revision 1.35  2008/08/31 21:26:16  jsedwards
--- Added assert around calls to nwos_read_variable_sized_object_from_disk
--- because it now returns false when it fails instead of asserting itself.
---
--- Revision 1.34  2008/04/26 11:42:18  jsedwards
--- Added 'const' to char* name parameter in some of the functions.
---
--- Revision 1.33  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.32  2007/06/03 17:32:38  jsedwards
--- Fix so when converting to string it changes the third letter ot upper case
--- if the first two letters are "Mc" or "O'".
---
--- Revision 1.31  2007/05/23 03:18:25  jsedwards
--- Removed acronym functions added in r1.30, this version is identical to r1.29.
---
--- Revision 1.30  2007/05/22 03:02:42  jsedwards
--- Added public acronym functions.
---
--- Revision 1.29  2007/05/22 02:38:43  jsedwards
--- Change 'create_spelling' to 'create_public_spelling'.
---
--- Revision 1.28  2007/01/06 20:07:49  jsedwards
--- Split find_name into find_public_name and find_private_name and fixed
--- create name to create according to mode we are in.
---
--- Revision 1.27  2006/12/27 12:23:30  jsedwards
--- Allow an apostrophe in a name (O'Malley).
---
--- Revision 1.26  2006/12/25 12:14:52  jsedwards
--- Fix to only work with public names, this still needs to be fixed.
---
--- Revision 1.25  2006/12/21 12:59:47  jsedwards
--- Hack to make it compile with new split public and private classes,
--- NON-FUNCTIONAL!
---
--- Revision 1.24  2006/12/01 14:31:30  jsedwards
--- Changed to use new malloc_reference_list and free_reference_list functions
--- instead of inlining the code.
---
--- Revision 1.23  2006/11/18 15:09:10  jsedwards
--- Added "max_size" parameter to read_variable_sized_object_from_disk because
--- objects are no longer limited to one file block.
---
--- Revision 1.22  2006/11/11 12:01:04  jsedwards
--- Update e-mail address to something that works.
---
--- Revision 1.21  2006/10/26 01:51:27  jsedwards
--- Merged alpha_05_branch back into main trunk.
---
--- Revision 1.20.2.3  2006/09/01 13:27:20  jsedwards
--- Changed "nwos_object_size" to "nwos_reference_list_size" and added the
--- object reference to "nwos_fill_in_common_header" so it can put the "id"
--- in the header now.
---
--- Revision 1.20.2.2  2006/08/18 12:53:48  jsedwards
--- Changed hard coded 512 for block size to FILE_BLOCK_SIZE.
---
--- Revision 1.20.2.1  2006/08/16 12:43:58  jsedwards
--- Changed to use temporary buffers to reconvert to string instead of reusing
--- the "kludge" buffer, so that new versions of GCC don't complain about the
--- signedness of pointers.
---
--- Revision 1.20  2006/01/12 02:56:27  jsedwards
--- Added code to make first letter upper case, because spellings are now
--- always stored as lower case.
---
--- Revision 1.19  2006/01/09 02:45:18  jsedwards
--- Fix bug where it tried to verify the name on objects it didn't find.  Now
--- it only reassembles the object and verifies it, if it finds it.
---
--- Revision 1.18  2006/01/04 18:53:02  jsedwards
--- Fixed bug in matching name object number of words.  It was not correctly
--- comparing the number of words, so it would match one with the wrong number
--- of words.  For example when searching for "Los Angeles" it would match up
--- with "East Los Angeles".
---
--- Revision 1.17  2006/01/04 18:37:44  jsedwards
--- Changed to allow abbreviations (such as St. for Saint) in names.
--- Changed reassembly code to just call "name to string" routine to
--- reassemble the name and then compare it to the original name.
---
--- Revision 1.16  2006/01/02 23:21:56  jsedwards
--- Moved 'ref_to_word' function to an inline function in objectify.h.
--- Changed old 'ref_to_name' calls to use 'ref_to_word' instead.
---
--- Revision 1.15  2006/01/02 21:57:54  jsedwards
--- Fixed two bugs in the finding of names.  The first was it set current_top
--- outside of the compare lists loop, so it didn't get reset back to zero
--- when we started over on list [0].  The second was that when it recomputed
--- the num_spellings after compare lists it indexed the reference list with
--- the "word" index instead of [0] which it was computing.
---
--- Revision 1.14  2006/01/02 21:48:33  jsedwards
--- Removed some of the debugging printf statements and added asserts to check
--- that the new calculated num_spellings is rational.
---
--- Revision 1.13  2006/01/02 21:35:38  jsedwards
--- Added a bunch of debug printf statements.
---
--- Revision 1.12  2005/12/29 17:50:53  jsedwards
--- Commented out printf debugging statements, that aren't useful now.
---
--- Revision 1.11  2005/12/29 17:36:08  jsedwards
--- Changes to make Name and Spelling objects variable sized.  This allows the
--- write object to disk routine to fill in the remainder of the 512 bytes with
--- random data.
---
--- Revision 1.10  2005/12/27 18:26:57  jsedwards
--- Added special routine for the "big_bang" to set the class reference.
--- Changed to look up class definition instead of using a fixed file name.
--- Also changed so that object id is random instead of based upon contents.
---
--- Revision 1.9  2005/12/24 16:18:26  jsedwards
--- Removed "host" id from object references (ObjRef).  Host redirection will
--- be done using a "redirection" object in the future.
---
--- Revision 1.8  2005/12/21 23:23:03  jsedwards
--- Added 'find_name' and 'name_to_string' routines.
---
--- Revision 1.7  2005/12/21 03:58:00  jsedwards
--- Changed so that a name can have multiple words in it.
---
--- Revision 1.6  2005/12/11 16:32:15  jsedwards
--- Fixed error message to say "name" instead of "year".
---
--- Revision 1.5  2005/12/10 15:03:36  jsedwards
--- Fixed header to say the GPL is in the LICENSE file instead of COPYING.
---
--- Revision 1.4  2005/12/05 05:22:46  jsedwards
--- Change to call read_reference_list_from_disk for reference lists instead
--- of read_object_from_disk.  Also moved calculating checksums down to just
--- before writing object, so that no changes occur after computing them.
---
--- Revision 1.3  2005/12/04 04:13:03  jsedwards
--- Added 'nwos' prefix to create_xxxx function names and eliminated the
--- 'referring' object parameter from all of them.
---
--- Revision 1.2  2005/12/04 00:39:28  jsedwards
--- Changed to use new "spelling" class to store the letters that make up the
--- name (copied the create_word class and adjusted accordingly).
---
--- Revision 1.1  2005/12/03 21:46:47  jsedwards
--- Initial version extracted from create_person.c file.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file and the old create_person.c file
+--   which this file was originally derived from.  I left the old log from the
+--   create_person.c file in the computer.c file to make it easier to find.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
@@ -184,7 +57,9 @@
 
 #include "crc32.h"
 #include "objectify.h"
-#include "objectify_private.h"
+
+
+#define MAX_NAME_OR_SPELLING_SIZE (MAX_NAME_OBJ_SIZE > MAX_SPELLING_OBJ_SIZE ? MAX_NAME_OBJ_SIZE : MAX_SPELLING_OBJ_SIZE)
 
 
 static ObjRef* get_public_name_class_ref()
@@ -262,7 +137,7 @@ static size_t get_name_object_size(void* name_obj)
 
 bool nwos_find_public_name(const char* name, ObjRef* ref)
 {
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_NAME_OBJ_SIZE];
     C_struct_Name* ptr_name_obj = (C_struct_Name*)kludge;
     EveryObject spelling_header;
     ObjRef spelling_ref[21];
@@ -467,7 +342,7 @@ bool nwos_find_public_name(const char* name, ObjRef* ref)
 
 bool nwos_find_private_name(const char* name, ObjRef* ref)
 {
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_NAME_OBJ_SIZE];
     C_struct_Name* ptr_name_obj = (C_struct_Name*)kludge;
     EveryObject spelling_header;
     ObjRef spelling_ref[21];
@@ -677,7 +552,7 @@ bool nwos_find_private_name(const char* name, ObjRef* ref)
 
 ObjCreateResult nwos_create_name(const char* name, ObjRef* ref)
 {
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_NAME_OBJ_SIZE];
     C_struct_Name* ptr_name_obj = (C_struct_Name*)kludge;
     EveryObject spelling_header;
     ObjRef* name_class_ref_ptr;
@@ -952,7 +827,7 @@ static size_t get_spelling_object_size(void* spelling_obj)
 
 bool nwos_name_to_string(ObjRef* ref, char* string, size_t size)
 {
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_NAME_OR_SPELLING_SIZE];
     C_struct_Name* ptr_name_obj;
     C_struct_Spelling* ptr_spelling_obj;
     int word;
