@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2005-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--               Copyright (C) 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,65 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: number.c,v $
--- Revision 1.14  2009/07/19 13:21:44  jsedwards
--- Added ifdef VERIFY_WRITE around code that reads back objects to verify they
--- were written correctly, they don't work correctly when nwos_write_block
--- modifies the upper 4 bytes of the reference in the block.
---
--- Revision 1.13  2009/03/10 11:42:32  jsedwards
--- Moved MAX_DIGITS and MAX_CARDINAL_NUMBER_SIZE defines to the objectify.h
--- file and renamed to MAX_CARDINAL_NUMBER_DIGITS and
--- MAX_CARDINAL_NUMBER_OBJ_SIZE.
---
--- Revision 1.12  2009/03/10 02:14:43  jsedwards
--- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
---
--- Revision 1.11  2009/03/08 00:13:54  jsedwards
--- Changed include objectify_private.h to objectify.h.
---
--- Revision 1.10  2008/09/01 00:10:52  jsedwards
--- Fix copyright year.  NO code changes.
---
--- Revision 1.9  2008/08/31 21:53:53  jsedwards
--- Added an assert around calls to nwos_read_variable_sized_object_from_disk
--- and nwos_read_object_from_disk because now they return false when they fail
--- instead of asserting themselves.
---
--- Revision 1.8  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.7  2006/12/21 12:59:47  jsedwards
--- Hack to make it compile with new split public and private classes,
--- NON-FUNCTIONAL!
---
--- Revision 1.6  2006/12/10 19:28:36  jsedwards
--- Added code to skip over leading zeros in a number.  Also fixed cardinal
--- number to string routine to verify it is an cardinal number.
---
--- Revision 1.5  2006/12/10 15:21:34  jsedwards
--- Added cardinal and ordinal number to string functions.
---
--- Revision 1.4  2006/12/10 15:05:07  jsedwards
--- Added find and create ordinal number routines.
---
--- Revision 1.3  2006/12/10 12:05:41  jsedwards
--- Changed to deal with numbers as strings of ascii decimal digits instead of
--- a uint32 and increased max_digits to 127 for now.
---
--- Revision 1.2  2006/12/09 18:55:37  jsedwards
--- Fixed bug using uninitialized variable to compute size of cardinal object.
--- Also verify it is a cardinal object in find before reading it.
---
--- Revision 1.1  2006/12/09 16:17:14  jsedwards
--- Initial version with only Cardinal Number functions (untested).
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
