@@ -1,10 +1,7 @@
 /*
---         This file is part of the New World OS and Objectify projects
---                    Copyright (C) 2004-2009  QRW Software
---              J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                         http://www.qrwsoftware.com
---                         http://nwos.sourceforge.com
---                      http://objectify.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--         Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -20,29 +17,33 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: objects.c,v $
--- Revision 1.4  2009/06/13 12:53:14  jsedwards
--- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
---
--- Revision 1.195.2.1  2009/05/18 12:38:49  jsedwards
--- Changed so nwos_remove_object is not compiled in public mode.  (Note: this
--- change was made to objectify.c in the alpha_29_10_branch.)
---
--- Revision 1.3  2009/04/14 11:58:29  jsedwards
--- Fixed to use root object reference for getting root object class.
---
--- Revision 1.2  2009/04/14 11:51:38  jsedwards
--- Moved external declarations for update file functions from objectify.c file.
---
--- Revision 1.1  2009/04/13 14:10:04  jsedwards
--- Initial version created with functions moved from objectify.c file.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file and the objectify.c file which this
+--   file was derived from.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
