@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2007-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                  Copyright (C) 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,90 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: patch_compressed.c,v $
--- Revision 1.19  2009/07/18 16:07:40  jsedwards
--- Added code to set the upper 4 bytes of the reference in blocks from a 0029
--- or older file to 0xfffffffe and back to zero if the block has to go around
--- again.
---
--- Revision 1.18  2009/07/18 02:33:14  jsedwards
--- Fixed to deal with having 0xfffffffe in the upper word of the reference in
--- each block if the version > 29.
---
--- Revision 1.17  2009/07/17 14:36:52  jsedwards
--- Fixed to print message to stderr when upper four bytes of block reference
--- are not zero and to exit with error code.  Added test for patch file block
--- and when finishing compressed file or patch file.
---
--- Revision 1.16  2009/07/11 13:31:28  jsedwards
--- Changed to pass TYPE_CODE_COMPRESSED and TYPE_CODE_DIFF in the calls to
--- check disk header.
---
--- Revision 1.15  2009/07/10 15:06:35  jsedwards
--- Changed to write compressed into the disk header of the output file if it
--- is version 0030 or above.
---
--- Revision 1.14  2009/07/05 13:07:31  jsedwards
--- Removed code that converted the 0022_to_0029 header to a 0030 header because
--- it was wrong and I am not sure it was necessary anyway.
---
--- Revision 1.13  2009/07/03 13:49:08  jsedwards
--- Changed to include new header.h file instead of disk_io.h and to use new
--- nwos_check_disk_header function to verify header is correct.
---
--- Revision 1.12  2009/04/06 14:28:13  jsedwards
--- Merged in changes from CVS branch_0030_new_chunk_info branch, see revision
--- 1.9.2.1 below.
---
--- Revision 1.11  2009/03/08 00:39:05  jsedwards
--- Changed include objectify_private.h to disk_io.h.
---
--- Revision 1.10  2008/09/01 00:10:52  jsedwards
--- Fix copyright year.  NO code changes.
---
--- Revision 1.9.2.1  2008/08/16 12:41:50  jsedwards
--- Added new convert_0022_to_0029_header_to_0030_header function to convert an
--- old header to the new 0030 header.  Also changed total_blocks to total_chunks
--- for new Disk_Header.
---
--- Revision 1.9  2008/02/02 11:24:41  jsedwards
--- Added code to print the number of used blocks in the old file and the patch
--- when they don't match.
---
--- Revision 1.8  2008/01/13 17:19:48  jsedwards
--- Changed to check individual differences in headers so that --ignore-times
--- will work.
---
--- Revision 1.7  2008/01/07 04:18:56  jsedwards
--- Added --ignore-times option which isn't functional yet.
---
--- Revision 1.6  2007/11/20 05:45:31  jsedwards
--- Fix comparison of reference id's.
---
--- Revision 1.5  2007/11/17 21:41:41  jsedwards
--- Added codee to determine if it is an older wrapped id file or the new
--- sequential file and decide where to insert the new blocks using the
--- appropriate method.
---
--- Revision 1.4  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.3  2007/06/18 13:07:38  jsedwards
--- Fixed to close output file.
---
--- Revision 1.2  2007/03/24 14:09:25  jsedwards
--- Added loop to finish writing the patch file blocks to the output file
--- after file 1 has reached end of file (blocks were added at the end).
---
--- Revision 1.1  2007/03/15 13:44:59  jsedwards
--- Initial version.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
