@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2005-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--            Copyright (C) 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,144 +17,35 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-26 08:35:32 -0600 (Sun, 26 Jul 2009) $
+--   $Revision: 4192 $
 --
--- $Log: person.c,v $
--- Revision 1.27.2.1  2009/06/06 14:59:35  jsedwards
--- Moved get_input function to new dialog.c file, renamed it to nwos_ask_user,
--- and changed to call it.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revisions of this file.  Since this file was originally created
+--   from a file called "create_person.c", I left the part of the log from
+--   when it was called create_person.c below to make it easier to access.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
--- Revision 1.27  2009/03/07 15:09:02  jsedwards
--- Removed include of objectify_private.h and changed to call
--- nwos_generate_new_id instead of nwos_generate_new_completely_random_id.
---
--- Revision 1.26  2008/12/27 15:00:29  jsedwards
--- Merged from alpha_29_5_branch back into main trunk.
---
--- Revision 1.25.2.1  2008/12/24 14:37:45  jsedwards
--- Fix Bug #2051304 - changed assert in list_persons to print a warning message
--- and return instead.
---
--- Revision 1.25  2008/09/01 00:10:54  jsedwards
--- Fix copyright year.  NO code changes.
---
--- Revision 1.24  2008/08/31 20:33:18  jsedwards
--- Add assert around calls to nwos_read_object_from_disk because it now
--- returns false when it fails, whereas before it would assert itself.
---
--- Revision 1.23  2007/07/29 19:46:00  jsedwards
--- Fix so variable isn't compiled because code that uses it isn't compiled to
--- eliminate compiler warning.
---
--- Revision 1.22  2007/07/12 03:11:47  jsedwards
--- Add nwos_add_birthday function to add a birthday to a person that doesn't
--- have one.
---
--- Revision 1.21  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.20  2007/05/05 14:43:45  jsedwards
--- Changed add_person to verify public names first.
---
--- Revision 1.19  2007/04/02 03:50:57  jsedwards
--- Added routines to do private gender objects and made add_person function
--- deal with creating private person objects.
---
--- Revision 1.18  2007/01/06 20:13:32  jsedwards
--- Changed to find_private_name instead of find_name.
---
--- Revision 1.17  2006/12/21 12:59:47  jsedwards
--- Hack to make it compile with new split public and private classes,
--- NON-FUNCTIONAL!
---
--- Revision 1.16  2006/12/07 14:08:46  jsedwards
--- Moved setup routine and associated functions to attic/big_bang.c.
---
--- Revision 1.15  2006/12/01 14:31:30  jsedwards
--- Changed to use new malloc_reference_list and free_reference_list functions
--- instead of inlining the code.
---
--- Revision 1.14  2006/11/11 12:01:06  jsedwards
--- Update e-mail address to something that works.
---
--- Revision 1.13  2006/11/03 04:17:12  jsedwards
--- Change "nick_name" to "nickname" (in the dictionary it is one word).
---
--- Revision 1.12  2006/10/26 01:51:28  jsedwards
--- Merged alpha_05_branch back into main trunk.
---
--- Revision 1.11.2.6  2006/10/25 12:22:29  jsedwards
--- Changed C_struct_class_definition to C_struct_Class_Definition so the case
--- is consistent with all the other C_struct objects.
---
--- Revision 1.11.2.5  2006/10/01 11:43:18  jsedwards
--- Add asserts to make sure it finds the gender objects.
---
--- Revision 1.11.2.4  2006/09/29 12:10:07  jsedwards
--- Add list_persons function.
---
--- Revision 1.11.2.3  2006/09/01 13:27:20  jsedwards
--- Changed "nwos_object_size" to "nwos_reference_list_size" and added the
--- object reference to "nwos_fill_in_common_header" so it can put the "id"
--- in the header now.
---
--- Revision 1.11.2.2  2006/08/16 12:50:12  jsedwards
--- Removed unused variable "create".
---
--- Revision 1.11.2.1  2006/07/31 12:48:59  jsedwards
--- Changed to use ask_yes_or_no function so that it will accept 'y' instead of
--- just 'yes'.
---
--- Revision 1.11  2006/01/09 13:52:54  jsedwards
--- Moved all "add to references" calls after person object is created.  This
--- way we don't get a bunch of non-existent objects in the reference lists
--- if it crashes before the person object is created.
---
--- Revision 1.10  2006/01/09 03:25:15  jsedwards
--- Added "any persons named", "full name to string", and "upgrade persons
--- from 0004 to 0005" routines.
---
--- Revision 1.9  2006/01/08 18:37:36  jsedwards
--- Fixed a bug in find person where it assumed that if it found the name it
--- would find a person, which of course isn't true.
---
--- Revision 1.8  2006/01/08 16:43:48  jsedwards
--- Fixed size of buffer passed to 'get_input' so that it is based upon the
--- actual 'sizeof' the buffer, instead of #define which could be (and was)
--- wrong.
---
--- Revision 1.7  2006/01/02 23:02:35  jsedwards
--- Fixed bug where fixed define was passed to fgets instead of the actual
--- 'size' parameter.  Added an assert to verify class was found.
---
--- Revision 1.6  2006/01/01 21:17:57  jsedwards
--- Changed "find person" routine to not print out the "cannot find" message,
--- and just return false.  It is now up to the caller to print the "not found"
--- message.
---
--- Revision 1.5  2006/01/01 21:13:25  jsedwards
--- Removed Social Security Number stuff from "add person" again.  This will
--- be done with a separate command.
---
--- Revision 1.4  2006/01/01 19:42:29  jsedwards
--- Fixed bug when entering a male person, there was garbage in the maiden name.
--- Changed the wording for more than one person.
---
--- Revision 1.3  2006/01/01 00:47:05  jsedwards
--- Added "find_person" and "describe_person" routines.
---
--- Revision 1.2  2005/12/31 17:51:14  jsedwards
--- Added gender stuff.  Moved creation of classes related to persons from
--- big_bang.  Added social security stuff back in (still not working).
---
--- Revision 1.1  2005/12/31 14:57:05  jsedwards
--- Copied "create_person.c" into "computer.c" and "person.c" and then removed
--- "create_person.c".
 --
 -- Revision 1.15  2005/12/30 14:13:39  jsedwards
 -- Removed Social Security Number stuff, not ready yet.
@@ -487,9 +376,19 @@ void nwos_add_person()
     char maiden_name[MAX_NAME_SIZE];
     char nickname[MAX_NAME_SIZE];
     char birth_date[MAX_DATE_SIZE];
+    char temp[MAX_NAME_SIZE];
     ObjRef person_class_ref;
+    ObjRef last_name_ref;
+    ObjRef middle_name_ref;
+    ObjRef first_name_ref;
+    ObjRef object_class;
+    EveryObject name_header;
+    ReferenceList* ref_list;
     int month, day, year;
+    int num_refs;
+    int i;
     bool ok;
+    bool printed_warning = false;
     C_struct_Person person_obj;
 
     nwos_find_or_create_private_class_definition("PERSON", &person_class_ref);
@@ -591,6 +490,61 @@ void nwos_add_person()
 	}
     }
 
+    if (nwos_find_private_name(last_name, &last_name_ref) && nwos_find_private_name(first_name, &first_name_ref))
+    {
+	if (*middle_name == '\0' || !nwos_find_private_name(middle_name, &middle_name_ref))
+	{
+	    void_reference(&middle_name_ref);
+	}
+
+	nwos_read_object_headers_from_disk(&last_name_ref, &name_header);
+
+	ref_list = nwos_malloc_reference_list(&name_header.object.references);
+
+	num_refs = ref_list->common_header.num_refs;
+
+	for (i = 0; i < num_refs; i++)
+	{
+	    nwos_get_object_class(&ref_list->references[i], &object_class);   /* find out what kind of object it is */
+
+	    if (is_same_object(&object_class, &person_class_ref))
+	    {
+		assert(nwos_read_object_from_disk(&ref_list->references[i], &person_obj, sizeof(person_obj)));
+
+		if (is_same_object(&last_name_ref, &person_obj.last_name) && is_same_object(&first_name_ref, &person_obj.first_name))
+		{
+		    if (*middle_name == '\0' || (!is_void_reference(&middle_name_ref) && is_same_object(&middle_name_ref, &person_obj.middle_name)))
+		    {
+			if (!printed_warning)
+			{
+			    printf("\n");
+			    printed_warning = true;
+			}
+
+			printf("WARNING: a person named ");
+
+			nwos_name_to_string(&person_obj.first_name, temp, sizeof(temp));
+			printf("%s ", temp);
+
+			if (!is_void_reference(&person_obj.middle_name))
+			{
+			    nwos_name_to_string(&person_obj.middle_name, temp, sizeof(temp));
+			    printf("%s ", temp);
+			}
+
+			nwos_name_to_string(&person_obj.last_name, temp, sizeof(temp));
+			printf("%s already exists!\n", temp);
+		    }
+		}
+	    }
+	}
+
+	nwos_free_reference_list(ref_list);
+	ref_list = NULL;
+    }
+
+    printf("\n");
+
     if (nwos_ask_yes_or_no(NULL, "Create person"))
     {
 	memset(&person_obj, 0, sizeof(person_obj));
