@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2005-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--            Copyright (C) 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,125 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: phone.c,v $
--- Revision 1.29  2009/06/13 11:37:25  jsedwards
--- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
---
--- Revision 1.28.2.1  2009/06/06 14:59:35  jsedwards
--- Moved get_input function to new dialog.c file, renamed it to nwos_ask_user,
--- and changed to call it.
---
--- Revision 1.28  2009/03/07 20:17:19  jsedwards
--- Removed #include of objectify_private.h, not needed.
---
--- Revision 1.27  2008/09/01 00:10:54  jsedwards
--- Fix copyright year.  NO code changes.
---
--- Revision 1.26  2008/08/31 20:33:17  jsedwards
--- Add assert around calls to nwos_read_object_from_disk because it now
--- returns false when it fails, whereas before it would assert itself.
---
--- Revision 1.25  2007/09/02 17:06:04  jsedwards
--- Changed bug number from 1786617 to 1786616 in previous log comment.  Bug
--- 1786617 is not fixed yet.  No code changes.
---
--- Revision 1.24  2007/09/02 16:54:12  jsedwards
--- Fixed Bugs #1786619 and #1786616, which occurred when creating an area code
--- for the first time and when creating the first phone number.
---
--- Revision 1.23  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.22  2007/04/10 13:27:32  jsedwards
--- Changed to find or create phone_number and mobile_phone classes.
---
--- Revision 1.21  2007/04/08 18:15:49  jsedwards
--- Made separate public and private create area code functions.
---
--- Revision 1.20  2007/04/07 14:05:54  jsedwards
--- Split find_area_code function into public and private variants.
---
--- Revision 1.19  2007/02/11 15:15:20  jsedwards
--- Change 'sprintf' calls to 'snprintf' calls so the OpenBSD linker will stop
--- whining.
---
--- Revision 1.18  2006/12/25 12:05:41  jsedwards
--- Ifdef out code that isn't used in "public_mode".
---
--- Revision 1.17  2006/12/21 12:59:47  jsedwards
--- Hack to make it compile with new split public and private classes,
--- NON-FUNCTIONAL!
---
--- Revision 1.16  2006/12/07 14:08:46  jsedwards
--- Moved setup routine and associated functions to attic/big_bang.c.
---
--- Revision 1.15  2006/12/01 14:31:30  jsedwards
--- Changed to use new malloc_reference_list and free_reference_list functions
--- instead of inlining the code.
---
--- Revision 1.14  2006/11/11 12:01:06  jsedwards
--- Update e-mail address to something that works.
---
--- Revision 1.13  2006/10/26 01:51:28  jsedwards
--- Merged alpha_05_branch back into main trunk.
---
--- Revision 1.12.2.2  2006/10/25 12:22:29  jsedwards
--- Changed C_struct_class_definition to C_struct_Class_Definition so the case
--- is consistent with all the other C_struct objects.
---
--- Revision 1.12.2.1  2006/09/01 13:27:20  jsedwards
--- Changed "nwos_object_size" to "nwos_reference_list_size" and added the
--- object reference to "nwos_fill_in_common_header" so it can put the "id"
--- in the header now.
---
--- Revision 1.12  2006/01/12 03:43:07  jsedwards
--- Commented out print statement.
---
--- Revision 1.11  2006/01/10 14:09:17  jsedwards
--- Added "find phone for person" routine.
---
--- Revision 1.10  2006/01/01 21:49:01  jsedwards
--- Moved date, phone, us_state, and word class creations out of "big bang"
--- and into the respective files.
---
--- Revision 1.9  2006/01/01 21:08:38  jsedwards
--- Removed debugging print statement and added a blank line before printing
--- give up (can't find person and phone number looks bad) message.
---
--- Revision 1.8  2006/01/01 19:55:24  jsedwards
--- Added "parse phone number" and "parse phone number wo area code" routines
--- to deal with phone numbers and reworked the whole problems with phone
--- numbers section of getting a mobile phone.
---
--- Revision 1.7  2006/01/01 14:52:51  jsedwards
--- Added phone number creation stuff in part taken from "create_phone.c".
---
--- Revision 1.6  2005/12/29 17:50:53  jsedwards
--- Commented out printf debugging statements, that aren't useful now.
---
--- Revision 1.5  2005/12/27 18:32:36  jsedwards
--- Changed to look up class definition instead of using a fixed file name.
--- Also changed so that object id is random instead of based upon contents.
---
--- Revision 1.4  2005/12/24 16:18:26  jsedwards
--- Removed "host" id from object references (ObjRef).  Host redirection will
--- be done using a "redirection" object in the future.
---
--- Revision 1.3  2005/12/21 23:31:07  jsedwards
--- Added create_phone_number, find_phone_number, check phone number, etc.
---
--- Revision 1.2  2005/12/21 17:10:31  jsedwards
--- Add 'nwos' to 'create_all_area_codes' routine name.
---
--- Revision 1.1  2005/12/21 16:55:01  jsedwards
--- Initial version that adds all US area codes.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
