@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2005-2008  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--               Copyright (C) 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,53 +17,33 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: recrypt.c,v $
--- Revision 1.7  2008/12/27 15:00:29  jsedwards
--- Merged from alpha_29_5_branch back into main trunk.
---
--- Revision 1.6.2.2  2008/12/23 11:51:23  jsedwards
--- Fix Bug #2026708 - change to use strlcpy instead of strncpy.
---
--- Revision 1.6.2.1  2008/12/23 11:03:15  jsedwards
--- Changed to use strlcpy instead of strcpy.
---
--- Revision 1.6  2008/09/01 00:10:54  jsedwards
--- Fix copyright year.  NO code changes.
---
--- Revision 1.5  2008/08/31 21:53:53  jsedwards
--- Added an assert around calls to nwos_read_variable_sized_object_from_disk
--- and nwos_read_object_from_disk because now they return false when they fail
--- instead of asserting themselves.
---
--- Revision 1.4  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.3  2006/12/01 14:31:31  jsedwards
--- Changed to use new malloc_reference_list and free_reference_list functions
--- instead of inlining the code.
---
--- Revision 1.2  2006/10/26 01:51:28  jsedwards
--- Merged alpha_05_branch back into main trunk.
---
--- Revision 1.1.2.4  2006/10/25 12:22:29  jsedwards
--- Changed C_struct_class_definition to C_struct_Class_Definition so the case
--- is consistent with all the other C_struct objects.
---
--- Revision 1.1.2.3  2006/09/02 12:45:07  jsedwards
--- Change function "nwos_object_size" to "nwos_reference_list_size".
---
--- Revision 1.1.2.2  2006/08/18 12:53:48  jsedwards
--- Changed hard coded 512 for block size to FILE_BLOCK_SIZE.
---
--- Revision 1.1.2.1  2006/07/28 04:02:40  jsedwards
--- This is a hack to change the passphrase on an entire set of objects.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.  Also this file was created in the
+--   alpha_05_branch so check the logs for this file in it too.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
@@ -76,7 +54,6 @@
 #include <string.h>
 
 #include "objectify.h"
-#include "objectify_private.h"
 #include "crc32.h"
 
 #define MAX_NAME_SIZE 64
@@ -323,8 +300,9 @@ static void write_object_to_disk(ObjRef* ref, void* object, size_t size)
     char msg[OBJ_PATH_SIZE + 16];
     FILE* fp;
     char log_msg[128];
+    uint8 block[FILE_BLOCK_SIZE];
 
-    assert(!nwos_object_exists(ref));
+    assert(!nwos_read_block(ref, block));
 
     ref_to_path(ref, path);
 #if 0
