@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2004-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--         Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,199 +17,33 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: reference_list.c,v $
--- Revision 1.47  2009/06/13 12:53:14  jsedwards
--- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
---
--- Revision 1.45.2.1  2009/05/23 03:48:03  jsedwards
--- Moved endif so that nwos_flush_dirty_ref_lists get compiled in public mode.
---
--- Revision 1.46  2009/04/19 14:20:05  jsedwards
--- Added include of chunk_info.h file to define nwos_hash_ref.
---
--- Revision 1.45  2009/03/14 20:25:52  jsedwards
--- Fix bug introduced in previous check-in where seq was not set to block_num.
---
--- Revision 1.44  2009/03/14 19:28:34  jsedwards
--- Added include of security.h file and renamed read and write object and
--- encrypt or decrypt functions to read and write block.
---
--- Revision 1.43  2009/03/14 03:31:24  jsedwards
--- Added include of bit_map.h file.
---
--- Revision 1.42  2009/03/13 13:10:15  jsedwards
--- Added includes for log.h and reference_list.h files.  Also moved
--- MAX_REFS_IN_REF_LIST, MAX_REFS_IN_SIDECAR, Ref_List_Extra_Block, and
--- Ref_List_First_Block.
---
--- Revision 1.41  2009/03/08 19:21:49  jsedwards
--- Surrounded nwos_remove_from_reference_list and nwos_remove_from_references
--- with ifndef PUBLIC_MODE so they won't be compiled in public mode.
---
--- Revision 1.40  2009/03/08 00:52:42  jsedwards
--- Changed include objectify_private.h to disk_io.h and added include
--- class_definition.h.
---
--- Revision 1.39  2009/01/24 18:16:04  jsedwards
--- Added test to nwos_remove_from_reference_list to verify the last_block
--- pointer is valid after changing the reference list.  Also undefined
--- VERIFY_LAST_BLOCK_POINTER so that verification is normally disabled.
---
--- Revision 1.38  2009/01/24 12:35:49  jsedwards
--- Fix Bug #2392531 - Added new verify_last_block_pointer function and removed
--- loop to find last block from nwos_add_to_reference_list.
---
--- Revision 1.37  2009/01/22 12:36:31  jsedwards
--- Added last_block to cache.
---
--- Revision 1.36  2008/08/02 04:31:25  jsedwards
--- Finished changes to read a reference list that has the old encryption at
--- the beginning and later on has blocks with the new encryption.
---
--- Revision 1.35  2008/08/01 22:10:53  jsedwards
--- Changed to check both the class definition and the checksum instead of just
--- the class definition.  Also fixed to not re-read the block if it is a public
--- reference list.
---
--- Revision 1.34  2008/08/01 00:13:18  jsedwards
--- Changed to try old decryption algorithm if class definition doesn't match
--- nwos_reference_list_class_ref after reading with new decryption algorithm.
---
--- Revision 1.33  2008/07/19 13:59:15  jsedwards
--- Changed nwos_add_to_references to call nwos_get_object_class_without_update
--- instead of nwos_get_object_class.  This fixed a problem where cloning the
--- updated file class definition called this function to add the new reference
--- to the class definition reference list.  But when this called
--- nwos_get_object_class, it called get_file_00x_reference, which called
--- get_file_references, which called find_private_class_defintion, which reads
--- the class defintion reference list.  Unfortunately that was what was being
--- added with this function so it wasn't in the list yet so it could not find
--- the "FILE" class definition, then later puked because it didn't have the
--- private FILE class definitions in the file_references array.
---
--- Revision 1.32  2008/05/06 13:27:26  jsedwards
--- Added assert around calls to nwos_read_object_from_disk_and_decrypt because
--- it now returns true or false if it read the object okay.  Before it asserted
--- itself if it could not read the block.
---
--- Revision 1.31  2007/09/16 15:00:48  jsedwards
--- Fixed case where entry to be removed is in first block and there are two
--- or more blocks in the list.
---
--- Revision 1.30  2007/09/16 13:30:50  jsedwards
--- Added function header for remove_from_reference_list that explains the
--- different cases, added and changed some comments in the code.  NO code
--- changes.
---
--- Revision 1.29  2007/09/16 03:53:56  jsedwards
--- Added code to handle moving entries down one and rewriting intermediate
--- blocks.
---
--- Revision 1.28  2007/09/15 20:53:45  jsedwards
--- Changes to handle removing a block when an entry is removed in the previous
--- block and there is only one entry in the last block.
---
--- Revision 1.27  2007/09/15 19:36:56  jsedwards
--- Added code to deal with removing block because there was only one entry in
--- it, for blocks beyond the second block.
---
--- Revision 1.26  2007/09/15 18:59:26  jsedwards
--- Moved ivec out of Block_Cache and into First_Block and Extra_Block
--- structures so we have the ivec for every block.  Needed when removing
--- entries from a reference list and need to write blocks other than the last.
---
--- Revision 1.25  2007/09/15 16:32:59  jsedwards
--- Added code in remove_from_reference_list to deal with special case where
--- there is two blocks in the list, there is only one entry in the second
--- list and that entry is the one that has to be removed.
---
--- Revision 1.24  2007/09/15 14:04:36  jsedwards
--- Added code to remove_from_reference_list to deal with the entry being in
--- the first block if there is only one entry after the first block and so
--- the second block can be eliminated.
---
--- Revision 1.23  2007/09/14 13:27:32  jsedwards
--- Removed unused ivec variable in write_reference_list.
---
--- Revision 1.22  2007/09/14 12:56:12  jsedwards
--- Changed so that when removing entry from reference list that only has one
--- block, it moves them down by one instead of copying the last over it.
---
--- Revision 1.21  2007/09/14 00:07:07  jsedwards
--- Added code to nwos_remove_from_reference_list to remove entry as long as
--- it is in last block.
---
--- Revision 1.20  2007/08/30 03:58:01  jsedwards
--- Moved #endif to the correct place (mistake in previous check-in).
---
--- Revision 1.19  2007/08/29 04:20:17  jsedwards
--- Put #ifdefs around two more log messages of add to references so normally
--- the are not printed.
---
--- Revision 1.18  2007/07/11 02:45:08  jsedwards
--- Fix bug in create_reference_list where not enough memory was allocated for
--- the first block.
---
--- Revision 1.17  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.16  2007/06/30 14:14:01  jsedwards
--- Added #ifdef around logging of add_to_reference_list, so it is off by default.
---
--- Revision 1.15  2007/05/28 16:03:25  jsedwards
--- Added 'remove_from_references' and 'remove_from_reference_list' functions.
---
--- Revision 1.14  2007/05/28 09:06:48  jsedwards
--- Fixed the comment added in previous revision.  Still NO code changes.
---
--- Revision 1.13  2007/05/28 09:04:53  jsedwards
--- Added comment, NO code changes.
---
--- Revision 1.12  2007/02/11 14:32:39  jsedwards
--- Changed calls to 'sprintf' to 'snprintf' so OpenBSD won't whine so much.
---
--- Revision 1.11  2007/01/09 03:02:34  jsedwards
--- Fixed bug where if there were exactly 54 entries in the reference list it
--- wrote a random value into the next block pointer (which has to be null in
--- this case).
---
--- Revision 1.10  2007/01/05 13:44:15  jsedwards
--- Added asserts to verify the reference_list is being created in the correct
--- space (public/private).
---
--- Revision 1.9  2006/12/29 01:49:45  jsedwards
--- Fix compile error.
---
--- Revision 1.8  2006/12/28 23:17:23  jsedwards
--- Removed line feed from messages to go into the log.
---
--- Revision 1.7  2006/12/25 12:18:34  jsedwards
--- Fix error in printing reference to log in add_reference.
---
--- Revision 1.6  2006/12/20 13:12:48  jsedwards
--- Added malloc_class_reference_list function (untested).
---
--- Revision 1.5  2006/12/15 15:01:38  jsedwards
--- Changed for only two disk areas (Public and Private-Encrypted).
---
--- Revision 1.4  2006/12/05 13:56:33  jsedwards
--- Fix so that it doesn't fill unencrypted blocks with random data.
---
--- Revision 1.3  2006/12/04 04:42:05  jsedwards
--- Changed to call new generate_new_id_of_same_type function.
---
--- Revision 1.2  2006/12/01 14:24:31  jsedwards
--- Added malloc and free reference list functions.
---
--- Revision 1.1  2006/11/11 15:21:40  jsedwards
--- Moved all reference list code out of objectify.c and into this file.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file and the objectify.c file which this
+--   file was derived from.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
