@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2007-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                  Copyright (C) 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,78 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: remove_file.c,v $
--- Revision 1.17  2009/06/13 11:37:25  jsedwards
--- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
---
--- Revision 1.16.2.1  2009/06/06 15:18:44  jsedwards
--- Fix Bug #2740516 - Changed to check return value from fgets and exit if end
--- of file or error is returned.
---
--- Revision 1.16  2009/03/10 10:23:52  jsedwards
--- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
---
--- Revision 1.15  2009/03/07 14:52:19  jsedwards
--- Changed #include objectify_private.h to objectify.h and changed to call new
--- backup_is_enabled function instead of checking to see if there is a backup
--- path.
---
--- Revision 1.14  2009/01/22 11:34:10  jsedwards
--- Fixed year in copyright.  NO code changes.
---
--- Revision 1.13  2009/01/20 11:50:10  jsedwards
--- Changed warning text about using this program and added test to see if
--- backup (.dif) files are enabled and terminate execution if they are.
---
--- Revision 1.12  2008/09/06 15:34:23  jsedwards
--- Changed to use TEST_ENVIRONMENT_VARIABLE.
---
--- Revision 1.11  2008/09/06 13:36:50  jsedwards
--- Change pass phrase from TEST_PASS_PHRASE define to environment variable.
---
--- Revision 1.10  2008/09/01 03:13:44  jsedwards
--- Change for new nwos_initialize_objectify calling convention (doesn't pass
--- back root_object_reference anymore) and removed call to nwos_set_root_object
--- because initialize calls it now.
---
--- Revision 1.9  2008/08/31 21:53:53  jsedwards
--- Added an assert around calls to nwos_read_variable_sized_object_from_disk
--- and nwos_read_object_from_disk because now they return false when they fail
--- instead of asserting themselves.
---
--- Revision 1.8  2008/08/30 12:46:17  jsedwards
--- Removed code and variables to read pass phrase and pass it to initialize,
--- and change parameters passed to initialize.
---
--- Revision 1.7  2008/08/02 10:51:11  jsedwards
--- Added call to log arguments.
---
--- Revision 1.6  2008/02/03 01:00:54  jsedwards
--- Changed DEFAULT_TYPE_RW to READ_WRITE.
---
--- Revision 1.5  2007/09/16 15:52:55  jsedwards
--- Added warning and confirmation before removing file.
---
--- Revision 1.4  2007/09/16 15:15:57  jsedwards
--- Remove warning comment which is no longer pertinent and with functions and
--- variables that weren't used.
---
--- Revision 1.3  2007/09/15 21:16:15  jsedwards
--- Put SHA1 code back the way it was in the previous version (it was correct
--- in the first place) and added code to remove a SHA256 sum if it exists.
---
--- Revision 1.2  2007/09/15 21:00:17  jsedwards
--- Changed to handle the case where an old file doesn't have a SHA1 checksum.
---
--- Revision 1.1  2007/07/27 15:15:29  jsedwards
--- Initial version NOT fully functional.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
