@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2007-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                  Copyright (C) 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,98 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: rename_file.c,v $
--- Revision 1.22  2009/07/19 13:21:44  jsedwards
--- Added ifdef VERIFY_WRITE around code that reads back objects to verify they
--- were written correctly, they don't work correctly when nwos_write_block
--- modifies the upper 4 bytes of the reference in the block.
---
--- Revision 1.21  2009/03/19 11:38:21  jsedwards
--- Wrapped call to nwos_set_security_level with ifdef CHANGE_SECURITY_TO_DENSITY
--- because what was called security level stuff is temporarily disabled.
---
--- Revision 1.20  2009/03/10 09:38:18  jsedwards
--- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
---
--- Revision 1.19  2009/03/08 00:13:54  jsedwards
--- Changed include objectify_private.h to objectify.h.
---
--- Revision 1.18  2008/09/01 03:13:44  jsedwards
--- Change for new nwos_initialize_objectify calling convention (doesn't pass
--- back root_object_reference anymore) and removed call to nwos_set_root_object
--- because initialize calls it now.
---
--- Revision 1.17  2008/08/31 21:53:54  jsedwards
--- Added an assert around calls to nwos_read_variable_sized_object_from_disk
--- and nwos_read_object_from_disk because now they return false when they fail
--- instead of asserting themselves.
---
--- Revision 1.16  2008/08/30 12:46:18  jsedwards
--- Removed code and variables to read pass phrase and pass it to initialize,
--- and change parameters passed to initialize.
---
--- Revision 1.15  2008/02/27 05:46:14  jsedwards
--- Changed so that either --keep-history or --no-history must be specified,
--- it will not default to either one.
---
--- Revision 1.14  2008/02/03 01:00:55  jsedwards
--- Changed DEFAULT_TYPE_RW to READ_WRITE.
---
--- Revision 1.13  2008/01/04 04:21:37  jsedwards
--- Added call to nwos_log_arguments.
---
--- Revision 1.12  2007/10/07 03:43:50  jsedwards
--- Renamed 'nwos_set_block_estimate' to 'nwos_check_blocks_available' and
--- changed to exit gracefully if not enough space available.
---
--- Revision 1.11  2007/10/04 11:34:16  jsedwards
--- Fixed compiler warning about "no_history" possibly being used uninitialized.
---
--- Revision 1.10  2007/09/23 13:20:03  jsedwards
--- Added code to optionally do the rename the way it was done in Revision 1.5
--- and before, by overwriting the string in the path object.
---
--- Revision 1.9  2007/09/23 13:10:16  jsedwards
--- Changed handling of arguments so that the regular code doesn't explicitly
--- access argv[1] or argv[2] but through a pointer.
---
--- Revision 1.8  2007/09/23 12:23:53  jsedwards
--- Moved code out of main that renamed the file by creating a new path, into
--- new 'create_new_path' function.
---
--- Revision 1.7  2007/09/02 19:47:25  jsedwards
--- Added call to set the block estimate.
---
--- Revision 1.6  2007/08/25 20:16:11  jsedwards
--- Changed completely so that instead of just changing the string in the Path
--- object it creates a new path object with the new string and a new Fath and
--- File Association object and hooks up the next_verision and prev_version
--- links.
---
--- Revision 1.5  2007/08/25 00:45:11  jsedwards
--- Added code to print error and exit if the new file name is already in the
--- system.
---
--- Revision 1.4  2007/08/24 23:59:06  jsedwards
--- Changed so that file_is_used_in_disc_list is only called if a private
--- disc_list class exists (meaning there are private disc_list objects).
---
--- Revision 1.3  2007/08/24 23:48:05  jsedwards
--- Moved code to find out if a path (file name) was used in a disc_list and
--- made it into a new function: file_is_used_in_disc_list().
---
--- Revision 1.2  2007/08/24 19:44:51  jsedwards
--- Added code to print disc_list id instead of reference number.
---
--- Revision 1.1  2007/08/24 19:11:18  jsedwards
--- Initial version.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
