@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2004-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--            Copyright (C) 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,127 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: security.c,v $
--- Revision 1.27  2009/04/13 13:25:24  jsedwards
--- Change include of gen_id.h file to new storage.h file which now contains
--- the nwos_read_block and nwos_write_block functions.
---
--- Revision 1.26  2009/04/12 00:41:17  jsedwards
--- Added include for gen_id.h file which now contains the nwos_read_block and
--- nwos_write_block function declarations.
---
--- Revision 1.25  2009/03/14 19:08:10  jsedwards
--- Moved security related variables and functions from objectify.c file.
---
--- Revision 1.24  2009/03/13 13:14:57  jsedwards
--- Removed include of objectify.h file and added includes for strlcxx.h and
--- types.h files.
---
--- Revision 1.23  2009/03/07 20:17:19  jsedwards
--- Removed #include of objectify_private.h, not needed.
---
--- Revision 1.22  2008/12/27 15:00:29  jsedwards
--- Merged from alpha_29_5_branch back into main trunk.
---
--- Revision 1.21.2.1  2008/12/23 11:57:48  jsedwards
--- Fix Bug #2026708 - change to use strlcpy instead of strncpy.
---
--- Revision 1.21  2008/09/13 15:09:27  jsedwards
--- Fix Bug #2103915 - pass phrase now obscured in "show" mode.
---
--- Revision 1.20  2008/09/07 14:42:46  jsedwards
--- Fixed so pass phrase from environment variable works correctly.
---
--- Revision 1.19  2008/09/07 12:38:40  jsedwards
--- Made display_help function, changed Escape to not exit, and simplified the
--- backspace code.
---
--- Revision 1.18  2008/09/07 12:28:01  jsedwards
--- Added 'last' and 'none' display modes and 'quit' or 'exit' to exit the
--- program.
---
--- Revision 1.17  2008/09/07 11:22:24  jsedwards
--- Changed to have 'show' and 'hide' modes for pass phrase.
---
--- Revision 1.16  2008/09/07 03:18:55  jsedwards
--- First attempt at reading pass phrase in non-canonical mode.
---
--- Revision 1.15  2008/09/06 15:34:24  jsedwards
--- Changed to use TEST_ENVIRONMENT_VARIABLE.
---
--- Revision 1.14  2008/09/06 13:36:50  jsedwards
--- Change pass phrase from TEST_PASS_PHRASE define to environment variable.
---
--- Revision 1.13  2008/03/12 04:06:44  jsedwards
--- Changed to use the GNU MD5 context and functions instead of the RSA context
--- and functions.
---
--- Revision 1.12  2007/09/15 14:31:58  jsedwards
--- Added conditional code so that if TEST_PASS_PHRASE is defined, it will use
--- it instead of asking for pass phrase from user.
---
--- Revision 1.11  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.10  2007/01/16 14:12:02  jsedwards
--- Changed to use MD5 and SHA1 to generate key from short pass phrases.
---
--- Revision 1.9  2007/01/16 13:37:22  jsedwards
--- Eliminated get_short_key_from_password and made get_key_from_password call
--- convert_short_pass_phrase_to_reference if the password entered was too
--- short by itself.
---
--- Revision 1.8  2007/01/16 02:27:04  jsedwards
--- Added new routine for short pass phrases.
---
--- Revision 1.7  2006/12/01 14:37:23  jsedwards
--- Fix the year in the copyright.
---
--- Revision 1.6  2006/11/11 12:01:06  jsedwards
--- Update e-mail address to something that works.
---
--- Revision 1.5  2006/10/26 01:51:29  jsedwards
--- Merged alpha_05_branch back into main trunk.
---
--- Revision 1.4.2.4  2006/09/09 13:03:33  jsedwards
--- Moved "create_root_object" routine from security.c to objectify.c so that
--- the security module didn't have references to so many other parts of the
--- system.
---
--- Revision 1.4.2.3  2006/09/06 13:15:25  jsedwards
--- Removed nwos_seed_sequence function and instead pass pointers to the values
--- in the call to next_sequence function.
---
--- Revision 1.4.2.2  2006/09/02 15:04:30  jsedwards
--- Add reference list class reference to root object because now it has to
--- read the reference list to get it's size and we can't easily read it
--- without the read routine verifying it's class.
---
--- Revision 1.4.2.1  2006/09/02 01:12:25  jsedwards
--- Add root object reference in call to fill_in_common_header so it can put
--- it into the header.
---
--- Revision 1.4  2005/12/30 03:16:12  jsedwards
--- Changed "Password" prompt to "Pass phrase".
---
--- Revision 1.3  2005/12/28 13:03:24  jsedwards
--- Added sequence generator (from Fine random_number_generator).  Changed the
--- get reference from password routine to get a variable length key from the
--- password.  It's actually more like a pass phrase now because it requires
--- the input to be long enough to get enough bits to fill up the key.
---
--- Revision 1.2  2005/12/27 19:45:27  jsedwards
--- Added routine to create a root object.
---
--- Revision 1.1  2005/12/27 18:02:42  jsedwards
--- Initial version converts a pass phrase into an object reference (ObjRef).
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
