@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2005-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--            Copyright (C) 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,142 +17,33 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: spelling.c,v $
--- Revision 1.30  2009/07/19 13:21:44  jsedwards
--- Added ifdef VERIFY_WRITE around code that reads back objects to verify they
--- were written correctly, they don't work correctly when nwos_write_block
--- modifies the upper 4 bytes of the reference in the block.
---
--- Revision 1.29  2009/03/10 10:39:39  jsedwards
--- Moved MAX_SPELLING_SIZE to the objectify.h file and renamed to
--- MAX_SPELLING_OBJ_SIZE.
---
--- Revision 1.28  2009/03/10 02:23:02  jsedwards
--- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
---
--- Revision 1.27  2009/03/07 20:17:19  jsedwards
--- Removed #include of objectify_private.h, not needed.
---
--- Revision 1.26  2008/09/01 00:10:55  jsedwards
--- Fix copyright year.  NO code changes.
---
--- Revision 1.25  2008/08/31 21:53:54  jsedwards
--- Added an assert around calls to nwos_read_variable_sized_object_from_disk
--- and nwos_read_object_from_disk because now they return false when they fail
--- instead of asserting themselves.
---
--- Revision 1.24  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.23  2007/05/22 02:38:42  jsedwards
--- Change 'create_spelling' to 'create_public_spelling'.
---
--- Revision 1.22  2007/04/22 13:51:29  jsedwards
--- Remove old debugging code and a superfluous line of code.
---
--- Revision 1.21  2007/04/02 04:08:27  jsedwards
--- Fixed to operate in private mode.
---
--- Revision 1.20  2007/01/08 14:26:23  jsedwards
--- Added code to change class of cloned spelling objects to private class.
---
--- Revision 1.19  2007/01/06 19:32:08  jsedwards
--- Split find_spelling into find_public_spelling and find_private_spelling.
--- Added create_private_spelling function.
---
--- Revision 1.18  2006/12/21 12:59:47  jsedwards
--- Hack to make it compile with new split public and private classes,
--- NON-FUNCTIONAL!
---
--- Revision 1.17  2006/12/09 16:02:45  jsedwards
--- Removed old upgrade from 0004 to 0005 routine.
---
--- Revision 1.16  2006/12/01 14:31:31  jsedwards
--- Changed to use new malloc_reference_list and free_reference_list functions
--- instead of inlining the code.
---
--- Revision 1.15  2006/11/18 15:09:10  jsedwards
--- Added "max_size" parameter to read_variable_sized_object_from_disk because
--- objects are no longer limited to one file block.
---
--- Revision 1.14  2006/11/11 12:01:07  jsedwards
--- Update e-mail address to something that works.
---
--- Revision 1.13  2006/10/26 01:51:29  jsedwards
--- Merged alpha_05_branch back into main trunk.
---
--- Revision 1.12.2.5  2006/10/25 12:22:30  jsedwards
--- Changed C_struct_class_definition to C_struct_Class_Definition so the case
--- is consistent with all the other C_struct objects.
---
--- Revision 1.12.2.4  2006/09/03 11:05:45  jsedwards
--- Changed name of spelling_class_ref function to get_spelling_class_ref and
--- class_ref variable to spelling_class_ref.
---
--- Revision 1.12.2.3  2006/09/01 13:27:20  jsedwards
--- Changed "nwos_object_size" to "nwos_reference_list_size" and added the
--- object reference to "nwos_fill_in_common_header" so it can put the "id"
--- in the header now.
---
--- Revision 1.12.2.2  2006/08/18 12:53:48  jsedwards
--- Changed hard coded 512 for block size to FILE_BLOCK_SIZE.
---
--- Revision 1.12.2.1  2006/08/16 12:51:24  jsedwards
--- Added a cast so new versions of GCC won't complain about the signedness of
--- a pointer.
---
--- Revision 1.12  2006/01/12 02:53:45  jsedwards
--- Changed so letters are always stored in lower case.  Added upgrade routine
--- to change all letters in a 0004 object to lower case.
---
--- Revision 1.11  2005/12/29 17:50:53  jsedwards
--- Commented out printf debugging statements, that aren't useful now.
---
--- Revision 1.10  2005/12/29 17:28:16  jsedwards
--- Changed so that a spelling object is variable sized depending upon it's
--- contents.  That way when it is written to disk the write routine can fill
--- in the remaining data up to 512 bytes with random data.
---
--- Revision 1.9  2005/12/27 18:26:57  jsedwards
--- Added special routine for the "big_bang" to set the class reference.
--- Changed to look up class definition instead of using a fixed file name.
--- Also changed so that object id is random instead of based upon contents.
---
--- Revision 1.8  2005/12/24 16:18:26  jsedwards
--- Removed "host" id from object references (ObjRef).  Host redirection will
--- be done using a "redirection" object in the future.
---
--- Revision 1.7  2005/12/21 03:59:02  jsedwards
--- Added check to make sure the counts match before comparing the characters.
---
--- Revision 1.6  2005/12/11 16:34:56  jsedwards
--- Fixed error message to say "spelling" instead of "year".
--- Split "find_spelling" function out of "create_spelling" function.
---
--- Revision 1.5  2005/12/10 15:03:36  jsedwards
--- Fixed header to say the GPL is in the LICENSE file instead of COPYING.
---
--- Revision 1.4  2005/12/05 05:22:46  jsedwards
--- Change to call read_reference_list_from_disk for reference lists instead
--- of read_object_from_disk.  Also moved calculating checksums down to just
--- before writing object, so that no changes occur after computing them.
---
--- Revision 1.3  2005/12/04 04:13:03  jsedwards
--- Added 'nwos' prefix to create_xxxx function names and eliminated the
--- 'referring' object parameter from all of them.
---
--- Revision 1.2  2005/12/03 22:13:28  jsedwards
--- Changed to create a spelling object.
---
--- Revision 1.1  2005/12/03 22:11:26  jsedwards
--- Initial version created from word.c.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file and the word.c file which this
+--   file was derived from.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
