@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2006-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--               Copyright (C) 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,94 +17,40 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-31 05:41:15 -0600 (Fri, 31 Jul 2009) $
+--   $Revision: 4212 $
 --
--- $Log: sync_archive.c,v $
--- Revision 1.21  2009/07/21 13:09:06  jsedwards
--- Fix Bug #2824790 - copied code from expand_sparse to increase number of
--- chunks in destination file.
---
--- Revision 1.20  2009/07/21 12:28:32  jsedwards
--- Added erase and start progress bar calls around printing of block with zero
--- reference warning code.
---
--- Revision 1.19  2009/07/21 12:21:10  jsedwards
--- Fix Bug #2824305 - changed to move bit map outside of chunk.
---
--- Revision 1.18  2009/07/12 01:57:23  jsedwards
--- Changed used_private_blocks to 64 bits and added 'll' in print statements
--- for when printing number of blocks.
---
--- Revision 1.17  2009/07/05 00:50:32  jsedwards
--- Changed to include the new header.h file instead of the disk_io.h file.
---
--- Revision 1.16  2009/06/13 12:53:14  jsedwards
--- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
---
--- Revision 1.11.2.1  2009/06/06 15:20:32  jsedwards
--- Fix Bug #2740516 - Changed to check return value from fgets.
---
--- Revision 1.15  2009/04/21 12:14:13  jsedwards
--- Changed to byte swap chunk_info 64 bit references and 32 bit indexes.
---
--- Revision 1.14  2009/04/14 12:32:17  jsedwards
--- Changed to call new terminate_storage function instead of terminate_disk_io.
---
--- Revision 1.13  2009/04/14 11:59:38  jsedwards
--- Changed to call new initialize_storage function instead of initialize_disk_io.
---
--- Revision 1.12  2009/04/09 10:54:25  jsedwards
--- Changed to read total_chunks from source disk header instead of total_blocks.
---
--- Revision 1.11  2009/03/14 23:09:05  jsedwards
--- Added includes of the new backup.h and chunk_info.h files.
---
--- Revision 1.10  2009/03/14 11:43:21  jsedwards
--- Added includes for gen_id.h and user_config.h files.
---
--- Revision 1.9  2009/03/14 03:31:24  jsedwards
--- Added include of bit_map.h file.
---
--- Revision 1.8  2009/03/13 12:36:58  jsedwards
--- Added includes for config.h, log.h, and progress_bar.h files.  Also changed
--- to call nwos_terminate_disk_io instead of nwos_terminate_objectify (because
--- it calls nwos_initialize_disk_io, not nwos_initialize_objectify).
---
--- Revision 1.7  2009/03/08 00:06:18  jsedwards
--- Changed include objectify_private.h to disk_io.h.
---
--- Revision 1.6  2009/01/02 21:42:49  jsedwards
--- Fixed copyright year in header.  NO code changes.
---
--- Revision 1.5  2009/01/02 21:34:34  jsedwards
--- Changed so that it takes a source and a destination parameter instead of
--- using the default archive as the source.
---
--- Revision 1.4  2008/12/30 14:10:59  jsedwards
--- Fixed usage statement.
---
--- Revision 1.3  2008/12/30 13:46:24  jsedwards
--- Changed to call new set_private_objects_path function in user_config.c to
--- change to write the destination archive.
---
--- Revision 1.2  2008/12/30 13:41:56  jsedwards
--- Changed to set the private path environment variable.  Still doesn't work
--- because the environment variable has already been read by that point in time.
---
--- Revision 1.1  2008/12/30 13:36:35  jsedwards
--- Initial version created by combining compress_sparse.c and expand_sparce.c.
--- Does not work!
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file, the compress_sparse.c file and
+--   the expand_sparse.c file which it was derived from.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
 
 #include <assert.h>
 #include <fcntl.h>
+#include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -122,8 +66,10 @@
 #include "gen_id.h"
 #include "header.h"
 #include "log.h"
+#include "mem_alloc.h"
 #include "progress_bar.h"
 #include "storage.h"
+#include "strlcxx.h"           /* in case strlcpy and strlcat are not provided by the system */
 #include "user_config.h"
 
 
@@ -132,7 +78,20 @@ extern void nwos_set_private_objects_path(const char* path);
 
 static void print_usage(char *program)
 {
-    fprintf(stderr, "usage: %s source-archive destination-archive\n", program);
+    fprintf(stderr, "usage: %s [source-archive] destination-archive\n", program);
+}
+
+
+static bool control_c_received = false;
+
+static void control_c_handler(int signal_num)
+{
+    signal(SIGINT, SIG_DFL);    /* restore to default control-C handler */
+
+    fputs("^C", stdout);     /* indicate that control-C was received */
+    fflush(stdout);
+
+    control_c_received = true;
 }
 
 
@@ -162,29 +121,55 @@ int main(int argc, char* argv[])
     uint32 total_chunks;
     Chunk_Info* chunk_info;
     int blocks_with_bad_ids = 0;
+    char* source;
+    char* destination;
+    size_t source_len = 0;
 
 
     for (i = 0; i < SIZE_COUNTS; i++) counts[i] = 0;
 
-    if (argc != 3)
+    if (argc != 2 && argc != 3)
     {
 	print_usage(argv[0]);
 	exit(1);
     }
 
-    if (*argv[1] == '-' || *argv[2] == '-')
+    if (*argv[1] == '-' || (argc == 3 && *argv[2] == '-'))
     {
 	fprintf(stderr, "error: this program doesn't have any options\n");
 	print_usage(argv[0]);
 	exit(1);
     }
 
+    if (argc == 2)
+      {
+	source_len = strlen(nwos_get_private_objects_path()) + 1;
+
+	source = nwos_malloc(source_len);
+
+	strlcpy(source, nwos_get_private_objects_path(), source_len);
+
+	destination = argv[1];
+    }
+    else
+    {
+	source = argv[1];
+	destination = argv[2];
+    }
+
+    if (strcmp(source, destination) == 0)
+    {
+	fprintf(stderr, "Error: the source and destination cannot be the same!\n");
+	print_usage(argv[0]);
+	exit(1);
+    }
+
 
     nwos_log_arguments(argc, argv);
 
-    nwos_set_private_objects_path(argv[2]);
+    nwos_set_private_objects_path(destination);
 
-    assert(strcmp(nwos_get_private_objects_path(), argv[2]) == 0);
+    assert(strcmp(nwos_get_private_objects_path(), destination) == 0);
 
     nwos_initialize_storage(READ_WRITE, DEFAULT_FILE);
 
@@ -234,11 +219,11 @@ int main(int argc, char* argv[])
 
     /* Open the storage drive and verify the header info */
 
-    obj_file_desc = open(argv[1], O_RDONLY);
+    obj_file_desc = open(source, O_RDONLY);
 
     if (obj_file_desc < 0)
     {
-	perror(argv[1]);
+	perror(source);
 	exit(1);
     }
 
@@ -252,13 +237,13 @@ int main(int argc, char* argv[])
 
     if (memcmp(&block[0], MAGIC_NUMBER, 4) != 0)
     {
-	fprintf(stderr, "Missing magic number in disk header: %s\n", argv[1]);
+	fprintf(stderr, "Missing magic number in disk header: %s\n", source);
 	exit(1);
     }
 
     if (memcmp(&block[4], VERSION_STRING, 4) != 0)
     {
-	fprintf(stderr, "Incorrect version string in disk header: %s\n", argv[1]);
+	fprintf(stderr, "Incorrect version string in disk header: %s\n", source);
 	exit(1);
     }
 
@@ -337,10 +322,15 @@ int main(int argc, char* argv[])
 
     num_blocks = 0;
 
+    if (signal(SIGINT, control_c_handler) == SIG_ERR)
+    {
+	perror("setting SIGINT signal to catch control-C");
+    }
+
     nwos_start_progress_bar();
 
     // for now we can skip over public blocks because they should always stay the same
-    for (chunk_num = 0; chunk_num < used_chunks; chunk_num++)
+    for (chunk_num = 0; chunk_num < used_chunks && !control_c_received; chunk_num++)
     {
 	nwos_update_progress_bar((float)num_blocks / (float)used_private_blocks);
 
@@ -445,6 +435,11 @@ int main(int argc, char* argv[])
 	}
     }
 
+    if (signal(SIGINT, SIG_DFL) == SIG_ERR)
+    {
+	perror("setting SIGINT signal to default");
+    }
+
     nwos_finish_progress_bar();
 
     printf("Number of blocks: %d\n", num_blocks);
@@ -475,7 +470,12 @@ int main(int argc, char* argv[])
 	if (counts[i] > 0) printf("  %d: %u\n", i, counts[i]);
     }
 
-    return 0;
+    if (source_len > 0)
+    {
+	nwos_free(source);
+    }
+
+    return control_c_received;    /* exit with 0 if normal completion, exit with 1 if control-C was hit */
 }
 
 
