@@ -1,44 +1,50 @@
-# 
-#              This file is part of the New World OS project
-#                     Copyright (C) 2007 QRW Software
-#            J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
-#                       http://www.qrwsoftware.com
-#                       http://nwos.sourceforge.com
-# 
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-# 
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-# 
-#    You should have received a copy of the GNU General Public License
-#    along with this program, in the file LICENSE.  If not, see 
-#    <http://www.gnu.org/licenses/>.
-# 
-#    You can also contact me via paper mail at:
-# 
-#       QRW Software
-#       P.O. Box 27511
-#       Salt Lake City, UT 84127-0511, USA.
-# 
-# 
-#  This script runs a quick test of file importing and exporting.
-# 
-#  $Log: test_diff_compressed.sh,v $
-#  Revision 1.3  2009/07/21 13:38:03  jsedwards
-#  Partial fix of Bug #2824308 - added test of sync_archive.
 #
-#  Revision 1.2  2009/07/18 04:14:03  jsedwards
-#  Fix wrong name in print (echo) statement.
+#          This file is part of the New World OS and Objectify projects
+#                        Copyright (C) 2009  QRW Software
+#               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 #
-#  Revision 1.1  2009/07/10 11:24:09  jsedwards
-#  Initial version created from test_import_sizes.sh.
+#   This program is free software: you can redistribute it and/or modify
+#   it under the terms of the GNU General Public License as published by
+#   the Free Software Foundation, either version 3 of the License, or
+#   (at your option) any later version.
 #
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#   GNU General Public License for more details.
 #
+#   You should have received a copy of the GNU General Public License
+#   along with this program, in the file LICENSE.  If not, see 
+#   <http://www.gnu.org/licenses/>.
+#
+#   For the latest information, source code (SVN), releases, bug and feature
+#   request tracking go to:
+#      http://sourceforge.net/projects/objectify
+#
+#   For older bug tracking, releases and source code (CVS) prior to the
+#   Alpha_30 release go to:
+#      http://sourceforge.net/projects/nwos
+#
+#   Other related websites:
+#      http://www.qrwsoftware.com
+#      http://www.worldwide-database.org
+#
+#   You can also contact me via paper mail at:
+#
+#      QRW Software
+#      P.O. Box 27511
+#      Salt Lake City, UT 84127-0511, USA.
+#
+#   $Author: jsedwards $
+#   $Date: 2009-07-27 05:34:42 -0600 (Mon, 27 Jul 2009) $
+#   $Revision: 4196 $
+#
+#   NOTE: Subversion does not support the Log keyword so I have removed the
+#   logs that were here when I was using CVS.  Use the "svn log" command to
+#   see the revision history of this file.
+#   (See http://subversion.tigris.org/faq.html#log-in-source)
+# 
+
 
 export OBJECTIFY_TEST_ONLY_DO_NOT_USE="Diff Compressed Test"
 export OBJECTIFY_PRIVATE_PATH=/tmp/objectify_test/private.obj
@@ -330,9 +336,7 @@ echo "---------------------------"
 echo " prep a second archive..."
 echo "---------------------------"
 
-export OBJECTIFY_PRIVATE_PATH=/tmp/objectify_test/private2.obj
-
-if ! $EXEC/prep_disk --no-private; then
+if ! $EXEC/prep_disk --no-private /tmp/objectify_test/private2.obj; then
    echo ""
    echo "prep_disk failed"
    echo ""
@@ -345,7 +349,7 @@ sleep 2
 echo "---------------------"
 echo " sync archive..."
 echo "---------------------"
-if ! $EXEC/sync_archive /tmp/objectify_test/private.obj /tmp/objectify_test/private2.obj; then
+if ! $EXEC/sync_archive /tmp/objectify_test/private2.obj; then
    echo ""
    echo "sync_archive failed"
    echo ""
@@ -358,6 +362,9 @@ sleep 2
 echo "------------------------------"
 echo " compress second archive..."
 echo "------------------------------"
+
+export OBJECTIFY_PRIVATE_PATH=/tmp/objectify_test/private2.obj
+
 if ! $EXEC/compress_sparse /tmp/objectify_test/compressed-second; then
    echo ""
    echo "compress_sparse failed"
@@ -380,9 +387,133 @@ fi
 
 echo "PLEASE check above that there were no differences!"
 
+sleep 5
+
+
+echo "---------------------------"
+echo " prep a third archive..."
+echo "---------------------------"
+
+if ! $EXEC/prep_disk --no-private /tmp/objectify_test/private3.obj; then
+   echo ""
+   echo "prep_disk failed"
+   echo ""
+   exit 1
+fi
+
 sleep 2
 
 
+echo "---------------------"
+echo " sync archive..."
+echo "---------------------"
+if ! $EXEC/sync_archive /tmp/objectify_test/private2.obj /tmp/objectify_test/private3.obj; then
+   echo ""
+   echo "sync_archive failed"
+   echo ""
+   exit 1
+fi
+
+sleep 2
+
+
+echo "------------------------------"
+echo " compress third archive..."
+echo "------------------------------"
+
+export OBJECTIFY_PRIVATE_PATH=/tmp/objectify_test/private3.obj
+
+if ! $EXEC/compress_sparse /tmp/objectify_test/compressed-third; then
+   echo ""
+   echo "compress_sparse failed"
+   echo ""
+   exit 1
+fi
+
+
+sleep 2
+
+echo "-----------------------------------------------------"
+echo " verify first and third compressed are the same..."
+echo "-----------------------------------------------------"
+if ! $EXEC/diff_compressed /tmp/objectify_test/compressed-after /tmp/objectify_test/compressed-third; then
+   echo ""
+   echo "first and third compressed files differ"
+   echo ""
+   exit 1
+fi
+
+echo "PLEASE check above that there were no differences!"
+
+sleep 5
+
+
+echo "---------------------------"
+echo " prep a fourth archive..."
+echo "---------------------------"
+
+if ! $EXEC/prep_disk /tmp/objectify_test/private4.obj; then
+   echo ""
+   echo "prep_disk failed"
+   echo ""
+   exit 1
+fi
+
+sleep 2
+
+
+echo "-----------------------------------"
+echo " expand into non-empty archive..."
+echo "-----------------------------------"
+
+export OBJECTIFY_PRIVATE_PATH=/tmp/objectify_test/private4.obj
+
+if $EXEC/expand_sparse /tmp/objectify_test/patched-after; then
+   echo ""
+   echo "expand_sparse into non-empty archive succeeded"
+   echo ""
+   exit 1
+fi
+
+sleep 2
+
+
+echo "------------------------------------------"
+echo " sync archive into non-empty archive..."
+echo "------------------------------------------"
+if $EXEC/sync_archive /tmp/objectify_test/private3.obj /tmp/objectify_test/private4.obj; then
+   echo ""
+   echo "sync_archive into non-empty archive succeeded"
+   echo ""
+   exit 1
+fi
+
+sleep 2
+
+
+echo "------------------------------------------"
+echo " sync archive with duplicate path..."
+echo "------------------------------------------"
+if $EXEC/sync_archive /tmp/objectify_test/private4.obj; then
+   echo ""
+   echo "sync_archive with duplicate path succeeded"
+   echo ""
+   exit 1
+fi
+
+sleep 2
+
+echo "------------------------------------------"
+echo " sync archive with duplicate paths..."
+echo "------------------------------------------"
+if $EXEC/sync_archive /tmp/objectify_test/private3.obj /tmp/objectify_test/private3.obj; then
+   echo ""
+   echo "sync_archive with duplicate paths succeeded"
+   echo ""
+   exit 1
+fi
+
+
 
 echo ""
 echo "All tests passed!"
