@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2004-2008  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--         Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,69 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: time_stamp.h,v $
--- Revision 1.10  2008/05/21 14:20:42  jsedwards
--- Added nwos_time_stamp_to_string function.
---
--- Revision 1.9  2008/02/16 18:12:09  jsedwards
--- Added new nwos_time_stamp_is_zero inline function to test to see if a
--- time stamp is all zeros.
---
--- Revision 1.8  2007/10/22 03:53:26  jsedwards
--- Added include of sys/time.h to define struct timeval on some platforms.
---
--- Revision 1.7  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.6  2006/12/01 14:39:22  jsedwards
--- Fix the year in the copyright.
---
--- Revision 1.5  2006/11/11 12:01:07  jsedwards
--- Update e-mail address to something that works.
---
--- Revision 1.4  2006/10/26 01:51:29  jsedwards
--- Merged alpha_05_branch back into main trunk.
---
--- Revision 1.3.2.5  2006/09/14 11:43:45  jsedwards
--- Changed values in inlined functions from 'int' to 'uint'.
---
--- Revision 1.3.2.4  2006/09/13 13:33:22  jsedwards
--- Added static, inline functions to insert values into time stamp.  Also
--- added asserts to export functions.
---
--- Revision 1.3.2.3  2006/09/10 20:41:13  jsedwards
--- Added static inline routines to extract the individual values from a time
--- stamp.
---
--- Revision 1.3.2.2  2006/08/24 11:56:38  jsedwards
--- Added convert_time_struct_to_timeval routine.
---
--- Revision 1.3.2.1  2006/08/23 13:22:26  jsedwards
--- Added nwos_convert_timespec_to_time_stamp function.
---
--- Revision 1.3  2005/12/10 15:03:36  jsedwards
--- Fixed header to say the GPL is in the LICENSE file instead of COPYING.
---
--- Revision 1.2  2005/11/26 15:15:24  jsedwards
--- Added 'nwos' prefix to function name and changed parameter to TimeStamp
--- instead of uint8[8].
---
--- Revision 1.1.1.1  2005/11/25 12:44:27  jsedwards
--- Copied from 'lab'.
---
--- Revision 1.2  2005/11/23 20:22:02  jsedwards
--- Changed to store as 8 bytes instead of a 64 bit integer.  This has the
--- advantage of working the same for both big and little endian machines.
---
--- Revision 1.1  2004/10/31 18:23:39  jsedwards
--- Moved time stamp definitions from 'types.h' into here.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
