@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2006-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--               Copyright (C) 2006, 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,58 +17,33 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: update_files_0028.c,v $
--- Revision 1.11  2009/07/19 13:26:56  jsedwards
--- Change to include objectify.h instead of disk_io.h and wrapped call to
--- nwos_set_security_level with ifdef CHANGE_SECURITY_TO_DENSITY because what
--- was called security level stuff is temporarily disabled.
---
--- Revision 1.10  2009/07/19 13:21:44  jsedwards
--- Added ifdef VERIFY_WRITE around code that reads back objects to verify they
--- were written correctly, they don't work correctly when nwos_write_block
--- modifies the upper 4 bytes of the reference in the block.
---
--- Revision 1.9  2009/03/10 10:30:27  jsedwards
--- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
---
--- Revision 1.8  2009/03/08 00:37:42  jsedwards
--- Changed include objectify_private.h to disk_io.h.
---
--- Revision 1.7  2008/09/01 03:13:45  jsedwards
--- Change for new nwos_initialize_objectify calling convention (doesn't pass
--- back root_object_reference anymore) and removed call to nwos_set_root_object
--- because initialize calls it now.
---
--- Revision 1.6  2008/08/31 21:53:54  jsedwards
--- Added an assert around calls to nwos_read_variable_sized_object_from_disk
--- and nwos_read_object_from_disk because now they return false when they fail
--- instead of asserting themselves.
---
--- Revision 1.5  2008/08/30 12:46:20  jsedwards
--- Removed code and variables to read pass phrase and pass it to initialize,
--- and change parameters passed to initialize.
---
--- Revision 1.4  2008/07/19 14:11:30  jsedwards
--- Added call to set security level in case updated FILE class is created and
--- call find_or_create FILE class instead of just find FILE class so that the
--- updated FILE class will be cloned if it hasn't been already.
---
--- Revision 1.3  2008/05/24 01:59:18  jsedwards
--- Changed to log arguments instead of disabling logging.
---
--- Revision 1.2  2008/05/21 11:43:55  jsedwards
--- Added code to update the objects and write them back to disk.
---
--- Revision 1.1  2008/05/20 13:43:12  jsedwards
--- Initial version created from attic/fix_img_files.c, which was created from
--- list_files.c.  This version only scans the files does NOT update them.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file, the attic/fix_img_files.c file
+--   and the list_files.c file which it was derived from.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
