@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2007-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                  Copyright (C) 2007, 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,41 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: url.c,v $
--- Revision 1.8  2009/07/19 13:21:44  jsedwards
--- Added ifdef VERIFY_WRITE around code that reads back objects to verify they
--- were written correctly, they don't work correctly when nwos_write_block
--- modifies the upper 4 bytes of the reference in the block.
---
--- Revision 1.7  2009/03/10 11:53:43  jsedwards
--- Moved MAX_URL_SIZE to the objectify.h file and renamed to MAX_URL_OBJ_SIZE.
---
--- Revision 1.6  2009/03/10 02:36:08  jsedwards
--- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
---
--- Revision 1.5  2009/03/08 00:13:54  jsedwards
--- Changed include objectify_private.h to objectify.h.
---
--- Revision 1.4  2008/09/01 00:10:55  jsedwards
--- Fix copyright year.  NO code changes.
---
--- Revision 1.3  2008/08/31 21:53:54  jsedwards
--- Added an assert around calls to nwos_read_variable_sized_object_from_disk
--- and nwos_read_object_from_disk because now they return false when they fail
--- instead of asserting themselves.
---
--- Revision 1.2  2007/07/01 19:44:12  jsedwards
--- Upgrade to GPLv3.
---
--- Revision 1.1  2007/04/22 14:25:45  jsedwards
--- Initial version.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
