@@ -1,9 +1,7 @@
 /*
---             This file is part of the New World OS project
---                 Copyright (C) 2008-2009  QRW Software
---           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
---                      http://www.qrwsoftware.com
---                      http://nwos.sourceforge.com
+--          This file is part of the New World OS and Objectify projects
+--                     Copyright (C) 2008, 2009  QRW Software
+--               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
 --   it under the terms of the GNU General Public License as published by
@@ -19,79 +17,32 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
+--   For the latest information, source code (SVN), releases, bug and feature
+--   request tracking go to:
+--      http://sourceforge.net/projects/objectify
+--
+--   For older bug tracking, releases and source code (CVS) prior to the
+--   Alpha_30 release go to:
+--      http://sourceforge.net/projects/nwos
+--
+--   Other related websites:
+--      http://www.qrwsoftware.com
+--      http://www.worldwide-database.org
+--
 --   You can also contact me via paper mail at:
 --
 --      QRW Software
 --      P.O. Box 27511
 --      Salt Lake City, UT 84127-0511, USA.
 --
+--   $Author: jsedwards $
+--   $Date: 2009-07-25 17:25:15 -0600 (Sat, 25 Jul 2009) $
+--   $Revision: 4184 $
 --
--- $Log: user_config.c,v $
--- Revision 1.18  2009/03/14 04:08:02  jsedwards
--- Removed include of disk_io.h file and added includes for assert.h and
--- user_config.h files.
---
--- Revision 1.17  2009/03/13 13:17:26  jsedwards
--- Removed include of objectify.h and added includes for config.h, disk_io.h,
--- log.h, and strlcxx.h files.
---
--- Revision 1.16  2009/01/02 21:44:29  jsedwards
--- Added code to read the configuration before changing the private path so
--- that it won't be overwritten.
---
--- Revision 1.15  2008/12/30 12:52:59  jsedwards
--- Added set_private_objects_path function to allow changing the path for the
--- sync_archive program.
---
--- Revision 1.14  2008/08/24 14:41:13  jsedwards
--- Changed DEFAULT_LOG_FILE_PATH to NULL, not doing a default log file anymore.
---
--- Revision 1.13  2008/06/08 16:33:08  jsedwards
--- Added #ifdef HTTP around code that tries to open a config file in the user's
--- home directory, because when running under apache $HOME isn't defined.
---
--- Revision 1.12  2008/02/24 13:24:33  jsedwards
--- Fix so that if DEFAULT_USER_CONFIG_PATH contains a leading '~' the user's
--- home directory will correctly be substituted.
---
--- Revision 1.11  2008/02/23 02:06:26  jsedwards
--- Changed to search for a configuration file in the users home directory
--- first and then read the system configuration file if it doesn't exist.
---
--- Revision 1.10  2008/02/06 04:19:27  jsedwards
--- Fix Bug #1887042 - changed so that all environment variables are checked
--- before reading the config file.
---
--- Revision 1.9  2008/02/05 04:30:05  jsedwards
--- Added nwos_get_log_file_path function.
---
--- Revision 1.8  2008/02/05 04:09:10  jsedwards
--- Fix home directory substitution so it doesn't leave the tilde in.
---
--- Revision 1.7  2008/02/04 03:14:01  jsedwards
--- Added nwos_get_backup_directory_path function.
---
--- Revision 1.6  2008/02/04 02:48:32  jsedwards
--- Added code to convert a path that begins with ~ to the $HOME directory.
---
--- Revision 1.5  2008/02/02 18:20:33  jsedwards
--- Added nwos_get_private_objects_path function.
---
--- Revision 1.4  2008/02/02 16:27:56  jsedwards
--- Added the environment variable name and default path to path_table and
--- made a generic function to find a given path.
---
--- Revision 1.3  2008/02/02 16:11:13  jsedwards
--- Eliminated public_objects_path variable and just stored the path in the
--- path_table.
---
--- Revision 1.2  2008/02/02 15:53:06  jsedwards
--- Added new function to read the configuration file and changed the
--- nwos_get_public_objects_path function to check for environment variable
--- first, then read the configuration file and finally use default path.
---
--- Revision 1.1  2008/01/22 14:51:35  jsedwards
--- Initial version, just returns default public path.
+--   NOTE: Subversion does not support the Log keyword so I have removed the
+--   logs that were here when I was using CVS.  Use the "svn log" command to
+--   see the revision history of this file.
+--   (See http://subversion.tigris.org/faq.html#log-in-source)
 --
 */
 
